# All Global changes to build and install go here.
# Per the below section about __spec_install_pre, any rpm
# environment changes that affect %%install need to go
# here before the %%install macro is pre-built.

# Disable frame pointers
%undefine _include_frame_pointers

# Disable LTO in userspace packages.
%global _lto_cflags %{nil}

# Option to enable compiling with clang instead of gcc.
%bcond_with toolchain_clang

%if %{with toolchain_clang}
%global toolchain clang
%endif

# Compile the kernel with LTO (only supported when building with clang).
%bcond_with clang_lto

%if %{with clang_lto} && %{without toolchain_clang}
{error:clang_lto requires --with toolchain_clang}
%endif

# RPM macros strip everything in BUILDROOT, either with __strip
# or find-debuginfo.sh. Make use of __spec_install_post override
# and save/restore binaries we want to package as unstripped.
%define buildroot_unstripped %{_builddir}/root_unstripped
%define buildroot_save_unstripped() \
(cd %{buildroot}; cp -rav --parents -t %{buildroot_unstripped}/ %1 || true) \
%{nil}
%define __restore_unstripped_root_post \
    echo "Restoring unstripped artefacts %{buildroot_unstripped} -> %{buildroot}" \
    cp -rav %{buildroot_unstripped}/. %{buildroot}/ \
%{nil}

# The kernel's %%install section is special
# Normally the %%install section starts by cleaning up the BUILD_ROOT
# like so:
#
# %%__spec_install_pre %%{___build_pre}\
#     [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf "${RPM_BUILD_ROOT}"\
#     mkdir -p `dirname "$RPM_BUILD_ROOT"`\
#     mkdir "$RPM_BUILD_ROOT"\
# %%{nil}
#
# But because of kernel variants, the %%build section, specifically
# BuildKernel(), moves each variant to its final destination as the
# variant is built.  This violates the expectation of the %%install
# section.  As a result we snapshot the current env variables and
# purposely leave out the removal section.  All global wide changes
# should be added above this line otherwise the %%install section
# will not see them.
%global __spec_install_pre %{___build_pre}

# Replace '-' with '_' where needed so that variants can use '-' in
# their name.
%define uname_suffix() %{lua:
	local flavour = rpm.expand('%{?1:+%{1}}')
	flavour = flavour:gsub('-', '_')
	if flavour ~= '' then
		print(flavour)
	end
}

# This returns the main kernel tied to a debug variant. For example,
# kernel-debug is the debug version of kernel, so we return an empty
# string. However, kernel-64k-debug is the debug version of kernel-64k,
# in this case we need to return "64k", and so on. This is used in
# macros below where we need this for some uname based requires.
%define uname_variant() %{lua:
	local flavour = rpm.expand('%{?1:%{1}}')
	_, _, main, sub = flavour:find("(%w+)-(.*)")
	if main then
		print("+" .. main)
	end
}


# At the time of this writing (2019-03), RHEL8 packages use w2.xzdio
# compression for rpms (xz, level 2).
# Kernel has several large (hundreds of mbytes) rpms, they take ~5 mins
# to compress by single-threaded xz. Switch to threaded compression,
# and from level 2 to 3 to keep compressed sizes close to "w2" results.
#
# NB: if default compression in /usr/lib/rpm/redhat/macros ever changes,
# this one might need tweaking (e.g. if default changes to w3.xzdio,
# change below to w4T.xzdio):
#
# This is disabled on i686 as it triggers oom errors

%ifnarch i686
%define _binary_payload w3T.xzdio
%endif

Summary: The Linux kernel
%if 0%{?fedora}
%define secure_boot_arch x86_64
%else
%define secure_boot_arch x86_64 aarch64 s390x ppc64le
%endif

# Signing for secure boot authentication
%ifarch %{secure_boot_arch}
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

# Default compression algorithm
%global compression xz
%global compression_flags --compress
%global compext xz

%if 0%{?fedora}
%define primary_target fedora
%else
%define primary_target rhel
%endif

#
# genspec.sh variables
#

# kernel package name
%global package_name kernel
%global gemini 0
# Include Fedora files
%global include_fedora 0
# Include RHEL files
%global include_rhel 1
# Include RT files
%global include_rt 1
# Include Automotive files
%global include_automotive 1
# Provide Patchlist.changelog file
%global patchlist_changelog 0
# Set released_kernel to 1 when the upstream source tarball contains a
#  kernel release. (This includes prepatch or "rc" releases.)
# Set released_kernel to 0 when the upstream source tarball contains an
#  unreleased kernel development snapshot.
%global released_kernel 0
# Set debugbuildsenabled to 1 to build separate base and debug kernels
#  (on supported architectures). The kernel-debug-* subpackages will
#  contain the debug kernel.
# Set debugbuildsenabled to 0 to not build a separate debug kernel, but
#  to build the base kernel using the debug configuration. (Specifying
#  the --with-release option overrides this setting.)
%define debugbuildsenabled 1
# define buildid .local
%define specrpmversion 6.12.0
%define specversion 6.12.0
%define patchversion 6.12
%define pkgrelease 74
%define kversion 6
%define tarfile_release 6.12.0-74.el10
# This is needed to do merge window version magic
%define patchlevel 12
# This allows pkg_release to have configurable %%{?dist} tag
%define specrelease 74%{?buildid}%{?dist}
# This defines the kabi tarball version
%define kabiversion 6.12.0-74.el10

# If this variable is set to 1, a bpf selftests build failure will cause a
# fatal kernel package build error
%define selftests_must_build 0

#
# End of genspec.sh variables
#

%define pkg_release %{specrelease}

# libexec dir is not used by the linker, so the shared object there
# should not be exported to RPM provides
%global __provides_exclude_from ^%{_libexecdir}/kselftests

# The following build options are (mostly) enabled by default, but may become
# enabled/disabled by later architecture-specific checks.
# Where disabled by default, they can be enabled by using --with <opt> in the
# rpmbuild command, or by forcing these values to 1.
# Where enabled by default, they can be disabled by using --without <opt> in
# the rpmbuild command, or by forcing these values to 0.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# build the base variants
%define with_base      %{?_without_base:      0} %{?!_without_base:      1}
# build also debug variants
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-16k (aarch64 kernel with 16K page_size)
%define with_arm64_16k %{?_with_arm64_16k:    1} %{?!_with_arm64_16k:    0}
# kernel-64k (aarch64 kernel with 64K page_size)
%define with_arm64_64k %{?_without_arm64_64k: 0} %{?!_without_arm64_64k: 1}
# kernel-rt (x86_64 and aarch64 only PREEMPT_RT enabled kernel)
%define with_realtime  %{?_without_realtime:  0} %{?!_without_realtime:  1}
# kernel-rt-64k (aarch64 RT kernel with 64K page_size)
%define with_realtime_arm64_64k %{?_without_realtime_arm64_64k: 0} %{?!_without_realtime_arm64_64k: 1}
# kernel-automotive (x86_64 and aarch64 with PREEMPT_RT enabled - currently off by default)
%define with_automotive %{?_with_automotive:  1} %{?!_with_automotive:   0}

# Supported variants
#            with_base with_debug    with_gcov
# up         X         X             X
# zfcpdump   X                       X
# arm64_16k  X         X             X
# arm64_64k  X         X             X
# realtime   X         X             X
# automotive X         X             X

# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# libperf
%define with_libperf   %{?_without_libperf:   0} %{?!_without_libperf:   1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# ynl
%define with_ynl      %{?_without_ynl:      0} %{?!_without_ynl:      1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-abi-stablelists
%define with_kernel_abi_stablelists %{?_without_kernel_abi_stablelists: 0} %{?!_without_kernel_abi_stablelists: 1}
# internal samples and selftests
%define with_selftests %{?_without_selftests: 0} %{?!_without_selftests: 1}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug variants (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Only build the realtime kernel (--with rtonly):
%define with_rtonly    %{?_with_rtonly:       1} %{?!_with_rtonly:       0}
# Only build the automotive kernel (--with automotiveonly):%
%define with_automotiveonly %{?_with_automotiveonly:       1} %{?!_with_automotiveonly:       0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Temporarily disable kabi checks until RC.
%define with_kabichk 0
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# Control whether to install the vdso directories.
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# verbose build, i.e. no silent rules and V=1
%define with_verbose %{?_with_verbose:        1} %{?!_with_verbose:      0}

#
# check for mismatched config options
%define with_configchecks %{?_without_configchecks:        0} %{?!_without_configchecks:        1}

#
# gcov support
%define with_gcov %{?_with_gcov:1}%{?!_with_gcov:0}

#
# ipa_clone support
%define with_ipaclones %{?_without_ipaclones: 0} %{?!_without_ipaclones: 1}

# Want to build a vanilla kernel build without any non-upstream patches?
%define with_vanilla %{?_with_vanilla: 1} %{?!_with_vanilla: 0}

%ifarch x86_64 aarch64 riscv64
%define with_efiuki %{?_without_efiuki: 0} %{?!_without_efiuki: 1}
%else
%define with_efiuki 0
%endif

%if 0%{?fedora}
# Kernel headers are being split out into a separate package
%define with_headers 0
%define with_cross_headers 0
# no ipa_clone for now
%define with_ipaclones 0
# no stablelist
%define with_kernel_abi_stablelists 0
%define with_arm64_64k 0
%define with_realtime 0
%define with_realtime_arm64_64k 0
%define with_automotive 0
%endif

%if %{with_verbose}
%define make_opts V=1
%else
%define make_opts -s
%endif

%if %{with toolchain_clang}
%ifarch s390x ppc64le
%global llvm_ias 0
%else
%global llvm_ias 1
%endif
%global clang_make_opts HOSTCC=clang CC=clang LLVM_IAS=%{llvm_ias}
%if %{with clang_lto}
# LLVM=1 enables use of all LLVM tools.
%global clang_make_opts %{clang_make_opts} LLVM=1
%endif
%global make_opts %{make_opts} %{clang_make_opts}
# clang does not support the -fdump-ipa-clones option
%global with_ipaclones 0
%endif

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%define with_kabidw_base 0
%define with_kernel_abi_stablelists 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

# kpatch_kcflags are extra compiler flags applied to base kernel
# -fdump-ipa-clones is enabled only for base kernels on selected arches
%if %{with_ipaclones}
%ifarch x86_64 ppc64le
%define kpatch_kcflags -fdump-ipa-clones
%else
%define with_ipaclones 0
%endif
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{specversion}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{with_vanilla}
%define nopatches 1
%endif

%if %{with_release}
%define debugbuildsenabled 1
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%define with_realtime 0
%define with_vdso_install 0
%define with_perf 0
%define with_libperf 0
%define with_tools 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_ipaclones 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_base 0
%define with_vdso_install 0
%define with_perf 0
%define with_libperf 0
%define with_tools 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_ipaclones 0
%endif

# if requested, only build realtime kernel
%if %{with_rtonly}
%define with_realtime 1
%define with_realtime_arm64_64k 1
%define with_automotive 0
%define with_up 0
%define with_debug 0
%define with_debuginfo 0
%define with_vdso_install 0
%define with_perf 0
%define with_libperf 0
%define with_tools 0
%define with_kernel_abi_stablelists 0
%define with_selftests 0
%define with_ipaclones 0
%define with_headers 0
%define with_efiuki 0
%define with_zfcpdump 0
%define with_arm64_16k 0
%define with_arm64_64k 0
%endif

# if requested, only build automotive kernel
%if %{with_automotiveonly}
%define with_automotive 1
%define with_realtime 0
%define with_up 0
%define with_debug 0
%define with_debuginfo 0
%define with_vdso_install 0
%define with_selftests 1
%endif

# RT and Automotive kernels are only built on x86_64 and aarch64
%ifnarch x86_64 aarch64
%define with_realtime 0
%define with_automotive 0
%endif

%if %{with_automotive}
# overrides compression algorithms for automotive
%global compression zstd
%global compression_flags --rm
%global compext zst

# automotive does not support the following variants
%define with_realtime 0
%define with_realtime_arm64_64k 0
%define with_arm64_16k 0
%define with_arm64_64k 0
%define with_efiuki 0
%define with_doc 0
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_libperf 0
%define with_tools 0
%define with_kabichk 0
%define with_kernel_abi_stablelists 0
%define with_kabidw_base 0
%define with_ipaclones 0
%endif


%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.%compext/'
# for parallel xz processes, replace with 1 to go back to single process
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%if %{with_vdso_install}
%define use_vdso 1
%endif

%ifnarch noarch
%define with_kernel_abi_stablelists 0
%endif

# Overrides for generic default options

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define doc_build_fail true
%endif

%if 0%{?fedora}
# don't do debug builds on anything but aarch64 and x86_64
%ifnarch aarch64 x86_64
%define with_debug 0
%endif
%endif

%define all_configs %{name}-%{specrpmversion}-*.config

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_realtime 0
%define with_automotive 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_libperf 0
%define with_selftests 0
%define with_debug 0
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# 16k and 64k variants only for aarch64
%ifnarch aarch64
%define with_arm64_16k 0
%define with_arm64_64k 0
%define with_realtime_arm64_64k 0
%endif

%if 0%{?fedora}
# This is not for Fedora
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define use_vdso 0
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define kernel_image arch/s390/boot/bzImage
%define vmlinux_decompressor arch/s390/boot/vmlinux
%endif

%ifarch aarch64
%define asmarch arm64
%define hdrarch arm64
%define make_target vmlinuz.efi
%define kernel_image arch/arm64/boot/vmlinuz.efi
%endif

%ifarch riscv64
%define asmarch riscv
%define hdrarch riscv
%define make_target vmlinuz.efi
%define kernel_image arch/riscv/boot/vmlinuz.efi
%endif

# Should make listnewconfig fail if there's config options
# printed out?
%if %{nopatches}
%define with_configchecks 0
%endif

# To temporarily exclude an architecture from being built, add it to
# %%nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We only build kernel-headers on the following...
%if 0%{?fedora}
%define nobuildarches i386
%else
%define nobuildarches i386 i686
%endif

%ifarch %nobuildarches
# disable BuildKernel commands
%define with_up 0
%define with_debug 0
%define with_zfcpdump 0
%define with_arm64_16k 0
%define with_arm64_64k 0
%define with_realtime 0
%define with_realtime_arm64_64k 0
%define with_automotive 0

%define with_debuginfo 0
%define with_perf 0
%define with_libperf 0
%define with_tools 0
%define with_selftests 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%if 0%{?fedora}
%define cpupowerarchs %{ix86} x86_64 ppc64le aarch64
%else
%define cpupowerarchs i686 x86_64 ppc64le aarch64
%endif

# Architectures we build kernel livepatching selftests on
%define klptestarches x86_64 ppc64le s390x

%if 0%{?use_vdso}
%define _use_vdso 1
%else
%define _use_vdso 0
%endif

# If build of debug packages is disabled, we need to know if we want to create
# meta debug packages or not, after we define with_debug for all specific cases
# above. So this must be at the end here, after all cases of with_debug or not.
%define with_debug_meta 0
%if !%{debugbuildsenabled}
%if %{with_debug}
%define with_debug_meta 1
%endif
%define with_debug 0
%endif

# short-hand for "are we building base/non-debug variants of ...?"
%if %{with_up} && %{with_base}
%define with_up_base 1
%else
%define with_up_base 0
%endif
%if %{with_realtime} && %{with_base}
%define with_realtime_base 1
%else
%define with_realtime_base 0
%endif
%if %{with_automotive} && %{with_base}
%define with_automotive_base 1
%else
%define with_automotive_base 0
%endif
%if %{with_arm64_16k} && %{with_base}
%define with_arm64_16k_base 1
%else
%define with_arm64_16k_base 0
%endif
%if %{with_arm64_64k} && %{with_base}
%define with_arm64_64k_base 1
%else
%define with_arm64_64k_base 0
%endif
%if %{with_realtime_arm64_64k} && %{with_base}
%define with_realtime_arm64_64k_base 1
%else
%define with_realtime_arm64_64k_base 0
%endif

#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: %{package_name}
License: ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-2-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-only WITH Linux-syscall-note) OR CDDL-1.0) AND ((GPL-2.0-only WITH Linux-syscall-note) OR Linux-OpenIB) AND ((GPL-2.0-only WITH Linux-syscall-note) OR MIT) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR BSD-3-Clause) AND ((GPL-2.0-or-later WITH Linux-syscall-note) OR MIT) AND 0BSD AND BSD-2-Clause AND (BSD-2-Clause OR Apache-2.0) AND BSD-3-Clause AND BSD-3-Clause-Clear AND CC0-1.0 AND GFDL-1.1-no-invariants-or-later AND GPL-1.0-or-later AND (GPL-1.0-or-later OR BSD-3-Clause) AND (GPL-1.0-or-later WITH Linux-syscall-note) AND GPL-2.0-only AND (GPL-2.0-only OR Apache-2.0) AND (GPL-2.0-only OR BSD-2-Clause) AND (GPL-2.0-only OR BSD-3-Clause) AND (GPL-2.0-only OR CDDL-1.0) AND (GPL-2.0-only OR GFDL-1.1-no-invariants-or-later) AND (GPL-2.0-only OR GFDL-1.2-no-invariants-only) AND (GPL-2.0-only WITH Linux-syscall-note) AND GPL-2.0-or-later AND (GPL-2.0-or-later OR BSD-2-Clause) AND (GPL-2.0-or-later OR BSD-3-Clause) AND (GPL-2.0-or-later OR CC-BY-4.0) AND (GPL-2.0-or-later WITH GCC-exception-2.0) AND (GPL-2.0-or-later WITH Linux-syscall-note) AND ISC AND LGPL-2.0-or-later AND (LGPL-2.0-or-later OR BSD-2-Clause) AND (LGPL-2.0-or-later WITH Linux-syscall-note) AND LGPL-2.1-only AND (LGPL-2.1-only OR BSD-2-Clause) AND (LGPL-2.1-only WITH Linux-syscall-note) AND LGPL-2.1-or-later AND (LGPL-2.1-or-later WITH Linux-syscall-note) AND (Linux-OpenIB OR GPL-2.0-only) AND (Linux-OpenIB OR GPL-2.0-only OR BSD-2-Clause) AND Linux-man-pages-copyleft AND MIT AND (MIT OR Apache-2.0) AND (MIT OR GPL-2.0-only) AND (MIT OR GPL-2.0-or-later) AND (MIT OR LGPL-2.1-only) AND (MPL-1.1 OR GPL-2.0-only) AND (X11 OR GPL-2.0-only) AND (X11 OR GPL-2.0-or-later) AND Zlib AND (copyleft-next-0.3.1 OR GPL-2.0-or-later)
URL: https://www.kernel.org/
Version: %{specrpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
%if 0%{?fedora}
ExclusiveArch: noarch x86_64 s390x aarch64 ppc64le riscv64
%else
ExclusiveArch: noarch i386 i686 x86_64 s390x aarch64 ppc64le
%endif
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: kernel-core-uname-r = %{KVERREL}
Requires: kernel-modules-uname-r = %{KVERREL}
Requires: kernel-modules-core-uname-r = %{KVERREL}
Provides: installonlypkg(kernel)
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, bash, coreutils, tar, git-core, which
BuildRequires: bzip2, xz, findutils, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk, %compression
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, bison, flex, gcc-c++
%if 0%{?fedora}
BuildRequires: rust, rust-src, bindgen
%endif
BuildRequires: net-tools, hostname, bc, elfutils-devel
BuildRequires: dwarves
BuildRequires: python3
BuildRequires: python3-devel
BuildRequires: python3-pyyaml
BuildRequires: kernel-rpm-macros
# glibc-static is required for a consistent build environment (specifically
# CONFIG_CC_CAN_LINK_STATIC=y).
BuildRequires: glibc-static
%if %{with_headers} || %{with_cross_headers}
BuildRequires: rsync
%endif
%if %{with_doc}
BuildRequires: xmlto, asciidoc, python3-sphinx, python3-sphinx_rtd_theme
%endif
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel python3-setuptools
BuildRequires: java-devel
BuildRequires: libbpf-devel >= 0.6.0-1
BuildRequires: libbabeltrace-devel
BuildRequires: libtraceevent-devel
%ifnarch s390x
BuildRequires: numactl-devel
%endif
%ifarch aarch64
BuildRequires: opencsd-devel >= 1.0.0
%endif
%endif
%if %{with_tools}
BuildRequires: python3-docutils
BuildRequires: gettext ncurses-devel
BuildRequires: libcap-devel libcap-ng-devel
# The following are rtla requirements
BuildRequires: python3-docutils
BuildRequires: libtraceevent-devel
BuildRequires: libtracefs-devel

%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%ifarch i686 x86_64
BuildRequires: libnl3-devel
%endif
%endif

%if %{with_tools} && %{with_ynl}
BuildRequires: python3-pyyaml python3-jsonschema python3-pip python3-setuptools python3-wheel
%endif

%if %{with_tools} || %{signmodules} || %{signkernel}
BuildRequires: openssl-devel
%endif
%if %{with_selftests}
BuildRequires: clang llvm-devel fuse-devel zlib-devel binutils-devel
%ifarch x86_64 riscv64
BuildRequires: lld
%endif
BuildRequires: libcap-devel libcap-ng-devel rsync libmnl-devel libxml2-devel
BuildRequires: numactl-devel
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
BuildConflicts: dwarves < 1.13
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages

# Remove -q option below to provide 'extracting debug info' messages
%global _find_debuginfo_opts -r -q

%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl
%if %{signkernel}
# ELN uses Fedora signing process, so exclude
%if 0%{?rhel}%{?centos} && !0%{?eln}
BuildRequires: system-sb-certs
%endif
%ifarch x86_64 aarch64 riscv64
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%define __strip %{_build_arch}-linux-gnu-strip

# Work around find-debuginfo for cross builds.
# find-debuginfo doesn't support any of CROSS options (RHEL-21797),
# and since debugedit > 5.0-16.el10, or since commit
#   dfe1f7ff30f4 ("find-debuginfo.sh: Exit with real exit status in parallel jobs")
# it now aborts and build fails.
%undefine _include_gdb_index
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

%if %{with toolchain_clang}
BuildRequires: clang
%endif

%if %{with clang_lto}
BuildRequires: llvm
BuildRequires: lld
%endif

%if %{with_efiuki}
BuildRequires: dracut >= 104
# For dracut UEFI uki binaries
BuildRequires: binutils
# For the initrd
BuildRequires: lvm2
BuildRequires: systemd-boot-unsigned
# For systemd-stub and systemd-pcrphase
BuildRequires: systemd-udev >= 252-1
# For UKI kernel cmdline addons
BuildRequires: systemd-ukify
# For TPM operations in UKI initramfs
BuildRequires: tpm2-tools
# For UKI sb cert
%if 0%{?rhel}%{?centos} && !0%{?eln}
%if 0%{?centos}
BuildRequires: centos-sb-certs >= 9.0-23
%else
BuildRequires: redhat-sb-certs >= 9.4-0.1
%endif
%endif
%endif

# Because this is the kernel, it's hard to get a single upstream URL
# to represent the base without needing to do a bunch of patching. This
# tarball is generated from a src-git tree. If you want to see the
# exact git commit you can run
#
# xzcat -qq ${TARBALL} | git get-tar-commit-id
Source0: linux-%{tarfile_release}.tar.xz

Source1: Makefile.rhelver
Source2: kernel.changelog

Source10: redhatsecurebootca5.cer
Source13: redhatsecureboot501.cer

%if %{signkernel}
# Name of the packaged file containing signing key
%ifarch ppc64le
%define signing_key_filename kernel-signing-ppc.cer
%endif
%ifarch s390x
%define signing_key_filename kernel-signing-s390.cer
%endif

# Fedora/ELN pesign macro expects to see these cert file names, see:
# https://github.com/rhboot/pesign/blob/main/src/pesign-rpmbuild-helper.in#L216
%if 0%{?fedora}%{?eln}
%define pesign_name_0 redhatsecureboot501
%define secureboot_ca_0 %{SOURCE10}
%define secureboot_key_0 %{SOURCE13}
%endif

# RHEL/centos certs come from system-sb-certs
%if 0%{?rhel} && !0%{?eln}
%define secureboot_ca_0 %{_datadir}/pki/sb-certs/secureboot-ca-%{_arch}.cer
%define secureboot_key_0 %{_datadir}/pki/sb-certs/secureboot-kernel-%{_arch}.cer

%if 0%{?centos}
%define pesign_name_0 centossecureboot201
%else
%ifarch x86_64 aarch64
%define pesign_name_0 redhatsecureboot501
%endif
%ifarch s390x
%define pesign_name_0 redhatsecureboot302
%endif
%ifarch ppc64le
%define pesign_name_0 redhatsecureboot701
%endif
%endif
# rhel && !eln
%endif

# signkernel
%endif

Source20: mod-denylist.sh
Source21: mod-sign.sh
Source22: filtermods.py

%define modsign_cmd %{SOURCE21}

%if 0%{?include_rhel}
Source23: x509.genkey.rhel

Source24: %{name}-aarch64-rhel.config
Source25: %{name}-aarch64-debug-rhel.config

Source27: %{name}-ppc64le-rhel.config
Source28: %{name}-ppc64le-debug-rhel.config
Source29: %{name}-s390x-rhel.config
Source30: %{name}-s390x-debug-rhel.config
Source31: %{name}-s390x-zfcpdump-rhel.config
Source32: %{name}-x86_64-rhel.config
Source33: %{name}-x86_64-debug-rhel.config

Source34: def_variants.yaml.rhel

Source41: x509.genkey.centos
# ARM64 64K page-size kernel config
Source42: %{name}-aarch64-64k-rhel.config
Source43: %{name}-aarch64-64k-debug-rhel.config

%endif

%if 0%{?include_fedora}
Source50: x509.genkey.fedora

Source52: %{name}-aarch64-fedora.config
Source53: %{name}-aarch64-debug-fedora.config
Source54: %{name}-aarch64-16k-fedora.config
Source55: %{name}-aarch64-16k-debug-fedora.config
Source56: %{name}-ppc64le-fedora.config
Source57: %{name}-ppc64le-debug-fedora.config
Source58: %{name}-s390x-fedora.config
Source59: %{name}-s390x-debug-fedora.config
Source60: %{name}-x86_64-fedora.config
Source61: %{name}-x86_64-debug-fedora.config
Source700: %{name}-riscv64-fedora.config
Source701: %{name}-riscv64-debug-fedora.config

Source62: def_variants.yaml.fedora
%endif

Source70: partial-kgcov-snip.config
Source71: partial-kgcov-debug-snip.config
Source72: partial-clang-snip.config
Source73: partial-clang-debug-snip.config
Source74: partial-clang_lto-x86_64-snip.config
Source75: partial-clang_lto-x86_64-debug-snip.config
Source76: partial-clang_lto-aarch64-snip.config
Source77: partial-clang_lto-aarch64-debug-snip.config
Source80: generate_all_configs.sh
Source81: process_configs.sh

Source86: dracut-virt.conf

Source87: flavors

Source151: uki_create_addons.py
Source152: uki_addons.json

Source100: rheldup3.x509
Source101: rhelkpatch1.x509
Source102: nvidiagpuoot001.x509
Source103: rhelimaca1.x509
Source104: rhelima.x509
Source105: rhelima_centos.x509
Source106: fedoraimaca.x509

%if 0%{?fedora}%{?eln}
%define ima_ca_cert %{SOURCE106}
%endif

%if 0%{?rhel} && !0%{?eln}
%define ima_ca_cert %{SOURCE103}
# rhel && !eln
%endif

%if 0%{?centos}
%define ima_signing_cert %{SOURCE105}
%else
%define ima_signing_cert %{SOURCE104}
%endif

%define ima_cert_name ima.cer

Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64
Source205: Module.kabi_riscv64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64
Source214: Module.kabi_dup_riscv64

Source300: kernel-abi-stablelists-%{kabiversion}.tar.xz
Source301: kernel-kabi-dw-%{kabiversion}.tar.xz

%if 0%{include_rt}
%if 0%{include_rhel}
Source474: %{name}-aarch64-rt-rhel.config
Source475: %{name}-aarch64-rt-debug-rhel.config
Source476: %{name}-aarch64-rt-64k-rhel.config
Source477: %{name}-aarch64-rt-64k-debug-rhel.config
Source478: %{name}-x86_64-rt-rhel.config
Source479: %{name}-x86_64-rt-debug-rhel.config
%endif
%if 0%{include_fedora}
Source478: %{name}-aarch64-rt-fedora.config
Source479: %{name}-aarch64-rt-debug-fedora.config
Source480: %{name}-aarch64-rt-64k-fedora.config
Source481: %{name}-aarch64-rt-64k-debug-fedora.config
Source482: %{name}-x86_64-rt-fedora.config
Source483: %{name}-x86_64-rt-debug-fedora.config
Source484: %{name}-riscv64-rt-fedora.config
Source485: %{name}-riscv64-rt-debug-fedora.config
%endif
%endif

%if %{include_automotive}
# automotive config files
Source486: %{name}-aarch64-automotive-rhel.config
Source487: %{name}-aarch64-automotive-debug-rhel.config
Source488: %{name}-x86_64-automotive-rhel.config
Source489: %{name}-x86_64-automotive-debug-rhel.config
%endif


# Sources for kernel-tools
Source2002: kvm_stat.logrotate

# Some people enjoy building customized kernels from the dist-git in Fedora and
# use this to override configuration options. One day they may all use the
# source tree, but in the mean time we carry this to support the legacy workflow
Source3000: merge.py
Source3001: kernel-local
%if %{patchlist_changelog}
Source3002: Patchlist.changelog
%endif

Source4000: README.rst
Source4001: rpminspect.yaml
Source4002: gating.yaml

## Patches needed for building this package

%if !%{nopatches}

Patch1: patch-%{patchversion}-redhat.patch
%endif

# empty final patch to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

# END OF PATCH DEFINITIONS

%description
The kernel meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf [-o] <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf(o) \
%if %{-o:0}%{!-o:1}\
Provides: kernel = %{specversion}-%{pkg_release}\
%endif\
Provides: kernel-%{_target_cpu} = %{specrpmversion}-%{pkg_release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): ((linux-firmware >= 20150904-56.git6ebf5d57) if linux-firmware)\
Recommends: linux-firmware\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%if 0%{?gemini}
Provides: kernel-headers = %{specversion}-%{release}
Obsoletes: kernel-headers < %{specversion}
%endif
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
%if 0%{?gemini}
Provides: kernel-cross-headers = %{specversion}-%{release}
Obsoletes: kernel-cross-headers < %{specversion}
%endif
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.

%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
%if 0%{gemini}
Epoch: %{gemini}
%endif
Summary: Performance monitoring for the Linux kernel
Requires: bzip2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
%if 0%{gemini}
Epoch: %{gemini}
%endif
Summary: Debug information for package perf
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specrpmversion}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/libperf-jvmti.so(\.debug)?|XXX' -o perf-debuginfo.list}

%package -n python3-perf
%if 0%{gemini}
Epoch: %{gemini}
%endif
Summary: Python bindings for apps which will manipulate perf events
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
%if 0%{gemini}
Epoch: %{gemini}
%endif
Summary: Debug information for package perf python bindings
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specrpmversion}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}

# with_perf
%endif

%if %{with_libperf}
%package -n libperf
Summary: The perf library from kernel source
%description -n libperf
This package contains the kernel source perf library.

%package -n libperf-devel
Summary: Developement files for the perf library from kernel source
Requires: libperf = %{version}-%{release}
%description -n libperf-devel
This package includes libraries and header files needed for development
of applications which use perf library from kernel source.

%package -n libperf-debuginfo
Summary: Debug information for package libperf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n libperf-debuginfo
This package provides debug information for the libperf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libdir}/libperf.so.*(\.debug)?|XXX' -o libperf-debuginfo.list}
# with_libperf
%endif

%if %{with_tools}
%package -n %{package_name}-tools
Summary: Assortment of tools for the Linux kernel
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: %{package_name}-tools-libs = %{specrpmversion}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n %{package_name}-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n %{package_name}-tools-libs
Summary: Libraries for the kernels-tools
%description -n %{package_name}-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n %{package_name}-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Requires: %{package_name}-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: %{package_name}-tools-libs = %{version}-%{release}
Provides: %{package_name}-tools-devel
%description -n %{package_name}-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n %{package_name}-tools-debuginfo
Summary: Debug information for package %{package_name}-tools
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n %{package_name}-tools-debuginfo
This package provides debug information for package %{package_name}-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/bootconfig(\.debug)?|.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/gpio-watch(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|.*%%{_bindir}/intel-speed-select(\.debug)?|.*%%{_bindir}/page_owner_sort(\.debug)?|.*%%{_bindir}/slabinfo(\.debug)?|.*%%{_sbindir}/intel_sdsi(\.debug)?|XXX' -o %{package_name}-tools-debuginfo.list}

%package -n rtla
%if 0%{gemini}
Epoch: %{gemini}
%endif
Summary: Real-Time Linux Analysis tools
Requires: libtraceevent
Requires: libtracefs
%ifarch %{cpupowerarchs}
Requires: %{package_name}-tools-libs = %{version}-%{release}
%endif
%description -n rtla
The rtla meta-tool includes a set of commands that aims to analyze
the real-time properties of Linux. Instead of testing Linux as a black box,
rtla leverages kernel tracing capabilities to provide precise information
about the properties and root causes of unexpected results.

%package -n rv
Summary: RV: Runtime Verification
%description -n rv
Runtime Verification (RV) is a lightweight (yet rigorous) method that
complements classical exhaustive verification techniques (such as model
checking and theorem proving) with a more practical approach for
complex systems.
The rv tool is the interface for a collection of monitors that aim
analysing the logical and timing behavior of Linux.

# with_tools
%endif

%if %{with_selftests}

%package selftests-internal
Summary: Kernel samples and selftests
Requires: binutils, bpftool, iproute-tc, nmap-ncat, python3, fuse-libs, keyutils
%description selftests-internal
Kernel sample programs and selftests.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_libexecdir}/(ksamples|kselftests)/.*|XXX' -o selftests-debuginfo.list}

%define __requires_exclude ^liburandom_read.so.*$

# with_selftests
%endif

%define kernel_gcov_package() \
%package %{?1:%{1}-}gcov\
Summary: gcov graph and source files for coverage data collection.\
%description %{?1:%{1}-}gcov\
%{?1:%{1}-}gcov includes the gcov graph and source files for gcov coverage collection.\
%{nil}

%package -n %{package_name}-abi-stablelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol stablelists
AutoReqProv: no
%description -n %{package_name}-abi-stablelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kernel-kabidw-base-internal
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kernel-kabidw-base-internal
The package contains data describing the current ABI of the Red Hat Enterprise
Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
# Explanation of the find_debuginfo_opts: We build multiple kernels (debug,
# rt, 64k etc.) so the regex filters those kernels appropriately. We also
# have to package several binaries as part of kernel-devel but getting
# unique build-ids is tricky for these userspace binaries. We don't really
# care about debugging those so we just filter those out and remove it.
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} --keep-section '.BTF' -p '.*\/usr\/src\/kernels/.*|XXX' -o ignored-debuginfo.list -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_package(m) \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
Requires: openssl-devel\
Requires: elfutils-libelf-devel\
Requires: bison\
Requires: flex\
Requires: make\
Requires: gcc\
%if %{-m:1}%{!-m:0}\
Requires: kernel-devel-uname-r = %{KVERREL}%{uname_variant %{?1:%{1}}}\
%endif\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates an empty kernel-<subpackage>-devel-matched package that
# requires both the core and devel packages locked on the same version.
#	%%kernel_devel_matched_package [-m] <subpackage> <pretty-name>
#
%define kernel_devel_matched_package(m) \
%package %{?1:%{1}-}devel-matched\
Summary: Meta package to install matching core and devel packages for a given %{?2:%{2} }kernel\
Requires: %{package_name}%{?1:-%{1}}-devel = %{specrpmversion}-%{release}\
Requires: %{package_name}%{?1:-%{1}}-core = %{specrpmversion}-%{release}\
%description %{?1:%{1}-}devel-matched\
This meta package is used to install matching core and devel packages for a given %{?2:%{2} }kernel.\
%{nil}

#
# kernel-<variant>-ipaclones-internal package
#
%define kernel_ipaclones_package() \
%package %{?1:%{1}-}ipaclones-internal\
Summary: *.ipa-clones files generated by -fdump-ipa-clones for kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
AutoReqProv: no\
%description %{?1:%{1}-}ipaclones-internal\
This package provides *.ipa-clones files.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-internal package.
#	%%kernel_modules_internal_package <subpackage> <pretty-name>
#
%define kernel_modules_internal_package() \
%package %{?1:%{1}-}modules-internal\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-internal-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-internal = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-internal-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-internal\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat internal usage.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_extra_package(m) \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-extra = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-extra-uname-r = %{KVERREL}%{uname_variant %{?1:+%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_package(m) \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel-modules-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel-modules = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-uname-r = %{KVERREL}%{uname_variant %{?1:+%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-core package.
#	%%kernel_modules_core_package [-m] <subpackage> <pretty-name>
#
%define kernel_modules_core_package(m) \
%package %{?1:%{1}-}modules-core\
Summary: Core kernel modules to match the %{?2:%{2}-}core kernel\
Provides: kernel%{?1:-%{1}}-modules-core-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel-modules-core-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel-modules-core = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
%if %{-m:1}%{!-m:0}\
Requires: kernel-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:+%{1}}}\
%endif\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-core\
This package provides essential kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
Requires: kernel-%{1}-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-uname-r = %{KVERREL}%{uname_suffix %{1}}\
Requires: kernel-%{1}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{1}}\
%if "%{1}" == "rt" || "%{1}" == "rt-debug" || "%{1}" == "rt-64k" || "%{1}" == "rt-64k-debug"\
Requires: realtime-setup\
%endif\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

%if %{with_realtime} || %{with_realtime_arm64_64k}
#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package kernel%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n kernel%{?1:-%{1}}-kvm\
This package provides KVM modules for package kernel%{?1:-%{1}}.\
%{nil}
%endif

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] [-m] [-o] <subpackage>
#
%define kernel_variant_package(n:mo) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Provides: kernel-%{?1:%{1}-}core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel)\
%if %{-m:1}%{!-m:0}\
Requires: kernel-core-uname-r = %{KVERREL}%{uname_variant %{?1:+%{1}}}\
Requires: kernel-%{?1:%{1}-}-modules-core-uname-r = %{KVERREL}%{uname_variant %{?1:+%{1}}}\
%endif\
%{expand:%%kernel_reqprovconf %{?1:%{1}} %{-o:%{-o}}}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_devel_matched_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_core_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}} %{-m:%{-m}}}\
%if %{-m:0}%{!-m:1}\
%{expand:%%kernel_modules_internal_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%endif\
%if "%{1}" == "rt" || "%{1}" == "rt-debug" || "%{1}" == "rt-64k" || "%{1}" == "rt-64k-debug"\
%{expand:%%kernel_kvm_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%else \
%if %{with_efiuki}\
%package %{?1:%{1}-}uki-virt\
Summary: %{variant_summary} unified kernel image for virtual machines\
Provides: installonlypkg(kernel)\
Provides: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): systemd >= 254-1\
%package %{?1:%{1}-}uki-virt-addons\
Summary: %{variant_summary} unified kernel image addons for virtual machines\
Provides: installonlypkg(kernel)\
Requires: kernel%{?1:-%{1}}-uki-virt = %{specrpmversion}-%{release}\
Requires(pre): systemd >= 254-1\
%endif\
%endif\
%if %{with_gcov}\
%{expand:%%kernel_gcov_package %{?1:%{1}}}\
%endif\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-partner package.
#	%%kernel_modules_partner_package <subpackage> <pretty-name>
#
%define kernel_modules_partner_package() \
%package %{?1:%{1}-}modules-partner\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{specrpmversion}-%{release}\
Provides: kernel%{?1:-%{1}}-modules-partner-%{_target_cpu} = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: kernel%{?1:-%{1}}-modules-partner = %{specrpmversion}-%{release}%{uname_suffix %{?1:+%{1}}}\
Provides: installonlypkg(kernel-module)\
Provides: kernel%{?1:-%{1}}-modules-partner-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
Requires: kernel%{?1:-%{1}}-modules-core-uname-r = %{KVERREL}%{uname_suffix %{?1:+%{1}}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-partner\
This package provides kernel modules for the %{?2:%{2} }kernel package for Red Hat partners usage.\
%{nil}

# Now, each variant package.
%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package -o zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
# with_zfcpdump
%endif

%if %{with_arm64_16k_base}
%define variant_summary The Linux kernel compiled for 16k pagesize usage
%kernel_variant_package 16k
%description 16k-core
The kernel package contains a variant of the ARM64 Linux kernel using
a 16K page size.
%endif

%if %{with_arm64_16k} && %{with_debug}
%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m 16k-debug
%else
%kernel_variant_package 16k-debug
%endif
%description 16k-debug-core
The debug kernel package contains a variant of the ARM64 Linux kernel using
a 16K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_arm64_64k_base}
%define variant_summary The Linux kernel compiled for 64k pagesize usage
%kernel_variant_package 64k
%description 64k-core
The kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
%endif

%if %{with_arm64_64k} && %{with_debug}
%define variant_summary The Linux kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m 64k-debug
%else
%kernel_variant_package 64k-debug
%endif
%description 64k-debug-core
The debug kernel package contains a variant of the ARM64 Linux kernel using
a 64K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_debug} && %{with_realtime}
%define variant_summary The Linux PREEMPT_RT kernel compiled with extra debugging enabled
%kernel_variant_package rt-debug
%description rt-debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_realtime_base}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package rt
%description rt-core
This package includes a version of the Linux kernel compiled with the
PREEMPT_RT real-time preemption support
%endif

%if %{with_realtime_arm64_64k_base}
%define variant_summary The Linux PREEMPT_RT kernel compiled for 64k pagesize usage
%kernel_variant_package rt-64k
%description rt-64k-core
The kernel package contains a variant of the ARM64 Linux PREEMPT_RT kernel using
a 64K page size.
%endif

%if %{with_realtime_arm64_64k} && %{with_debug}
%define variant_summary The Linux PREEMPT_RT kernel compiled with extra debugging enabled
%if !%{debugbuildsenabled}
%kernel_variant_package -m rt-64k-debug
%else
%kernel_variant_package rt-64k-debug
%endif
%description rt-64k-debug-core
The debug kernel package contains a variant of the ARM64 Linux PREEMPT_RT kernel using
a 64K page size.
This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_debug} && %{with_automotive}
%define variant_summary The Linux Automotive kernel compiled with extra debugging enabled
%kernel_variant_package automotive-debug
%description automotive-debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_automotive_base}
%define variant_summary The Linux kernel compiled with PREEMPT_RT enabled
%kernel_variant_package automotive
%description automotive-core
This package includes a version of the Linux kernel compiled with the
PREEMPT_RT real-time preemption support, targeted for Automotive platforms
%endif

%if %{with_up} && %{with_debug}
%if !%{debugbuildsenabled}
%kernel_variant_package -m debug
%else
%kernel_variant_package debug
%endif
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.
%endif

%if %{with_up_base}
# And finally the main -core package

%define variant_summary The Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.
%endif

%if %{with_up} && %{with_debug} && %{with_efiuki}
%description debug-uki-virt
Prebuilt debug unified kernel image for virtual machines.

%description debug-uki-virt-addons
Prebuilt debug unified kernel image addons for virtual machines.
%endif

%if %{with_up_base} && %{with_efiuki}
%description uki-virt
Prebuilt default unified kernel image for virtual machines.

%description uki-virt-addons
Prebuilt default unified kernel image addons for virtual machines.
%endif

%if %{with_arm64_16k} && %{with_debug} && %{with_efiuki}
%description 16k-debug-uki-virt
Prebuilt 16k debug unified kernel image for virtual machines.

%description 16k-debug-uki-virt-addons
Prebuilt 16k debug unified kernel image addons for virtual machines.
%endif

%if %{with_arm64_16k_base} && %{with_efiuki}
%description 16k-uki-virt
Prebuilt 16k unified kernel image for virtual machines.

%description 16k-uki-virt-addons
Prebuilt 16k unified kernel image addons for virtual machines.
%endif

%if %{with_arm64_64k} && %{with_debug} && %{with_efiuki}
%description 64k-debug-uki-virt
Prebuilt 64k debug unified kernel image for virtual machines.

%description 64k-debug-uki-virt-addons
Prebuilt 64k debug unified kernel image addons for virtual machines.
%endif

%if %{with_arm64_64k_base} && %{with_efiuki}
%description 64k-uki-virt
Prebuilt 64k unified kernel image for virtual machines.

%description 64k-uki-virt-addons
Prebuilt 64k unified kernel image addons for virtual machines.
%endif

%if %{with_ipaclones}
%kernel_ipaclones_package
%endif

%define log_msg() \
	{ set +x; } 2>/dev/null \
	_log_msglineno=$(grep -n %{*} %{_specdir}/${RPM_PACKAGE_NAME}.spec | grep log_msg | cut -d":" -f1) \
	echo "kernel.spec:${_log_msglineno}: %{*}" \
	set -x

%prep
%{log_msg "Start of prep stage"}

%{log_msg "Sanity checks"}

# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
%{log_msg "Cannot build --with baseonly, up build is disabled"}
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
	%{log_msg "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"}
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='git --work-tree=. apply'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME}.spec ; then
    if [ "${patch:0:8}" != "patch-%{kversion}." ] ; then
	%{log_msg "ERROR: Patch  $patch  not listed as a source patch in specfile"}
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  %{log_msg "ApplyOptionalPatch: $1"}
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%{log_msg "Untar kernel tarball"}
%setup -q -n kernel-%{tarfile_release} -c
mv linux-%{tarfile_release} linux-%{KVERREL}

cd linux-%{KVERREL}
cp -a %{SOURCE1} .

%{log_msg "Start of patch applications"}
%if !%{nopatches}

ApplyOptionalPatch patch-%{patchversion}-redhat.patch
%endif

ApplyOptionalPatch linux-kernel-test.patch

%{log_msg "End of patch applications"}
# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.
%{log_msg "Pre-build tree manipulations"}
chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{specrpmversion}-%{release}

# on linux-next prevent scripts/setlocalversion from mucking with our version numbers
rm -f localversion-next localversion-rt

# Mangle /usr/bin/python shebangs to /usr/bin/python3
# Mangle all Python shebangs to be Python 3 explicitly
# -p preserves timestamps
# -n prevents creating ~backup files
# -i specifies the interpreter for the shebang
# This fixes errors such as
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
%{log_msg "Fixing Python shebangs..."}
%py3_shebang_fix \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	scripts/jobserver-exec \
	tools \
	Documentation \
	scripts/clang-tools 2> /dev/null

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

%{log_msg "Copy additional source files into buildroot"}
# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/%{name}-*.config .
cp %{SOURCE80} .
# merge.py
cp %{SOURCE3000} .
# kernel-local - rename and copy for partial snippet config process
cp %{SOURCE3001} partial-kernel-local-snip.config
cp %{SOURCE3001} partial-kernel-local-debug-snip.config
FLAVOR=%{primary_target} SPECPACKAGE_NAME=%{name} SPECVERSION=%{specversion} SPECRPMVERSION=%{specrpmversion} ./generate_all_configs.sh %{debugbuildsenabled}

# Collect custom defined config options
%{log_msg "Collect custom defined config options"}
PARTIAL_CONFIGS=""
%if %{with_gcov}
PARTIAL_CONFIGS="$PARTIAL_CONFIGS %{SOURCE70} %{SOURCE71}"
%endif
%if %{with toolchain_clang}
PARTIAL_CONFIGS="$PARTIAL_CONFIGS %{SOURCE72} %{SOURCE73}"
%endif
%if %{with clang_lto}
PARTIAL_CONFIGS="$PARTIAL_CONFIGS %{SOURCE74} %{SOURCE75} %{SOURCE76} %{SOURCE77}"
%endif
PARTIAL_CONFIGS="$PARTIAL_CONFIGS partial-kernel-local-snip.config partial-kernel-local-debug-snip.config"

GetArch()
{
  case "$1" in
  *aarch64*) echo "aarch64" ;;
  *ppc64le*) echo "ppc64le" ;;
  *s390x*) echo "s390x" ;;
  *x86_64*) echo "x86_64" ;;
  *riscv64*) echo "riscv64" ;;
  # no arch, apply everywhere
  *) echo "" ;;
  esac
}

# Merge in any user-provided local config option changes
%{log_msg "Merge in any user-provided local config option changes"}
%ifnarch %nobuildarches
for i in %{all_configs}
do
  kern_arch="$(GetArch $i)"
  kern_debug="$(echo $i | grep -q debug && echo "debug" || echo "")"

  for j in $PARTIAL_CONFIGS
  do
    part_arch="$(GetArch $j)"
    part_debug="$(echo $j | grep -q debug && echo "debug" || echo "")"

    # empty arch means apply to all arches
    if [ "$part_arch" == "" -o "$part_arch" == "$kern_arch" ] && [ "$part_debug" == "$kern_debug" ]
    then
      mv $i $i.tmp
      ./merge.py $j $i.tmp > $i
    fi
  done
  rm -f $i.tmp
done
%endif

%if %{signkernel}%{signmodules}

# Add DUP and kpatch certificates to system trusted keys for RHEL
%if 0%{?rhel}
%{log_msg "Add DUP and kpatch certificates to system trusted keys for RHEL"}
openssl x509 -inform der -in %{SOURCE100} -out rheldup3.pem
openssl x509 -inform der -in %{SOURCE101} -out rhelkpatch1.pem
openssl x509 -inform der -in %{SOURCE102} -out nvidiagpuoot001.pem
cat rheldup3.pem rhelkpatch1.pem nvidiagpuoot001.pem > ../certs/rhel.pem
%if %{signkernel}
%ifarch s390x ppc64le
openssl x509 -inform der -in %{secureboot_ca_0} -out secureboot.pem
cat secureboot.pem >> ../certs/rhel.pem
%endif
%endif

# rhel
%endif

openssl x509 -inform der -in %{ima_ca_cert} -out imaca.pem
cat imaca.pem >> ../certs/rhel.pem

for i in *.config; do
  sed -i 's@CONFIG_SYSTEM_TRUSTED_KEYS=""@CONFIG_SYSTEM_TRUSTED_KEYS="certs/rhel.pem"@' $i
done
%endif

# Adjust FIPS module name for RHEL
%if 0%{?rhel}
%{log_msg "Adjust FIPS module name for RHEL"}
for i in *.config; do
  sed -i 's/CONFIG_CRYPTO_FIPS_NAME=.*/CONFIG_CRYPTO_FIPS_NAME="Red Hat Enterprise Linux %{rhel} - Kernel Cryptographic API"/' $i
done
%endif

%{log_msg "Set process_configs.sh $OPTS"}
cp %{SOURCE81} .
OPTS=""
%if %{with_configchecks}
	OPTS="$OPTS -w -n -c"
%endif
%if %{with clang_lto}
for opt in %{clang_make_opts}; do
  OPTS="$OPTS -m $opt"
done
%endif
%{log_msg "Generate redhat configs"}
RHJOBS=$RPM_BUILD_NCPUS SPECPACKAGE_NAME=%{name} ./process_configs.sh $OPTS %{specrpmversion}

# We may want to override files from the primary target in case of building
# against a flavour of it (eg. centos not rhel), thus override it here if
# necessary
update_scripts() {
	TARGET="$1"

	for i in "$RPM_SOURCE_DIR"/*."$TARGET"; do
		NEW=${i%."$TARGET"}
		cp "$i" "$(basename "$NEW")"
	done
}

%{log_msg "Set scripts/SOURCES targets"}
update_target=%{primary_target}
if [ "%{primary_target}" == "rhel" ]; then
: # no-op to avoid empty if-fi error
%if 0%{?centos}
  update_scripts $update_target
  %{log_msg "Updating scripts/sources to centos version"}
  update_target=centos
%endif
fi
update_scripts $update_target

%endif

%{log_msg "End of kernel config"}
cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -delete >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -delete >/dev/null

cd ..

###
### build
###
%build
%{log_msg "Start of build stage"}

%{log_msg "General arch build configuration"}
rm -rf %{buildroot_unstripped} || true
mkdir -p %{buildroot_unstripped}

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

# Note we need to disable these flags for cross builds because the flags
# from redhat-rpm-config assume that host == target so target arch
# flags cause issues with the host compiler.
%if !%{with_cross}
%define build_hostcflags  %{?build_cflags}
%define build_hostldflags %{?build_ldflags}
%endif

%define make %{__make} %{?cross_opts} %{?make_opts} HOSTCFLAGS="%{?build_hostcflags}" HOSTLDFLAGS="%{?build_hostldflags}"

InitBuildVars() {
    %{log_msg "InitBuildVars for $1"}

    %{log_msg "InitBuildVars: Initialize build variables"}
    # Initialize the kernel .config file and create some variables that are
    # needed for the actual build process.

    Variant=$1

    # Pick the right kernel config file
    Config=%{name}-%{specrpmversion}-%{_target_cpu}${Variant:+-${Variant}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Variant:++${Variant}}

    KernelVer=%{specversion}-%{release}.%{_target_cpu}${Variant:++${Variant}}

    %{log_msg "InitBuildVars: Update Makefile"}
    # make sure EXTRAVERSION says what we want it to say
    # Trim the release if this is a CI build, since KERNELVERSION is limited to 64 characters
    ShortRel=$(perl -e "print \"%{release}\" =~ s/\.pr\.[0-9A-Fa-f]{32}//r")
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -${ShortRel}.%{_target_cpu}${Variant:++${Variant}}/" Makefile

    # if pre-rc1 devel kernel, must fix up PATCHLEVEL for our versioning scheme
    # if we are post rc1 this should match anyway so this won't matter
    perl -p -i -e 's/^PATCHLEVEL.*/PATCHLEVEL = %{patchlevel}/' Makefile

    %{log_msg "InitBuildVars: Copy files"}
    %{make} %{?_smp_mflags} mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp configs/x509.genkey certs/.
    %endif

%if %{with_debuginfo} == 0
    sed -i 's/^\(CONFIG_DEBUG_INFO.*\)=y/# \1 is not set/' .config
%endif

    Arch=`head -1 .config | cut -b 3-`
    %{log_msg "InitBuildVars: USING ARCH=$Arch"}

    KCFLAGS="%{?kcflags}"

    # add kpatch flags for base kernel
    %{log_msg "InitBuildVars: Configure KCFLAGS"}
    if [ "$Variant" == "" ]; then
        KCFLAGS="$KCFLAGS %{?kpatch_kcflags}"
    fi
}

BuildKernel() {
    %{log_msg "BuildKernel for $4"}
    MakeTarget=$1
    KernelImage=$2
    DoVDSO=$3
    Variant=$4
    InstallName=${5:-vmlinuz}

    %{log_msg "Setup variables"}
    DoModules=1
    if [ "$Variant" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

%if %{with_gcov}
    %{log_msg "Setup build directories"}
    # Make build directory unique for each variant, so that gcno symlinks
    # are also unique for each variant.
    if [ -n "$Variant" ]; then
        ln -s $(pwd) ../linux-%{KVERREL}-${Variant}
    fi
    %{log_msg "GCOV - continuing build in: $(pwd)"}
    pushd ../linux-%{KVERREL}${Variant:+-${Variant}}
    pwd > ../kernel${Variant:+-${Variant}}-gcov.list
%endif

    %{log_msg "Calling InitBuildVars for $Variant"}
    InitBuildVars $Variant

    %{log_msg "BUILDING A KERNEL FOR ${Variant} %{_target_cpu}..."}

    %{make} ARCH=$Arch olddefconfig >/dev/null

    %{log_msg "Setup build-ids"}
    # This ensures build-ids are unique to allow parallel debuginfo
    perl -p -i -e "s/^CONFIG_BUILD_SALT.*/CONFIG_BUILD_SALT=\"%{KVERREL}\"/" .config
    %{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} ARCH=$Arch KCFLAGS="$KCFLAGS" WITH_GCOV="%{?with_gcov}" %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    %{log_msg "Setup RPM_BUILD_ROOT directories"}
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/systemtap
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch aarch64 riscv64
    %{log_msg "Build dtb kernel"}
    %{make} ARCH=$Arch dtbs INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    %{make} ARCH=$Arch dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f -delete
%endif

    %{log_msg "Cleanup temp btf files"}
    # Remove large intermediate files we no longer need to save space
    # (-f required for zfcpdump builds that do not enable BTF)
    rm -f vmlinux.o .tmp_vmlinux.btf

    %{log_msg "Install files to RPM_BUILD_ROOT"}

    # Comment out specific config settings that may use resources not available
    # to the end user so that the packaged config file can be easily reused with
    # upstream make targets
    %if %{signkernel}%{signmodules}
      sed -i -e '/^CONFIG_SYSTEM_TRUSTED_KEYS/{
        i\# The kernel was built with
        s/^/# /
        a\# We are resetting this value to facilitate local builds
        a\CONFIG_SYSTEM_TRUSTED_KEYS=""
        }' .config
    %endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    %{log_msg "Create initrfamfs"}
    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      %{log_msg "Copy zImage.stub to RPM_BUILD_ROOT"}
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi

    %if %{signkernel}
    %{log_msg "Copy kernel for signing"}
    if [ "$KernelImage" = vmlinux ]; then
        # We can't strip and sign $KernelImage in place, because
        # we need to preserve original vmlinux for debuginfo.
        # Use a copy for signing.
        $CopyKernel $KernelImage $KernelImage.tosign
        KernelImage=$KernelImage.tosign
        CopyKernel=cp
    fi

    SignImage=$KernelImage

    %ifarch x86_64 aarch64
    %{log_msg "Sign kernel image"}
    %pesign -s -i $SignImage -o vmlinuz.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
    %endif
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
	rpm-sign --key "%{pesign_name_0}" --lkmsign $SignImage --output vmlinuz.signed
    elif [ "$DoModules" == "1" -a "%{signmodules}" == "1" ]; then
	chmod +x scripts/sign-file
	./scripts/sign-file -p sha256 certs/signing_key.pem certs/signing_key.x509 $SignImage vmlinuz.signed
    else
	mv $SignImage vmlinuz.signed
    fi
    %endif

    if [ ! -s vmlinuz.signed ]; then
	%{log_msg "pesigning failed"}
        exit 1
    fi
    mv vmlinuz.signed $SignImage
    # signkernel
    %endif

    %{log_msg "copy signed kernel"}
    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    %{log_msg "hmac sign the kernel for FIPS"}
    %{log_msg "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"}
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    (cd $RPM_BUILD_ROOT/%{image_install_path} && sha512hmac $InstallName-$KernelVer) > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	%{log_msg "Install modules in RPM_BUILD_ROOT"}
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} %{?_smp_mflags} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT %{?_smp_mflags} modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    %{log_msg "install gcov-needed files to $BUILDROOT/$BUILD/"}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    %{log_msg "Add VDSO files"}
    # add an a noop %%defattr statement 'cause rpm doesn't like empty file list files
    echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-ldsoconf.list
    if [ $DoVDSO -ne 0 ]; then
        %{make} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ -s ldconfig-kernel.conf ]; then
             install -D -m 444 ldconfig-kernel.conf \
                $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
	     echo /etc/ld.so.conf.d/kernel-$KernelVer.conf >> ../kernel${Variant:+-${Variant}}-ldsoconf.list
        fi

        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    %{log_msg "Save headers/makefiles, etc. for kernel-headers"}
    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # CONFIG_KERNEL_HEADER_TEST generates some extra files in the process of
    # testing so just delete
    find . -name *.h.s -delete
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ ! -e Module.symvers ]; then
        touch Module.symvers
    fi
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    %{log_msg "GENERATING kernel ABI metadata"}
    %compression --stdout %compression_flags < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.%compext
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.%compext $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.%compext

%if %{with_kabichk}
    %{log_msg "kABI checking is enabled in kernel SPEC file."}
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
	%{log_msg "NOTE: Cannot find reference Module.kabi file."}
    fi
%endif

%if %{with_kabidupchk}
    %{log_msg "kABI DUP checking is enabled in kernel SPEC file."}
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Variant $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        # for now, don't keep it around.
        rm $RPM_BUILD_ROOT/Module.kabi
    else
	%{log_msg "NOTE: Cannot find DUP reference Module.kabi file."}
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Variant" != "zfcpdump" -a "$Variant" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar -xvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
        tar -xvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

	%{log_msg "GENERATING DWARF-based kABI baseline dataset"}
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Variant:+.${Variant}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Variant" != "zfcpdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar -xvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/stablelists
            tar -xvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/stablelists

	    %{log_msg "GENERATING DWARF-based kABI dataset"}
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/stablelists/kabi-current/kabi_stablelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :

	    %{log_msg "kABI DWARF-based comparison report"}
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Variant:+.${Variant}}.tmp" || :
	    %{log_msg "End of kABI DWARF-based comparison report"}
        else
	    %{log_msg "Baseline dataset for kABI DWARF-BASED comparison report not found"}
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

   %{log_msg "Cleanup Makefiles/Kconfig files"}
    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py

%ifarch s390x
    # CONFIG_EXPOLINE_EXTERN=y produces arch/s390/lib/expoline/expoline.o
    # which is needed during external module build.
    %{log_msg "Copy expoline.o"}
    if [ -f arch/s390/lib/expoline/expoline.o ]; then
      cp -a --parents arch/s390/lib/expoline/expoline.o $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%endif

    %{log_msg "Copy additional files for make targets"}
    # Files for 'make scripts' to succeed with kernel-devel.
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/security/selinux/include
    cp -a --parents security/selinux/include/classmap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents security/selinux/include/initial_sid_to_string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/include/tools
    cp -a --parents tools/include/tools/be_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # Files for 'make prepare' to succeed with kernel-devel.
    cp -a --parents tools/include/linux/compiler* $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux/types.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/build/Build.include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/build/fixdep.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/sync-check.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/bpf/resolve_btfids $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp --parents security/selinux/include/policycap_names.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents security/selinux/include/policycap.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    cp -a --parents tools/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/uapi/linux $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/include/vdso $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/scripts/utilities.mak $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/subcmd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/*.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/*.[ch] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/objtool/include/objtool/*.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/lib/bpf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp --parents tools/lib/bpf/Build $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -f tools/objtool/fixdep ]; then
      cp -a tools/objtool/fixdep $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    if [ -d tools/arch/%{asmarch}/include ]; then
      cp -a --parents tools/arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    # Cross-reference from include/perf/events/sof.h
    cp -a sound/soc/sof/sof-audio.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/sound/soc/sof
%ifarch i686 x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents scripts/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents scripts/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/

    cp -a --parents tools/arch/x86/include/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/include/uapi/asm $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/lib $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/lib/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/arch/x86/tools/gen-insn-attr-x86.awk $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a --parents tools/objtool/arch/x86/ $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%endif
    %{log_msg "Clean up intermediate tools files"}
    # Clean up intermediate tools files
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools \( -iname "*.o" -o -iname "*.cmd" \) -exec rm -f {} +

    # Make sure the Makefile, version.h, and auto.conf have a matching
    # timestamp so that external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h \
        $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    %{log_msg "Copy additional files for kernel-debuginfo rpm"}
    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    # (use mv + symlink instead of cp to reduce disk space requirements)
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    mv vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    ln -s $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux vmlinux
    if [ -n "%{?vmlinux_decompressor}" ]; then
	    eu-readelf -n  %{vmlinux_decompressor} | grep "Build ID" | awk '{print $NF}' > vmlinux.decompressor.id
	    # Without build-id the build will fail. But for s390 the build-id
	    # wasn't added before 5.11. In case it is missing prefer not
	    # packaging the debuginfo over a build failure.
	    if [ -s vmlinux.decompressor.id ]; then
		    cp vmlinux.decompressor.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.decompressor.id
		    cp %{vmlinux_decompressor} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux.decompressor
	    fi
    fi

    # build and copy the vmlinux-gdb plugin files into kernel-debuginfo
    %{make} ARCH=$Arch %{?_smp_mflags} scripts_gdb
    cp -a --parents scripts/gdb/{,linux/}*.py $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    # this should be a relative symlink (Kbuild creates an absolute one)
    ln -s scripts/gdb/vmlinux-gdb.py $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/vmlinux-gdb.py
    %py_byte_compile %{python3} $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer/scripts/gdb
%endif

    %{log_msg "Create modnames"}
    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.
    %{log_msg "Generate a list of modules for block and networking"}
    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'

    %{log_msg "detect missing or incorrect license tags"}
    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1


    if [ $DoModules -eq 0 ]; then
        %{log_msg "Create empty files for RPM packaging"}
        # Ensure important files/directories exist to let the packaging succeed
        echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-modules-core.list
        echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-modules.list
        echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-modules-extra.list
        echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-modules-internal.list
        echo '%%defattr(-,-,-)' > ../kernel${Variant:+-${Variant}}-modules-partner.list
        mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel
        # Add files usually created by make modules, needed to prevent errors
        # thrown by depmod during package installation
        touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.order
        touch $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.builtin
    fi

    # Copy the System.map file for depmod to use
    cp System.map $RPM_BUILD_ROOT/.

    if [[ "$Variant" == "rt" || "$Variant" == "rt-debug" || "$Variant" == "rt-64k" || "$Variant" == "rt-64k-debug" || "$Variant" == "automotive" || "$Variant" == "automotive-debug" ]]; then
	%{log_msg "Skipping efiuki build"}
    else
%if %{with_efiuki}
        %{log_msg "Setup the EFI UKI kernel"}

        # RHEL/CentOS specific .SBAT entries
%if 0%{?centos}
        SBATsuffix="centos"
%else
        SBATsuffix="rhel"
%endif
        SBAT=$(cat <<- EOF
	linux,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	linux.$SBATsuffix,1,Red Hat,linux,$KernelVer,mailto:secalert@redhat.com
	kernel-uki-virt.$SBATsuffix,1,Red Hat,kernel-uki-virt,$KernelVer,mailto:secalert@redhat.com
	EOF
	)

	KernelUnifiedImageDir="$RPM_BUILD_ROOT/lib/modules/$KernelVer"
    	KernelUnifiedImage="$KernelUnifiedImageDir/$InstallName-virt.efi"

    	mkdir -p $KernelUnifiedImageDir

    	dracut --conf=%{SOURCE86} \
           --confdir=$(mktemp -d) \
           --verbose \
           --kver "$KernelVer" \
           --kmoddir "$RPM_BUILD_ROOT/lib/modules/$KernelVer/" \
           --logfile=$(mktemp) \
           --uefi \
%if 0%{?rhel} && !0%{?eln}
           --sbat "$SBAT" \
%endif
           --kernel-image $(realpath $KernelImage) \
           --kernel-cmdline 'console=tty0 console=ttyS0' \
	   $KernelUnifiedImage

  KernelAddonsDirOut="$KernelUnifiedImage.extra.d"
  mkdir -p $KernelAddonsDirOut
  python3 %{SOURCE151} %{SOURCE152} $KernelAddonsDirOut virt %{primary_target} %{_target_cpu}

%if %{signkernel}
	%{log_msg "Sign the EFI UKI kernel"}
%if 0%{?fedora}%{?eln}
        %pesign -s -i $KernelUnifiedImage -o $KernelUnifiedImage.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
%else
%if 0%{?centos}
        UKI_secureboot_name=centossecureboot204
%else
        UKI_secureboot_name=redhatsecureboot504
%endif
        UKI_secureboot_cert=%{_datadir}/pki/sb-certs/secureboot-uki-virt-%{_arch}.cer

        %pesign -s -i $KernelUnifiedImage -o $KernelUnifiedImage.signed -a %{secureboot_ca_0} -c $UKI_secureboot_cert -n $UKI_secureboot_name
# 0%{?fedora}%{?eln}
%endif
        if [ ! -s $KernelUnifiedImage.signed ]; then
            echo "pesigning failed"
            exit 1
        fi
        mv $KernelUnifiedImage.signed $KernelUnifiedImage

      for addon in "$KernelAddonsDirOut"/*; do
        %pesign -s -i $addon -o $addon.signed -a %{secureboot_ca_0} -c %{secureboot_key_0} -n %{pesign_name_0}
        rm -f $addon
        mv $addon.signed $addon
      done

# signkernel
%endif

    # hmac sign the UKI for FIPS
    KernelUnifiedImageHMAC="$KernelUnifiedImageDir/.$InstallName-virt.efi.hmac"
    %{log_msg "hmac sign the UKI for FIPS"}
    %{log_msg "Creating hmac file: $KernelUnifiedImageHMAC"}
    (cd $KernelUnifiedImageDir && sha512hmac $InstallName-virt.efi) > $KernelUnifiedImageHMAC;

# with_efiuki
%endif
	:  # in case of empty block
    fi # "$Variant" == "rt" || "$Variant" == "rt-debug" || "$Variant" == "automotive" || "$Variant" == "automotive-debug"


    #
    # Generate the modules files lists
    #
    move_kmod_list()
    {
        local module_list="$1"
        local subdir_name="$2"

        mkdir -p "$RPM_BUILD_ROOT/lib/modules/$KernelVer/$subdir_name"

        set +x
        while read -r kmod; do
            local target_file="$RPM_BUILD_ROOT/lib/modules/$KernelVer/$subdir_name/$kmod"
            local target_dir="${target_file%/*}"
            mkdir -p "$target_dir"
            mv "$RPM_BUILD_ROOT/lib/modules/$KernelVer/kernel/$kmod" "$target_dir"
        done < <(sed -e 's|^kernel/||' "$module_list")
        set -x
    }

    create_module_file_list()
    {
        # subdirectory within /lib/modules/$KernelVer where kmods should go
        local module_subdir="$1"
        # kmod list with relative paths produced by filtermods.py
        local relative_kmod_list="$2"
        # list with absolute paths to kmods and other files to be included
        local absolute_file_list="$3"
        # if 1, this adds also all kmod directories to absolute_file_list
        local add_all_dirs="$4"
        local run_mod_deny="$5"

        if [ "$module_subdir" != "kernel" ]; then
            # move kmods into subdirs if needed (internal, partner, extra,..)
            move_kmod_list $relative_kmod_list $module_subdir
        fi

        # make kmod paths absolute
        sed -e 's|^kernel/|/lib/modules/'$KernelVer'/'$module_subdir'/|' $relative_kmod_list > $absolute_file_list

	if [ "$run_mod_deny" -eq 1 ]; then
            # run deny-mod script, this adds blacklist-* files to absolute_file_list
            %{SOURCE20} "$RPM_BUILD_ROOT" lib/modules/$KernelVer $absolute_file_list
	fi

%if %{zipmodules}
        # deny-mod script works with kmods as they are now (not compressed),
        # but if they will be we need to add compext to all
        sed -i %{?zipsed} $absolute_file_list
%endif
        # add also dir for the case when there are no kmods
        # "kernel" subdir is covered in %files section, skip it here
        if [ "$module_subdir" != "kernel" ]; then
                echo "%dir /lib/modules/$KernelVer/$module_subdir" >> $absolute_file_list
        fi

        if [ "$add_all_dirs" -eq 1 ]; then
            (cd $RPM_BUILD_ROOT; find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n) > ../module-dirs.list
            sed -e 's|^lib|%dir /lib|' ../module-dirs.list >> $absolute_file_list
        fi
    }

    if [ $DoModules -eq 1 ]; then
        # save modules.dep for debugging
        cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.dep ../

        %{log_msg "Create module list files for all kernel variants"}
        variants_param=""
        if [[ "$Variant" == "rt" || "$Variant" == "rt-debug" ]]; then
            variants_param="-r rt"
        fi
        if [[ "$Variant" == "rt-64k" || "$Variant" == "rt-64k-debug" ]]; then
            variants_param="-r rt-64k"
        fi
        if [[ "$Variant" == "automotive" || "$Variant" == "automotive-debug" ]]; then
            variants_param="-r automotive"
        fi
        # this creates ../modules-*.list output, where each kmod path is as it
        # appears in modules.dep (relative to lib/modules/$KernelVer)
        ret=0
        %{SOURCE22} -l "../filtermods-$KernelVer.log" sort -d $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.dep -c configs/def_variants.yaml $variants_param -o .. || ret=$?
        if [ $ret -ne 0 ]; then
            echo "8< --- filtermods-$KernelVer.log ---"
            cat "../filtermods-$KernelVer.log"
            echo "--- filtermods-$KernelVer.log --- >8"

            echo "8< --- modules.dep ---"
            cat $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.dep
            echo "--- modules.dep --- >8"
            exit 1
        fi

        create_module_file_list "kernel" ../modules-core.list ../kernel${Variant:+-${Variant}}-modules-core.list 1 0
        create_module_file_list "kernel" ../modules.list ../kernel${Variant:+-${Variant}}-modules.list 0 0
        create_module_file_list "internal" ../modules-internal.list ../kernel${Variant:+-${Variant}}-modules-internal.list 0 1
        create_module_file_list "kernel" ../modules-extra.list ../kernel${Variant:+-${Variant}}-modules-extra.list 0 1
        if [[ "$Variant" == "rt" || "$Variant" == "rt-debug" ]]; then
            create_module_file_list "kvm" ../modules-rt-kvm.list ../kernel${Variant:+-${Variant}}-modules-rt-kvm.list 0 1
        fi
        if [[ "$Variant" == "rt-64k" || "$Variant" == "rt-64k-debug" ]]; then
            create_module_file_list "kvm" ../modules-rt-64k-kvm.list ../kernel${Variant:+-${Variant}}-modules-rt-64k-kvm.list 0 1
        fi
%if 0%{!?fedora:1}
        create_module_file_list "partner" ../modules-partner.list ../kernel${Variant:+-${Variant}}-modules-partner.list 1 1
%endif
    fi # $DoModules -eq 1

    remove_depmod_files()
    {
        # remove files that will be auto generated by depmod at rpm -i time
        pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
            # in case below list needs to be extended, remember to add a
            # matching ghost entry in the files section as well
            rm -f modules.{alias,alias.bin,builtin.alias.bin,builtin.bin} \
                  modules.{dep,dep.bin,devname,softdep,symbols,symbols.bin,weakdep}
        popd
    }

    # Cleanup
    %{log_msg "Cleanup build files"}
    rm -f $RPM_BUILD_ROOT/System.map
    %{log_msg "Remove depmod files"}
    remove_depmod_files

%if %{with_cross}
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build M=scripts clean
    make -C $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/bpf/resolve_btfids clean
    sed -i 's/REBUILD_SCRIPTS_FOR_CROSS:=0/REBUILD_SCRIPTS_FOR_CROSS:=1/' $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile
%endif

    # Move the devel headers out of the root file system
    %{log_msg "Move the devel headers to RPM_BUILD_ROOT"}
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

%if %{with_debuginfo}
    # Generate vmlinux.h and put it to kernel-devel path
    # zfcpdump build does not have btf anymore
    if [ "$Variant" != "zfcpdump" ]; then
	%{log_msg "Build the bootstrap bpftool to generate vmlinux.h"}
        # Build the bootstrap bpftool to generate vmlinux.h
        export BPFBOOTSTRAP_CFLAGS=$(echo "%{__global_compiler_flags}" | sed -r "s/\-specs=[^\ ]+\/redhat-annobin-cc1//")
        export BPFBOOTSTRAP_LDFLAGS=$(echo "%{__global_ldflags}" | sed -r "s/\-specs=[^\ ]+\/redhat-annobin-cc1//")
        CFLAGS="" LDFLAGS="" make EXTRA_CFLAGS="${BPFBOOTSTRAP_CFLAGS}" EXTRA_CXXFLAGS="${BPFBOOTSTRAP_CFLAGS}" EXTRA_LDFLAGS="${BPFBOOTSTRAP_LDFLAGS}" %{?make_opts} %{?clang_make_opts} V=1 -C tools/bpf/bpftool bootstrap

        tools/bpf/bpftool/bootstrap/bpftool btf dump file vmlinux format c > $RPM_BUILD_ROOT/$DevelDir/vmlinux.h
    fi
%endif

    %{log_msg "Cleanup kernel-devel and kernel-debuginfo files"}
    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -delete
    # prune junk from kernel-debuginfo
    find $RPM_BUILD_ROOT/usr/src/kernels -name "*.mod.c" -delete

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    %{log_msg "Install certs"}
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
%if %{signkernel}
    install -m 0644 %{secureboot_ca_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
    %ifarch s390x ppc64le
    if [ -x /usr/bin/rpm-sign ]; then
        install -m 0644 %{secureboot_key_0} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
    fi
    %endif
%endif

%if 0%{?rhel}
    # Red Hat IMA code-signing cert, which is used to authenticate package files
    install -m 0644 %{ima_signing_cert} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{ima_cert_name}
%endif

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
        # Save the signing keys so we can sign the modules in __modsign_install_post
        cp certs/signing_key.pem certs/signing_key.pem.sign${Variant:++${Variant}}
        cp certs/signing_key.x509 certs/signing_key.x509.sign${Variant:++${Variant}}
        %ifarch s390x ppc64le
        if [ ! -x /usr/bin/rpm-sign ]; then
            install -m 0644 certs/signing_key.x509.sign${Variant:++${Variant}} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer
            openssl x509 -in certs/signing_key.pem.sign${Variant:++${Variant}} -outform der -out $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
            chmod 0644 $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/%{signing_key_filename}
        fi
        %endif
    fi
%endif

%if %{with_ipaclones}
    %{log_msg "install IPA clones"}
    MAXPROCS=$(echo %{?_smp_mflags} | sed -n 's/-j\s*\([0-9]\+\)/\1/p')
    if [ -z "$MAXPROCS" ]; then
        MAXPROCS=1
    fi
    if [ "$Variant" == "" ]; then
        mkdir -p $RPM_BUILD_ROOT/$DevelDir-ipaclones
        find . -name '*.ipa-clones' | xargs -i{} -r -n 1 -P $MAXPROCS install -m 644 -D "{}" "$RPM_BUILD_ROOT/$DevelDir-ipaclones/{}"
    fi
%endif

%if %{with_gcov}
    popd
%endif
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}

%if %{with_debug}
%if %{with_realtime}
BuildKernel %make_target %kernel_image %{_use_vdso} rt-debug
%endif

%if %{with_realtime_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} rt-64k-debug
%endif

%if %{with_automotive}
BuildKernel %make_target %kernel_image %{_use_vdso} automotive-debug
%endif

%if %{with_arm64_16k}
BuildKernel %make_target %kernel_image %{_use_vdso} 16k-debug
%endif

%if %{with_arm64_64k}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k-debug
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{_use_vdso} debug
%endif
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{_use_vdso} zfcpdump
%endif

%if %{with_arm64_16k_base}
BuildKernel %make_target %kernel_image %{_use_vdso} 16k
%endif

%if %{with_arm64_64k_base}
BuildKernel %make_target %kernel_image %{_use_vdso} 64k
%endif

%if %{with_realtime_base}
BuildKernel %make_target %kernel_image %{_use_vdso} rt
%endif

%if %{with_realtime_arm64_64k_base}
BuildKernel %make_target %kernel_image %{_use_vdso} rt-64k
%endif

%if %{with_automotive_base}
BuildKernel %make_target %kernel_image %{_use_vdso} automotive
%endif

%if %{with_up_base}
BuildKernel %make_target %kernel_image %{_use_vdso}
%endif

%ifnarch noarch i686 %{nobuildarches}
%if !%{with_debug} && !%{with_zfcpdump} && !%{with_up} && !%{with_arm64_16k} && !%{with_arm64_64k} && !%{with_realtime} && !%{with_realtime_arm64_64k} && !%{with_automotive}
# If only building the user space tools, then initialize the build environment
# and some variables so that the various userspace tools can be built.
%{log_msg "Initialize userspace tools build environment"}
InitBuildVars
# Some tests build also modules, and need Module.symvers
if ! [[ -e Module.symvers ]] && [[ -f $DevelDir/Module.symvers ]]; then
    %{log_msg "Found Module.symvers in DevelDir, copying to ."}
    cp "$DevelDir/Module.symvers" .
fi
%endif
%endif

%ifarch aarch64
%global perf_build_extra_opts CORESIGHT=1
%endif
%global perf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_CXXFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags} -Wl,-E" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 LIBBPF_DYNAMIC=1 LIBTRACEEVENT_DYNAMIC=1 %{?perf_build_extra_opts} prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
%{log_msg "Build perf"}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%if %{with_libperf}
%global libperf_make \
  %{__make} %{?make_opts} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{?cross_opts} -C tools/lib/perf V=1
  %{log_msg "build libperf"}
%{libperf_make} DESTDIR=$RPM_BUILD_ROOT
%endif

%global tools_make \
  CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" EXTRA_CFLAGS="${RPM_OPT_FLAGS}" %{make} %{?make_opts}

%ifarch %{cpupowerarchs}
    # link against in-tree libcpupower for idle state support
    %global rtla_make %{tools_make} LDFLAGS="%{__global_ldflags} -L../../power/cpupower" INCLUDES="-I../../power/cpupower/lib"
%else
    %global rtla_make %{tools_make}
%endif

%if %{with_tools}

%if %{with_ynl}
pushd tools/net/ynl
export PIP_CONFIG_FILE=/tmp/pip.config
cat <<EOF > $PIP_CONFIG_FILE
[install]
no-index = true
no-build-isolation = false
EOF
%{tools_make} %{?_smp_mflags} DESTDIR=$RPM_BUILD_ROOT install
popd
%endif

%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{log_msg "build cpupower"}
%{tools_make} %{?_smp_mflags} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{log_msg "build centrino-decode powernow-k8-decode"}
    %{tools_make} %{?_smp_mflags} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{log_msg "build x86_energy_perf_policy"}
   %{tools_make}
   popd
   pushd tools/power/x86/turbostat
   %{log_msg "build turbostat"}
   %{tools_make}
   popd
   pushd tools/power/x86/intel-speed-select
   %{log_msg "build intel-speed-select"}
   %{tools_make}
   popd
   pushd tools/arch/x86/intel_sdsi
   %{log_msg "build intel_sdsi"}
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}"
   popd
%endif
%endif
pushd tools/thermal/tmon/
%{log_msg "build tmon"}
%{tools_make}
popd
pushd tools/bootconfig/
%{log_msg "build bootconfig"}
%{tools_make}
popd
pushd tools/iio/
%{log_msg "build iio"}
%{tools_make}
popd
pushd tools/gpio/
%{log_msg "build gpio"}
%{tools_make}
popd
# build VM tools
pushd tools/mm/
%{log_msg "build slabinfo page_owner_sort"}
%{tools_make} slabinfo page_owner_sort
popd
pushd tools/verification/rv/
%{log_msg "build rv"}
%{tools_make}
popd
pushd tools/tracing/rtla
%{log_msg "build rtla"}
%{rtla_make}
popd
%endif

if [ -f $DevelDir/vmlinux.h ]; then
  RPM_VMLINUX_H=$DevelDir/vmlinux.h
fi
echo "${RPM_VMLINUX_H}" > ../vmlinux_h_path

%if %{with_selftests}
%{log_msg "start build selftests"}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
%{log_msg "install headers for selftests"}
%{make} %{?_smp_mflags} headers_install

# If we re building only tools without kernel, we need to generate config
# headers and prepare tree for modules building. The modules_prepare target
# will cover both.
if [ ! -f include/generated/autoconf.h ]; then
   %{log_msg "modules_prepare for selftests"}
   %{make} %{?_smp_mflags} modules_prepare
fi

%{log_msg "build samples/bpf"}
%{make} %{?_smp_mflags} EXTRA_CXXFLAGS="${RPM_OPT_FLAGS}" ARCH=$Arch V=1 M=samples/bpf/ VMLINUX_H="${RPM_VMLINUX_H}" || true

pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%if %{selftests_must_build}
  force_targets="FORCE_TARGETS=1"
%else
  force_targets=""
%endif

%{log_msg "main selftests compile"}

# Some selftests (especially bpf) do not build with source fortification.
# Since selftests are not shipped, disable source fortification for them.
%global _fortify_level_bak %{_fortify_level}
%undefine _fortify_level
export CFLAGS="%{build_cflags}"

TARGETS="bpf cgroup mm net net/forwarding net/mptcp net/netfilter tc-testing memfd drivers/net/bonding iommu cachestat"
%{make} %{?_smp_mflags} EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_CXXFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" ARCH=$Arch V=1 TARGETS="$TARGETS" SKIP_TARGETS="" $force_targets VMLINUX_H="${RPM_VMLINUX_H}"

# Restore the original level of source fortification
%define _fortify_level %{_fortify_level_bak}
export CFLAGS="%{build_cflags}"

%ifarch %{klptestarches}
	# kernel livepatching selftest test_modules will build against
	# /lib/modules/$(shell uname -r)/build tree unless KDIR is set
	export KDIR=$(realpath $(pwd)/../../..)
	%{make} %{?_smp_mflags} ARCH=$Arch V=1 TARGETS="livepatch" SKIP_TARGETS="" $force_targets VMLINUX_H="${RPM_VMLINUX_H}" && TARGETS="${TARGETS} livepatch" || true
%endif

# We must install all the targets in a single step as each `make install`
# command overrides the kselftest-list.txt file.
%{make} ARCH=$Arch TARGETS="${TARGETS}" SKIP_TARGETS="" $force_targets INSTALL_PATH=%{buildroot}%{_libexecdir}/kselftests install

# 'make install' for bpf is broken and upstream refuses to fix it.
# Install the needed files manually.
%{log_msg "install selftests"}
for dir in bpf bpf/no_alu32 bpf/cpuv4 bpf/progs; do
	# In ARK, the rpm build continues even if some of the selftests
	# cannot be built. It's not always possible to build selftests,
	# as upstream sometimes dependens on too new llvm version or has
	# other issues. If something did not get built, just skip it.
	test -d $dir || continue
	mkdir -p %{buildroot}%{_libexecdir}/kselftests/$dir
	find $dir -maxdepth 1 \( -type f  -o -type l \) \
        \( -executable -o -name '*.py' -o -name settings -o \
		-name 'btf_dump_test_case_*.c' -o -name '*.ko' -o \
		-name '*.o' -exec sh -c 'readelf -h "{}" | grep -q "^  Machine:.*BPF"' \; \) -print0 | \
	xargs -0 cp -t %{buildroot}%{_libexecdir}/kselftests/$dir || true
done

%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs-no_alu32"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/test_progs-cpuv4"

# The urandom_read binary doesn't pass the check-rpaths check and upstream
# refuses to fix it. So, we save it to buildroot_unstripped and delete it so it
# will be hidden from check-rpaths and will automatically get restored later.
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/urandom_read"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/no_alu32/urandom_read"
%buildroot_save_unstripped "usr/libexec/kselftests/bpf/cpuv4/urandom_read"
rm -f %{buildroot}/usr/libexec/kselftests/bpf/urandom_read
rm -f %{buildroot}/usr/libexec/kselftests/bpf/no_alu32/urandom_read
rm -f %{buildroot}/usr/libexec/kselftests/bpf/cpuv4/urandom_read

popd
%{log_msg "end build selftests"}
%endif

%if %{with_doc}
%{log_msg "start install docs"}
# Make the HTML pages.
%{log_msg "build html docs"}
%{__make} PYTHON=/usr/bin/python3 htmldocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%{log_msg "end install docs"}
%endif

# Module signing (modsign)
#
# This must be run _after_ find-debuginfo.sh runs, otherwise that will strip
# the signature off of the modules.
#
# Don't sign modules for the zfcpdump variant as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    %{log_msg "Signing kernel modules ..."} \
    modules_dirs="$(shopt -s nullglob; echo $RPM_BUILD_ROOT/lib/modules/%{KVERREL}*)" \
    for modules_dir in $modules_dirs; do \
        variant_suffix="${modules_dir#$RPM_BUILD_ROOT/lib/modules/%{KVERREL}}" \
        [ "$variant_suffix" == "+zfcpdump" ] && continue \
	%{log_msg "Signing modules for %{KVERREL}${variant_suffix}"} \
        %{modsign_cmd} certs/signing_key.pem.sign${variant_suffix} certs/signing_key.x509.sign${variant_suffix} $modules_dir/ \
    done \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    %{log_msg "Compressing kernel modules ..."} \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs -n 16 -P${RPM_BUILD_NCPUS} -r %compression %compression_flags; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch %{nobuildarches}
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%endif

%endif

# We don't want to package debuginfo for self-tests and samples but
# we have to delete them to avoid an error messages about unpackaged
# files.
# Delete the debuginfo for kernel-devel files
%define __remove_unwanted_dbginfo_install_post \
  if [ "%{with_selftests}" -ne "0" ]; then \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/ksamples; \
    rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/libexec/kselftests; \
  fi \
  rm -rf $RPM_BUILD_ROOT/usr/lib/debug/usr/src; \
%{nil}

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__remove_unwanted_dbginfo_install_post}\
  %{__restore_unstripped_root_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

# re-define RPM_VMLINUX_H, because it doesn't carry over from %build
RPM_VMLINUX_H="$(cat ../vmlinux_h_path)"

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}

# copy the source over
mkdir -p $docdir
tar -h -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir
cat %{SOURCE2} | xz > $docdir/kernel.changelog.xz
chmod 0644 $docdir/kernel.changelog.xz

# with_doc
%endif

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
%{__make} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

%endif

%if %{with_cross_headers}
HDR_ARCH_LIST='arm64 powerpc s390 x86 riscv'
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers

for arch in $HDR_ARCH_LIST; do
	mkdir $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}
	%{__make} ARCH=${arch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch} headers_install
done

find $RPM_BUILD_ROOT/usr/tmp-headers \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) -delete

# Copy all the architectures we care about to their respective asm directories
for arch in $HDR_ARCH_LIST ; do
	mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
	mv $RPM_BUILD_ROOT/usr/tmp-headers/arch-${arch}/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_stablelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar -xvf %{SOURCE300} -C $INSTALL_KABI_PATH
# with_kernel_abi_stablelists
%endif

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/perf/examples
rm -rf %{buildroot}/usr/lib/perf/include

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man

# remove any tracevent files, eg. its plugins still gets built and installed,
# even if we build against system's libtracevent during perf build (by setting
# LIBTRACEEVENT_DYNAMIC=1 above in perf_make macro). Those files should already
# ship with libtraceevent package.
rm -rf %{buildroot}%{_libdir}/traceevent
%endif

%if %{with_libperf}
%{libperf_make} DESTDIR=%{buildroot} prefix=%{_prefix} libdir=%{_libdir} install install_headers
# This is installed on some arches and we don't want to ship it
rm -rf %{buildroot}%{_libdir}/libperf.a
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/intel-speed-select
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/arch/x86/intel_sdsi
   %{tools_make} CFLAGS="${RPM_OPT_FLAGS}" DESTDIR=%{buildroot} install
   popd
%endif
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/bootconfig
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
install -m644 -D %{SOURCE2002} %{buildroot}%{_sysconfdir}/logrotate.d/kvm_stat
pushd tools/kvm/kvm_stat
%{__make} INSTALL_ROOT=%{buildroot} install-tools
%{__make} INSTALL_ROOT=%{buildroot} install-man
install -m644 -D kvm_stat.service %{buildroot}%{_unitdir}/kvm_stat.service
popd
# install VM tools
pushd tools/mm/
install -m755 slabinfo %{buildroot}%{_bindir}/slabinfo
install -m755 page_owner_sort %{buildroot}%{_bindir}/page_owner_sort
popd
pushd tools/verification/rv/
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/tracing/rtla/
%{tools_make} DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_bindir}/hwnoise
rm -f %{buildroot}%{_bindir}/osnoise
rm -f %{buildroot}%{_bindir}/timerlat
(cd %{buildroot}

        ln -sf rtla ./%{_bindir}/hwnoise
        ln -sf rtla ./%{_bindir}/osnoise
        ln -sf rtla ./%{_bindir}/timerlat
)
popd
%endif

%if %{with_selftests}
pushd samples
install -d %{buildroot}%{_libexecdir}/ksamples
# install bpf samples
pushd bpf
install -d %{buildroot}%{_libexecdir}/ksamples/bpf
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/bpf \;
install -m755 *.sh %{buildroot}%{_libexecdir}/ksamples/bpf
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/ksamples/bpf/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/ksamples/bpf || true
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/ksamples/bpf
popd
# install pktgen samples
pushd pktgen
install -d %{buildroot}%{_libexecdir}/ksamples/pktgen
find . -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
find . -type f ! -executable -exec install -m644 {} %{buildroot}%{_libexecdir}/ksamples/pktgen/{} \;
popd
popd
# install mm selftests
pushd tools/testing/selftests/mm
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/mm/{} \;
popd
# install cgroup selftests
pushd tools/testing/selftests/cgroup
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/cgroup/{} \;
popd
# install drivers/net/mlxsw selftests
pushd tools/testing/selftests/drivers/net/mlxsw
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/mlxsw/{} \;
popd
# install drivers/net/netdevsim selftests
pushd tools/testing/selftests/drivers/net/netdevsim
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/netdevsim/{} \;
popd
# install drivers/net/bonding selftests
pushd tools/testing/selftests/drivers/net/bonding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/drivers/net/bonding/{} \;
popd
# install net/forwarding selftests
pushd tools/testing/selftests/net/forwarding
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/forwarding/{} \;
popd
# install net/mptcp selftests
pushd tools/testing/selftests/net/mptcp
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/mptcp/{} \;
popd
# install tc-testing selftests
pushd tools/testing/selftests/tc-testing
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/tc-testing/{} \;
popd
# install livepatch selftests
pushd tools/testing/selftests/livepatch
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/livepatch/{} \;
popd
# install net/netfilter selftests
pushd tools/testing/selftests/net/netfilter
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/net/netfilter/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/net/netfilter/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/net/netfilter/{} \;
popd

# install memfd selftests
pushd tools/testing/selftests/memfd
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/memfd/{} \;
popd
# install iommu selftests
pushd tools/testing/selftests/iommu
find -type d -exec install -d %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
find -type f -executable -exec install -D -m755 {} %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
find -type f ! -executable -exec install -D -m644 {} %{buildroot}%{_libexecdir}/kselftests/iommu/{} \;
popd
%endif

###
### clean
###

###
### scripts
###

%if %{with_tools}
%post -n %{package_name}-tools-libs
/sbin/ldconfig

%postun -n %{package_name}-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
# Note we don't run hardlink if ostree is in use, as ostree is
# a far more sophisticated hardlink implementation.
# https://github.com/projectatomic/rpm-ostree/commit/58a79056a889be8814aa51f507b2c7a4dccee526
#
# The deletion of *.hardlink-temporary files is a temporary workaround
# for this bug in the hardlink binary (fixed in util-linux 2.38):
# https://github.com/util-linux/util-linux/issues/1602
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/bin/hardlink -a ! -e /run/ostree-booted ] \
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f > /dev/null\
     done;\
     /usr/bin/find /usr/src/kernels -type f -name '*.hardlink-temporary' -delete\
    )\
fi\
%if %{with_cross}\
    echo "Building scripts and resolve_btfids"\
    env --unset=ARCH make -C /usr/src/kernels/%{KVERREL}%{?1:+%{1}} prepare_after_cross\
%endif\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-internal package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_internal_post [<subpackage>]
#
%define kernel_modules_internal_post() \
%{expand:%%post %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-internal}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-partner package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_partner_post [<subpackage>]
#
%define kernel_modules_partner_post() \
%{expand:%%post %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-partner}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

%if %{with_realtime} || %{with_realtime_arm64_64k}
#
# This macro defines a %%post script for a kernel*-kvm package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_kvm_post [<subpackage>]
#
%define kernel_kvm_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}kvm}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}
%endif

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
if [ ! -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?1:+%{1}} ]; then\
	mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
	touch %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
fi\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%posttrans %{?1:%{1}-}modules}\
if [ -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}} ]; then\
	rm -f %{_localstatedir}/lib/rpm-state/%{name}/need_to_run_dracut_%{KVERREL}%{?1:+%{1}}\
	echo "Running: dracut -f --kver %{KVERREL}%{?1:+%{1}}"\
	dracut -f --kver "%{KVERREL}%{?1:+%{1}}" || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-core package.
#	%%kernel_modules_core_post [<subpackage>]
#
%define kernel_modules_core_post() \
%{expand:%%posttrans %{?1:%{1}-}modules-core}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [-v <subpackage>] [-u uki-suffix]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans(v:u:) \
%{expand:%%posttrans %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
%if 0%{!?fedora:1}\
%if !%{with_automotive}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%endif\
%endif\
rm -f %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
/bin/kernel-install add %{KVERREL}%{?-v:+%{-v*}} /lib/modules/%{KVERREL}%{?-v:+%{-v*}}/vmlinuz%{?-u:-%{-u*}.efi} || exit $?\
if [[ ! -e "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.%compext" ]]; then\
    cp "/lib/modules/%{KVERREL}%{?-v:+%{-v*}}/symvers.%compext" "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.%compext"\
    if command -v restorecon &>/dev/null; then\
        restorecon "/boot/symvers-%{KVERREL}%{?-v:+%{-v*}}.%compext"\
    fi\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_core_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_modules_internal_post %{?-v*}}\
%if 0%{!?fedora:1}\
%{expand:%%kernel_modules_partner_post %{?-v*}}\
%endif\
%{expand:%%kernel_variant_posttrans %{?-v*:-v %{-v*}}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
mkdir -p %{_localstatedir}/lib/rpm-state/%{name}\
touch %{_localstatedir}/lib/rpm-state/%{name}/installing_core_%{KVERREL}%{?-v:+%{-v*}}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun [-v <subpackage>] -u [uki-suffix]
#
%define kernel_variant_preun(v:u:) \
%{expand:%%preun %{?-v:%{-v*}-}%{!?-u*:core}%{?-u*:uki-%{-u*}}}\
/bin/kernel-install remove %{KVERREL}%{?-v:+%{-v*}} || exit $?\
%if !%{with_automotive}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?-v:+%{-v*}} || exit $?\
fi\
%endif\
%{nil}

%if %{with_up_base} && %{with_efiuki}
%kernel_variant_posttrans -u virt
%kernel_variant_preun -u virt
%endif

%if %{with_up_base}
%kernel_variant_preun
%kernel_variant_post
%endif

%if %{with_zfcpdump}
%kernel_variant_preun -v zfcpdump
%kernel_variant_post -v zfcpdump
%endif

%if %{with_up} && %{with_debug} && %{with_efiuki}
%kernel_variant_posttrans -v debug -u virt
%kernel_variant_preun -v debug -u virt
%endif

%if %{with_up} && %{with_debug}
%kernel_variant_preun -v debug
%kernel_variant_post -v debug
%endif

%if %{with_arm64_16k_base}
%kernel_variant_preun -v 16k
%kernel_variant_post -v 16k
%endif

%if %{with_debug} && %{with_arm64_16k}
%kernel_variant_preun -v 16k-debug
%kernel_variant_post -v 16k-debug
%endif

%if %{with_arm64_16k} && %{with_debug} && %{with_efiuki}
%kernel_variant_posttrans -v 16k-debug -u virt
%kernel_variant_preun -v 16k-debug -u virt
%endif

%if %{with_arm64_16k_base} && %{with_efiuki}
%kernel_variant_posttrans -v 16k -u virt
%kernel_variant_preun -v 16k -u virt
%endif

%if %{with_arm64_64k_base}
%kernel_variant_preun -v 64k
%kernel_variant_post -v 64k
%endif

%if %{with_debug} && %{with_arm64_64k}
%kernel_variant_preun -v 64k-debug
%kernel_variant_post -v 64k-debug
%endif

%if %{with_arm64_64k} && %{with_debug} && %{with_efiuki}
%kernel_variant_posttrans -v 64k-debug -u virt
%kernel_variant_preun -v 64k-debug -u virt
%endif

%if %{with_arm64_64k_base} && %{with_efiuki}
%kernel_variant_posttrans -v 64k -u virt
%kernel_variant_preun -v 64k -u virt
%endif

%if %{with_realtime_base}
%kernel_variant_preun -v rt
%kernel_variant_post -v rt -r kernel
%kernel_kvm_post rt
%endif

%if %{with_automotive_base}
%kernel_variant_preun -v automotive
%kernel_variant_post -v automotive -r kernel
%endif

%if %{with_realtime} && %{with_debug}
%kernel_variant_preun -v rt-debug
%kernel_variant_post -v rt-debug
%kernel_kvm_post rt-debug
%endif

%if %{with_realtime_arm64_64k_base}
%kernel_variant_preun -v rt-64k
%kernel_variant_post -v rt-64k
%kernel_kvm_post rt-64k
%endif

%if %{with_debug} && %{with_realtime_arm64_64k}
%kernel_variant_preun -v rt-64k-debug
%kernel_variant_post -v rt-64k-debug
%kernel_kvm_post rt-64k-debug
%endif

%if %{with_automotive} && %{with_debug}
%kernel_variant_preun -v automotive-debug
%kernel_variant_post -v automotive-debug
%endif

###
### file lists
###

%if %{with_headers}
%files headers
/usr/include/*
%exclude %{_includedir}/cpufreq.h
%endif

%if %{with_cross_headers}
%files cross-headers
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_stablelists}
%files -n %{package_name}-abi-stablelists
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64 riscv64
%files kernel-kabidw-base-internal
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}
%{_datadir}/doc/kernel-doc-%{specversion}-%{pkgrelease}/kernel.changelog.xz
%endif

%if %{with_perf}
%files -n perf
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%{_docdir}/perf-tip/tips.txt

%files -n python3-perf
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%endif
# with_perf
%endif

%if %{with_libperf}
%files -n libperf
%{_libdir}/libperf.so.0
%{_libdir}/libperf.so.0.0.1

%files -n libperf-devel
%{_libdir}/libperf.so
%{_libdir}/pkgconfig/libperf.pc
%{_includedir}/internal/*.h
%{_includedir}/perf/bpf_perf.h
%{_includedir}/perf/core.h
%{_includedir}/perf/cpumap.h
%{_includedir}/perf/perf_dlfilter.h
%{_includedir}/perf/event.h
%{_includedir}/perf/evlist.h
%{_includedir}/perf/evsel.h
%{_includedir}/perf/mmap.h
%{_includedir}/perf/threadmap.h
%{_mandir}/man3/libperf.3.gz
%{_mandir}/man7/libperf-counting.7.gz
%{_mandir}/man7/libperf-sampling.7.gz
%{_docdir}/libperf/examples/sampling.c
%{_docdir}/libperf/examples/counting.c
%{_docdir}/libperf/html/libperf.html
%{_docdir}/libperf/html/libperf-counting.html
%{_docdir}/libperf/html/libperf-sampling.html

%if %{with_debuginfo}
%files -f libperf-debuginfo.list -n libperf-debuginfo
%endif

# with_libperf
%endif


%if %{with_tools}
%ifnarch %{cpupowerarchs}
%files -n %{package_name}-tools
%else
%files -n %{package_name}-tools -f cpupower.lang
%{_bindir}/cpupower
%{_datadir}/bash-completion/completions/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_mandir}/man[1-8]/cpupower*
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%{_bindir}/intel-speed-select
%{_sbindir}/intel_sdsi
%endif
# cpupowerarchs
%endif
%{_bindir}/tmon
%{_bindir}/bootconfig
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_bindir}/gpio-watch
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat
%{_unitdir}/kvm_stat.service
%config(noreplace) %{_sysconfdir}/logrotate.d/kvm_stat
%{_bindir}/page_owner_sort
%{_bindir}/slabinfo
%if %{with_ynl}
%{_bindir}/ynl*
%{_docdir}/ynl
%{_datadir}/ynl
%{python3_sitelib}/pyynl*
%endif

%if %{with_debuginfo}
%files -f %{package_name}-tools-debuginfo.list -n %{package_name}-tools-debuginfo
%endif

%files -n %{package_name}-tools-libs
%ifarch %{cpupowerarchs}
%{_libdir}/libcpupower.so.1
%{_libdir}/libcpupower.so.0.0.1
%endif

%files -n %{package_name}-tools-libs-devel
%ifarch %{cpupowerarchs}
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%{_includedir}/cpuidle.h
%{_includedir}/powercap.h
%endif
%if %{with_ynl}
%{_libdir}/libynl*
%{_includedir}/ynl
%endif

%files -n rtla
%{_bindir}/rtla
%{_bindir}/hwnoise
%{_bindir}/osnoise
%{_bindir}/timerlat
%{_mandir}/man1/rtla-hwnoise.1.gz
%{_mandir}/man1/rtla-osnoise-hist.1.gz
%{_mandir}/man1/rtla-osnoise-top.1.gz
%{_mandir}/man1/rtla-osnoise.1.gz
%{_mandir}/man1/rtla-timerlat-hist.1.gz
%{_mandir}/man1/rtla-timerlat-top.1.gz
%{_mandir}/man1/rtla-timerlat.1.gz
%{_mandir}/man1/rtla.1.gz

%files -n rv
%{_bindir}/rv
%{_mandir}/man1/rv-list.1.gz
%{_mandir}/man1/rv-mon-wip.1.gz
%{_mandir}/man1/rv-mon-wwnr.1.gz
%{_mandir}/man1/rv-mon.1.gz
%{_mandir}/man1/rv.1.gz

# with_tools
%endif

%if %{with_selftests}
%files selftests-internal
%{_libexecdir}/ksamples
%{_libexecdir}/kselftests
%endif

# empty meta-package
%if %{with_up_base}
%ifnarch %nobuildarches noarch
%files
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <use_vdso> <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files %{?1:-f kernel-%{?3:%{3}-}ldsoconf.list} %{?3:%{3}-}core}\
%{!?_licensedir:%global license %%doc}\
%%license linux-%{KVERREL}/COPYING-%{version}-%{release}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch aarch64 riscv64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost /boot/System.map-%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.%compext\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%ghost %attr(0644, root, root) /boot/symvers-%{KVERREL}%{?3:+%{3}}.%compext\
%ghost %attr(0600, root, root) /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%ghost %attr(0644, root, root) /boot/config-%{KVERREL}%{?3:+%{3}}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-core.list %{?3:%{3}-}modules-core}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/systemtap\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.block\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.drm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.modesetting\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.networking\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.order\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.alias.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.dep.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.devname\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.softdep\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.symbols.bin\
%ghost %attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.weakdep\
%{expand:%%files -f kernel-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%{expand:%%files %{?3:%{3}-}devel}\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}devel-matched}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-extra.list %{?3:%{3}-}modules-extra}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-internal.list %{?3:%{3}-}modules-internal}\
%if 0%{!?fedora:1}\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-partner.list %{?3:%{3}-}modules-partner}\
%endif\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%endif\
%endif\
%if "%{3}" == "rt" || "%{3}" == "rt-debug" || "%{3}" == "rt-64k" || "%{3}" == "rt-64k-debug"\
%if "%{3}" == "rt" || "%{3}" == "rt-debug"\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-rt-kvm.list %{?3:%{3}-}kvm}\
%else\
%{expand:%%files -f kernel-%{?3:%{3}-}modules-rt-64k-kvm.list %{?3:%{3}-}kvm}\
%endif\
%else\
%if %{with_efiuki}\
%{expand:%%files %{?3:%{3}-}uki-virt}\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.%compext\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.builtin*\
%attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi\
%attr(0644, root, root) /lib/modules/%{KVERREL}%{?3:+%{3}}/.%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.hmac\
%ghost /%{image_install_path}/efi/EFI/Linux/%{?-k:%{-k*}}%{!?-k:*}-%{KVERREL}%{?3:+%{3}}.efi\
%{expand:%%files %{?3:%{3}-}uki-virt-addons}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.extra.d/ \
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-virt.efi.extra.d/*.addon.efi\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%endif\
%if %{with_gcov}\
%ifnarch %nobuildarches noarch\
%{expand:%%files -f kernel-%{?3:%{3}-}gcov.list %{?3:%{3}-}gcov}\
%endif\
%endif\
%endif\
%{nil}

%kernel_variant_files %{_use_vdso} %{with_up_base}
%if %{with_up}
%kernel_variant_files %{_use_vdso} %{with_debug} debug
%endif
%if %{with_arm64_16k}
%kernel_variant_files %{_use_vdso} %{with_debug} 16k-debug
%endif
%if %{with_arm64_64k}
%kernel_variant_files %{_use_vdso} %{with_debug} 64k-debug
%endif
%kernel_variant_files %{_use_vdso} %{with_realtime_base} rt
%if %{with_realtime}
%kernel_variant_files %{_use_vdso} %{with_debug} rt-debug
%endif
%kernel_variant_files %{_use_vdso} %{with_automotive_base} automotive
%if %{with_automotive}
%kernel_variant_files %{_use_vdso} %{with_debug} automotive-debug
%endif
%if %{with_debug_meta}
%files debug
%files debug-core
%files debug-devel
%files debug-devel-matched
%files debug-modules
%files debug-modules-core
%files debug-modules-extra
%if %{with_arm64_16k}
%files 16k-debug
%files 16k-debug-core
%files 16k-debug-devel
%files 16k-debug-devel-matched
%files 16k-debug-modules
%files 16k-debug-modules-extra
%endif
%if %{with_arm64_64k}
%files 64k-debug
%files 64k-debug-core
%files 64k-debug-devel
%files 64k-debug-devel-matched
%files 64k-debug-modules
%files 64k-debug-modules-extra
%endif
%endif
%kernel_variant_files %{_use_vdso} %{with_zfcpdump} zfcpdump
%kernel_variant_files %{_use_vdso} %{with_arm64_16k_base} 16k
%kernel_variant_files %{_use_vdso} %{with_arm64_64k_base} 64k
%kernel_variant_files %{_use_vdso} %{with_realtime_arm64_64k_base} rt-64k
%if %{with_realtime_arm64_64k}
%kernel_variant_files %{_use_vdso} %{with_debug} rt-64k-debug
%endif

%define kernel_variant_ipaclones(k:) \
%if %{1}\
%if %{with_ipaclones}\
%{expand:%%files %{?2:%{2}-}ipaclones-internal}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?2:+%{2}}-ipaclones\
%endif\
%endif\
%{nil}

%kernel_variant_ipaclones %{with_up_base}

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Mon Apr 14 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-74.el10]
- sched/core: Prevent rescheduling when interrupts are disabled (Phil Auld) [RHEL-78822]
- sched: Don't define sched_clock_irqtime as static key (Phil Auld) [RHEL-78822]
- sched: Compact RSEQ concurrency IDs with reduced threads and affinity (Phil Auld) [RHEL-78822]
- getdelays: fix error format characters (Phil Auld) [RHEL-78822]
- taskstats: modify taskstats version (Phil Auld) [RHEL-78822]
- sched/debug: Provide slice length for fair tasks (Phil Auld) [RHEL-78822]
- hung_task: add task->flags, blocked by coredump to log (Phil Auld) [RHEL-78822]
- cpufreq/schedutil: Only bind threads if needed (Phil Auld) [RHEL-78822]
- sched/fair: Fix inaccurate h_nr_runnable accounting with delayed dequeue (Phil Auld) [RHEL-78822]
- tracing: Print lazy preemption model (Phil Auld) [RHEL-78822]
- psi: Fix race when task wakes up before psi_sched_switch() adjusts flags (Phil Auld) [RHEL-78822]
- sched/fair: Do not compute overloaded status unnecessarily during lb (Phil Auld) [RHEL-78822]
- sched/fair: Do not compute NUMA Balancing stats unnecessarily during lb (Phil Auld) [RHEL-78822]
- sched, psi: Don't account irq time if sched_clock_irqtime is disabled (Phil Auld) [RHEL-78822]
- sched: Don't account irq time if sched_clock_irqtime is disabled (Phil Auld) [RHEL-78822]
- sched: Define sched_clock_irqtime as static key (Phil Auld) [RHEL-78822]
- sched/debug: Change need_resched warnings to pr_err (Phil Auld) [RHEL-78822]
- sched/core: Prioritize migrating eligible tasks in sched_balance_rq() (Phil Auld) [RHEL-78822]
- sched: Fix race between yield_to() and try_to_wake_up() (Phil Auld) [RHEL-78822]
- sched/fair: Encapsulate set custom slice in a __setparam_fair() function (Phil Auld) [RHEL-78822]
- sched/fair: Fix update_cfs_group() vs DELAY_DEQUEUE (Phil Auld) [RHEL-78822]
- delayacct: add delay min to record delay peak (Phil Auld) [RHEL-78822]
- delayacct: add delay max to record delay peak (Phil Auld) [RHEL-78822]
- sched/fair: Fix EEVDF entity placement bug causing scheduling lag (Phil Auld) [RHEL-78822]
- preempt: Move PREEMPT_RT before PREEMPT in vermagic. (Phil Auld) [RHEL-78822]
- sched/fair: Update comments after sched_tick() rename. (Phil Auld) [RHEL-78822]
- powerpc: Large user copy aware of full:rt:lazy preemption (Phil Auld) [RHEL-78822]
- powerpc: Add preempt lazy support (Phil Auld) [RHEL-78822]
- PM: EM: Move sched domains rebuild function from schedutil to EM (Phil Auld) [RHEL-78822]
- PM: EM: Add min/max available performance state limits (Phil Auld) [RHEL-78822]
- cpufreq: schedutil: Fix superfluous updates caused by need_freq_update (Phil Auld) [RHEL-78822]
- sched/fair: Fix CPU bandwidth limit bypass during CPU hotplug (Phil Auld) [RHEL-78822]
- sched: deadline: Cleanup goto label in pick_earliest_pushable_dl_task (Phil Auld) [RHEL-78822]
- sched/fair: Mark m*_vruntime() with __maybe_unused (Phil Auld) [RHEL-78822]
- sched/fair: Untangle NEXT_BUDDY and pick_next_task() (Phil Auld) [RHEL-78822]
- sched/fair: Fix variable declaration position (Phil Auld) [RHEL-78822]
- sched/fair: Do not try to migrate delayed dequeue task (Phil Auld) [RHEL-78822]
- sched/fair: Rename cfs_rq.nr_running into nr_queued (Phil Auld) [RHEL-78822]
- sched/fair: Remove unused cfs_rq.idle_nr_running (Phil Auld) [RHEL-78822]
- sched/fair: Rename cfs_rq.idle_h_nr_running into h_nr_idle (Phil Auld) [RHEL-78822]
- sched/fair: Removed unsued cfs_rq.h_nr_delayed (Phil Auld) [RHEL-78822]
- sched/fair: Use the new cfs_rq.h_nr_runnable (Phil Auld) [RHEL-78822]
- sched/fair: Add new cfs_rq.h_nr_runnable (Phil Auld) [RHEL-78822]
- sched/fair: Rename h_nr_running into h_nr_queued (Phil Auld) [RHEL-78822]
- sched: Unify HK_TYPE_{TIMER|TICK|MISC} to HK_TYPE_KERNEL_NOISE (Phil Auld) [RHEL-78822]
- sched/isolation: Consolidate housekeeping cpumasks that are always identical (Phil Auld) [RHEL-78822]
- sched/isolation: Make "isolcpus=nohz" equivalent to "nohz_full" (Phil Auld) [RHEL-78822]
- sched/core: Remove HK_TYPE_SCHED (Phil Auld) [RHEL-78822]
- sched/deadline: Check bandwidth overflow earlier for hotplug (Phil Auld) [RHEL-78822]
- sched/deadline: Correctly account for allocated bandwidth during hotplug (Phil Auld) [RHEL-78822]
- sched/deadline: Consolidate Timer Cancellation (Phil Auld) [RHEL-78822]
- sched/fair: Remove CONFIG_CFS_BANDWIDTH=n definition of cfs_bandwidth_used() (Phil Auld) [RHEL-78822]
- sched: Don't try to catch up excess steal time. (Phil Auld) [RHEL-78822]
- sched: add READ_ONCE to task_on_rq_queued (Phil Auld) [RHEL-78822]
- sched/deadline: Restore dl_server bandwidth on non-destructive root domain changes (Phil Auld) [RHEL-78822]
- sched/core: Update kernel boot parameters for LAZY preempt. (Phil Auld) [RHEL-78822]
- Revert "redhat: Fix CONFIG_PREEMPT_RT for RT and AUTO kernels" (Phil Auld) [RHEL-78822]
- s390: Add ARCH_HAS_PREEMPT_LAZY support (Phil Auld) [RHEL-78822]
- s390: Add missing _TIF defines (Phil Auld) [RHEL-78822]
- tracing: Record task flag NEED_RESCHED_LAZY. (Phil Auld) [RHEL-78822]
- tracing: Remove TRACE_FLAG_IRQS_NOSUPPORT (Phil Auld) [RHEL-78822]
- sched/cpufreq: Ensure sd is rebuilt for EAS check (Phil Auld) [RHEL-78822]
- sched, x86: Update the comment for TIF_NEED_RESCHED_LAZY. (Phil Auld) [RHEL-78822]
- sched: No PREEMPT_RT=y for all{yes,mod}config (Phil Auld) [RHEL-78822]
- riscv: add PREEMPT_LAZY support (Phil Auld) [RHEL-78822]
- sched: Enable PREEMPT_DYNAMIC for PREEMPT_RT (Phil Auld) [RHEL-78822]
- sched: Add Lazy preemption model (Phil Auld) [RHEL-78822]
- sched, x86: Enable Lazy preemption (Phil Auld) [RHEL-78822]
- sched: Initialize idle tasks only once (Phil Auld) [RHEL-78822]
- sched: Add TIF_NEED_RESCHED_LAZY infrastructure (Phil Auld) [RHEL-78822]
- sched: psi: pass enqueue/dequeue flags to psi callbacks directly (Phil Auld) [RHEL-78822]
- sched/uclamp: Fix unnused variable warning (Phil Auld) [RHEL-78822]
- sched_getattr: port to copy_struct_to_user (Phil Auld) [RHEL-78822]
- uaccess: add copy_struct_to_user helper (Phil Auld) [RHEL-78822]
- sched: Split scheduler and execution contexts (Phil Auld) [RHEL-78822]
- sched: Consolidate pick_*_task to task_is_pushable helper (Phil Auld) [RHEL-78822]
- sched: Add move_queued_task_locked helper (Phil Auld) [RHEL-78822]
- sched: Split out __schedule() deactivate task logic into a helper (Phil Auld) [RHEL-78822]
- sched: idle: Optimize the generic idle loop by removing needless memory barrier (Phil Auld) [RHEL-78822]
- sched: Improve cache locality of RSEQ concurrency IDs for intermittent workloads (Phil Auld) [RHEL-78822]
- sched/fair: fix the comment for PREEMPT_SHORT (Phil Auld) [RHEL-78822]
- sched/fair: optimize the PLACE_LAG when se->vlag is zero (Phil Auld) [RHEL-78822]
- sched/wait: Remove unused bit_wait_io_timeout (Phil Auld) [RHEL-78822]
- sched/fair: remove the DOUBLE_TICK feature (Phil Auld) [RHEL-78822]
- redhat: Fix CONFIG_PREEMPT_RT for RT and AUTO kernels (Juri Lelli) [RHEL-78822]
- Revert "riscv: add PREEMPT_AUTO support" (Juri Lelli) [RHEL-78822]
- Revert "sched: define TIF_ALLOW_RESCHED" (Juri Lelli) [RHEL-78822]
- Revert "sched: Update the lazy-preempt bits." (Juri Lelli) [RHEL-78822]
- Revert "sched: Replace PREEMPT_AUTO with LAZY_PREEMPT." (Juri Lelli) [RHEL-78822]
- perf annotate: Use an array for the disassembler preference (Michael Petlan) [RHEL-77935]
- tools features: Don't check for libunwind devel files by default (Michael Petlan) [RHEL-77935]
- tools build: Remove the libunwind feature tests from the ones detected when test-all.o builds (Michael Petlan) [RHEL-77935]
- perf test: Fix parallel/sequential option documentation (Michael Petlan) [RHEL-77935]
- perf stat: Remove empty new_line_metric function (Michael Petlan) [RHEL-77935]
- perf stat: Also hide metric-units from JSON when event didn't run (Michael Petlan) [RHEL-77935]
- perf stat: Fix trailing comma when there is no metric unit (Michael Petlan) [RHEL-77935]
- perf test stat: Avoid hybrid assumption when virtualized (Michael Petlan) [RHEL-77935]
- perf tools: Fixup end address of modules (Michael Petlan) [RHEL-77935]
- perf symbol: Prefer non-label symbols with same address (Michael Petlan) [RHEL-77935]
- docs: ABI: sysfs-bus-event_source-devices-vpa-pmu: Fix htmldocs errors (Michael Petlan) [RHEL-77935]
- perf/x86/rapl: Remove the unused get_rapl_pmu_cpumask() function (Michael Petlan) [RHEL-77935]
- ARM: pmuv3: Add missing write_pmuacr() (Michael Petlan) [RHEL-77935]
- perf probe: Fix uninitialized variable (Michael Petlan) [RHEL-77935]
- libperf: evlist: Fix --cpu argument on hybrid platform (Michael Petlan) [RHEL-77935]
- perf test expr: Fix system_tsc_freq for only x86 (Michael Petlan) [RHEL-77935]
- perf test hwmon_pmu: Fix event file location (Michael Petlan) [RHEL-77935]
- perf hwmon_pmu: Use openat rather than dup to refresh directory (Michael Petlan) [RHEL-77935]
- perf ftrace: Fix undefined behavior in cmp_profile_data() (Michael Petlan) [RHEL-77935]
- perf tools: Fix precise_ip fallback logic (Michael Petlan) [RHEL-77935]
- tools headers: Sync uapi/linux/perf_event.h with the kernel sources (Michael Petlan) [RHEL-77935]
- perf test: Don't signal all processes on system when interrupting tests (Michael Petlan) [RHEL-77935]
- perf tools: Fix build-id event recording (Michael Petlan) [RHEL-77935]
- tools: Override makefile ARCH variable if defined, but empty (Michael Petlan) [RHEL-77935]
- perf tests: Fix hwmon parsing with PMU name test (Michael Petlan) [RHEL-77935]
- perf hwmon_pmu: Ensure hwmon key union is zeroed before use (Michael Petlan) [RHEL-77935]
- perf tests hwmon_pmu: Remove double evlist__delete() (Michael Petlan) [RHEL-77935]
- perf/test: fix perf ftrace test on s390 (Michael Petlan) [RHEL-77935]
- perf bpf-filter: Return -ENOMEM directly when pfi allocation fails (Michael Petlan) [RHEL-77935]
- perf test: Correct hwmon test PMU detection (Michael Petlan) [RHEL-77935]
- perf: Remove unused del_perf_probe_events() (Michael Petlan) [RHEL-77935]
- perf pmu: Move pmu_metrics_table__find and remove ARM override (Michael Petlan) [RHEL-77935]
- perf jevents: Add map_for_cpu() (Michael Petlan) [RHEL-77935]
- perf header: Pass a perf_cpu rather than a PMU to get_cpuid_str (Michael Petlan) [RHEL-77935]
- perf header: Avoid transitive PMU includes (Michael Petlan) [RHEL-77935]
- perf arm64 header: Use cpu argument in get_cpuid (Michael Petlan) [RHEL-77935]
- perf header: Refactor get_cpuid to take a CPU for ARM (Michael Petlan) [RHEL-77935]
- perf header: Move is_cpu_online to numa bench (Michael Petlan) [RHEL-77935]
- perf jevents: fix breakage when do perf stat on system metric (Michael Petlan) [RHEL-77935]
- perf test: Add missing __exit calls in tool/hwmon tests (Michael Petlan) [RHEL-77935]
- perf tests: Make leader sampling test work without branch event (Michael Petlan) [RHEL-77935]
- perf util: Remove kernel version deadcode (Michael Petlan) [RHEL-77935]
- perf test shell trace_exit_race: Use --no-comm to avoid cases where COMM isn't resolved (Michael Petlan) [RHEL-77935]
- perf test shell trace_exit_race: Show what went wrong in verbose mode (Michael Petlan) [RHEL-77935]
- perf tests: Add test for trace output loss (Michael Petlan) [RHEL-77935]
- perf trace: Avoid garbage when not printing a syscall's arguments (Michael Petlan) [RHEL-77935]
- perf trace: Do not lose last events in a race (Michael Petlan) [RHEL-77935]
- perf probe: Introduce quotation marks support (Michael Petlan) [RHEL-77935]
- perf string: Add strpbrk_esq() and strdup_esq() for escape and quote (Michael Petlan) [RHEL-77935]
- perf probe: Accept FUNC@* to specify function name explicitly (Michael Petlan) [RHEL-77935]
- perf probe: Fix to ignore escaped characters in --lines option (Michael Petlan) [RHEL-77935]
- perf probe: Fix error message for failing to find line range (Michael Petlan) [RHEL-77935]
- perf trace: Fix tracing itself, creating feedback loops (Michael Petlan) [RHEL-77935]
- libsubcmd: Move va_end() before exit (Michael Petlan) [RHEL-77935]
- perf timechart: Remove redundant variable assignment (Michael Petlan) [RHEL-77935]
- perf list: Fix topic and pmu_name argument order (Michael Petlan) [RHEL-77935]
- perf tools: Fix typos Muliplier -> Multiplier (Michael Petlan) [RHEL-77935]
- perf disasm: Allow configuring what disassemblers to use (Michael Petlan) [RHEL-77935]
- perf disasm: Define stubs for the LLVM and capstone disassemblers (Michael Petlan) [RHEL-77935]
- perf disasm: Introduce symbol__disassemble_objdump() (Michael Petlan) [RHEL-77935]
- perf build: Remove PERF_HAVE_DWARF_REGS (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Remove get_arch_regstr code (Michael Petlan) [RHEL-77935]
- perf xtensa: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf sparc: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf sh: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf s390: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf riscv: Remove dwarf-regs.c and add dwarf-regs-table.h (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Move powerpc dwarf-regs out of arch (Michael Petlan) [RHEL-77935]
- perf mips: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf loongarch: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Move csky dwarf-regs out of arch (Michael Petlan) [RHEL-77935]
- perf arm: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf arm64: Remove dwarf-regs.c (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Move x86 dwarf-regs out of arch (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Pass ELF flags to get_dwarf_regstr (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Pass accurate disassembly machine to get_dwarf_regnum (Michael Petlan) [RHEL-77935]
- perf disasm: Add e_machine/e_flags to struct arch (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Add EM_HOST and EF_HOST defines (Michael Petlan) [RHEL-77935]
- perf dwarf-regs: Remove PERF_HAVE_ARCH_REGS_QUERY_REGISTER_OFFSET (Michael Petlan) [RHEL-77935]
- perf bpf-prologue: Remove unused file (Michael Petlan) [RHEL-77935]
- perf docs: Document tool and hwmon events (Michael Petlan) [RHEL-77935]
- perf test: Add hwmon "PMU" test (Michael Petlan) [RHEL-77935]
- perf pmu: Add calls enabling the hwmon_pmu (Michael Petlan) [RHEL-77935]
- perf hwmon_pmu: Add a tool PMU exposing events from hwmon in sysfs (Michael Petlan) [RHEL-77935]
- perf test: Add hwmon filename parser test (Michael Petlan) [RHEL-77935]
- perf hwmon_pmu: Add hwmon filename parser (Michael Petlan) [RHEL-77935]
- tools api io: Ensure line_len_out is always initialized (Michael Petlan) [RHEL-77935]
- perf build: Include libtraceevent headers directly indicated by pkg-config (Michael Petlan) [RHEL-77935]
- perf script python: Adjust objdump start/end per map pgoff parameter (Michael Petlan) [RHEL-77935]
- perf script cs_etm: Add map_pgoff to python dictionary (Michael Petlan) [RHEL-77935]
- perf stat: Expand metric+unit buffer size (Michael Petlan) [RHEL-77935]
- perf tools: Add the empty-pmu-events build to .gitignore (Michael Petlan) [RHEL-77935]
- perf: event: Remove deadcode (Michael Petlan) [RHEL-77935]
- perf trace: avoid garbage when not printing a trace event's arguments (Michael Petlan) [RHEL-77935]
- perf test: Fix ftrace test with regex patterns (Michael Petlan) [RHEL-77935]
- perf test: Remove dangling CFLAGS for removed attr.o object (Michael Petlan) [RHEL-77935]
- perf tools: Add all shellcheck_log to gitignore (Michael Petlan) [RHEL-77935]
- perf build: Add missing cflags when building with custom libtraceevent (Michael Petlan) [RHEL-77935]
- perf build: Make libunwind opt-in rather than opt-out (Michael Petlan) [RHEL-77935]
- perf test: Use sqrtloop workload to test bperf event (Michael Petlan) [RHEL-77935]
- perf stat: Support inherit events during fork() for bperf (Michael Petlan) [RHEL-77935]
- perf arm-spe: Use old behavior when opening old SPE files (Michael Petlan) [RHEL-77935]
- perf ftrace latency: Fix unit on histogram first entry when using --use-nsec (Michael Petlan) [RHEL-77935]
- perf, riscv: Wire up perf trace support for RISC-V (Michael Petlan) [RHEL-77935]
- perf probe: Fix retrieval of source files from a debuginfod server (Michael Petlan) [RHEL-77935]
- perf arm-spe: Update --itrace help text (Michael Petlan) [RHEL-77935]
- perf arm-spe: Correctly set sample flags (Michael Petlan) [RHEL-77935]
- perf arm-spe: Use ARM_SPE_OP_BRANCH_ERET when synthesizing branches (Michael Petlan) [RHEL-77935]
- perf arm-spe: Set sample.addr to target address for instruction sample (Michael Petlan) [RHEL-77935]
- perf vendor events arm64: Add i.MX91 DDR Performance Monitor metrics (Michael Petlan) [RHEL-77935]
- perf test: Sort tests placing exclusive tests last (Michael Petlan) [RHEL-77935]
- perf test: Add a signal handler to kill forked child processes (Michael Petlan) [RHEL-77935]
- perf test: Make parallel testing the default (Michael Petlan) [RHEL-77935]
- perf test: Run parallel tests in two passes (Michael Petlan) [RHEL-77935]
- perf test: Add a signal handler around running a test (Michael Petlan) [RHEL-77935]
- perf test: Tag parallel failing shell tests with "(exclusive)" (Michael Petlan) [RHEL-77935]
- perf test: Avoid list test blocking on writing to stdout (Michael Petlan) [RHEL-77935]
- perf test: Reduce scope of parallel variable (Michael Petlan) [RHEL-77935]
- perf test: Display number of active running tests (Michael Petlan) [RHEL-77935]
- tools subcmd: Add non-waitpid check_if_command_finished() (Michael Petlan) [RHEL-77935]
- perf disasm: Fix not cleaning up disasm_line in symbol__disassemble_raw() (Michael Petlan) [RHEL-77935]
- perf disasm: Use disasm_line__free() to properly free disasm_line (Michael Petlan) [RHEL-77935]
- perf disasm: Use disasm_line__free() to properly free disasm_line (Michael Petlan) [RHEL-77935]
- perf test: Add precise_max subtest to the perf record shell test (Michael Petlan) [RHEL-77935]
- perf record: Just use "cycles:P" as the default event (Michael Petlan) [RHEL-77935]
- perf tools: Check fallback error and order (Michael Petlan) [RHEL-77935]
- perf tools: Move x86__is_amd_cpu() to util/env.c (Michael Petlan) [RHEL-77935]
- perf tools: Detect missing kernel features properly (Michael Petlan) [RHEL-77935]
- perf tools: Do not set exclude_guest for precise_ip (Michael Petlan) [RHEL-77935]
- perf tools: Simplify evsel__add_modifier() (Michael Petlan) [RHEL-77935]
- perf tools: Don't set attr.exclude_guest by default (Michael Petlan) [RHEL-77935]
- perf tools: Add fallback for exclude_guest (Michael Petlan) [RHEL-77935]
- perf tools: sched-pipe bench: add (-n) nonblocking benchmark (Michael Petlan) [RHEL-77935]
- perf test: Document the -w/--workload option (Michael Petlan) [RHEL-77935]
- perf test: Introduce --list-workloads to list the available workloads (Michael Petlan) [RHEL-77935]
- perf test: Introduce workloads__for_each() (Michael Petlan) [RHEL-77935]
- perf vendor events amd: Update Zen 5 data cache fill events (Michael Petlan) [RHEL-77935]
- perf vendor events amd: Add Zen 5 data fabric metrics (Michael Petlan) [RHEL-77935]
- perf vendor events amd: Add Zen 5 data fabric events (Michael Petlan) [RHEL-77935]
- perf test: Fix perf test case 84 on s390 (Michael Petlan) [RHEL-77935]
- perf test: Update all metrics test like metricgroups test (Michael Petlan) [RHEL-77935]
- perf build: Rename CONFIG_DWARF to CONFIG_LIBDW (Michael Petlan) [RHEL-77935]
- perf build: Rename HAVE_DWARF_SUPPORT to HAVE_LIBDW_SUPPORT (Michael Petlan) [RHEL-77935]
- perf libdw: Remove unnecessary defines (Michael Petlan) [RHEL-77935]
- perf probe: Move elfutils support check to libdw check (Michael Petlan) [RHEL-77935]
- perf build: Combine test-dwarf-getcfi into test-libdw (Michael Petlan) [RHEL-77935]
- perf build: Combine test-dwarf-getlocations into test-libdw (Michael Petlan) [RHEL-77935]
- perf build: Combine libdw-dwarf-unwind into libdw feature tests (Michael Petlan) [RHEL-77935]
- perf build: Rename test-dwarf to test-libdw (Michael Petlan) [RHEL-77935]
- perf build: Remove defined but never used variable (Michael Petlan) [RHEL-77935]
- perf build: Rename NO_DWARF to NO_LIBDW (Michael Petlan) [RHEL-77935]
- perf build: Fix LIBDW_DIR (Michael Petlan) [RHEL-77935]
- perf test: Move attr files into shell directory where they are used (Michael Petlan) [RHEL-77935]
- perf test: Remove C test wrapper for attr.py (Michael Petlan) [RHEL-77935]
- perf test: Add a shell wrapper for "Setup struct perf_event_attr" (Michael Petlan) [RHEL-77935]
- perf probe: Correct demangled symbols in C++ program (Michael Petlan) [RHEL-77935]
- perf stat: Disable metric thresholds for CSV and JSON metric-only mode (Michael Petlan) [RHEL-77935]
- perf stat: Add metric-threshold to json output (Michael Petlan) [RHEL-77935]
- perf stat: Change color to threshold in print_metric (Michael Petlan) [RHEL-77935]
- perf stat: Drop metric-unit if unit is NULL (Michael Petlan) [RHEL-77935]
- perf stat: Display "none" for NaN with metric only json (Michael Petlan) [RHEL-77935]
- perf stat: Fix/add parameter names for print_metric (Michael Petlan) [RHEL-77935]
- perf color: Add printf format checking and resolve issues (Michael Petlan) [RHEL-77935]
- perf probe: Fix libdw memory leak (Michael Petlan) [RHEL-77935]
- perf disasm: Fix capstone memory leak (Michael Petlan) [RHEL-77935]
- tools/perf/powerpc/util: Add support to handle compatible mode PVR for perf json events (Michael Petlan) [RHEL-77935]
- tools/perf/pmu-events/powerpc: Add support for compat events in json (Michael Petlan) [RHEL-77935]
- perf dso: Fix symtab_type for kmod compression (Michael Petlan) [RHEL-77935]
- perf probe: Improve log for long event name failure (Michael Petlan) [RHEL-77935]
- perf probe: Check group string length (Michael Petlan) [RHEL-77935]
- perf probe: Use the MAX_EVENT_NAME_LEN macro (Michael Petlan) [RHEL-77935]
- perf test: Speed up some tests using perf list (Michael Petlan) [RHEL-77935]
- perf x86/topdown: Refine helper arch_is_topdown_metrics() (Michael Petlan) [RHEL-77935]
- perf x86/topdown: Make topdown metrics comparators be symmetric (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Remove duplicate io.h header (Michael Petlan) [RHEL-77935]
- perf arm-spe: Add Cortex CPUs to common data source encoding list (Michael Petlan) [RHEL-77935]
- perf arm-spe: Add Neoverse-V2 to common data source encoding list (Michael Petlan) [RHEL-77935]
- perf arm-spe: Remove the unused 'midr' field (Michael Petlan) [RHEL-77935]
- perf arm-spe: Use metadata to decide the data source feature (Michael Petlan) [RHEL-77935]
- perf arm-spe: Introduce arm_spe__is_homogeneous() (Michael Petlan) [RHEL-77935]
- perf arm-spe: Rename the common data source encoding (Michael Petlan) [RHEL-77935]
- perf arm-spe: Rename arm_spe__synth_data_source_generic() (Michael Petlan) [RHEL-77935]
- perf test: Delete unused Intel CQM test (Michael Petlan) [RHEL-77935]
- perf evsel: Fix missing inherit + sample read check (Michael Petlan) [RHEL-77935]
- perf sched timehist: Add pre-migration wait time option (Michael Petlan) [RHEL-77935]
- perf tools: Remove unnecessary parentheses (Michael Petlan) [RHEL-77935]
- perf tools: Fix possible compiler warnings in hashmap (Michael Petlan) [RHEL-77935]
- perf tools: Fix compiler error in util/tool_pmu.c (Michael Petlan) [RHEL-77935]
- tools/perf/tests: Remove duplicate evlist__delete in tests/tool_pmu.c (Michael Petlan) [RHEL-77935]
- tools/perf/tests: Fix compilation error with strncpy in tests/tool_pmu (Michael Petlan) [RHEL-77935]
- perf report: Display columns Predicted/Abort/Cycles in --branch-history (Michael Petlan) [RHEL-77935]
- perf tests: Add tool PMU test (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Switch to standard pmu functions and json descriptions (Michael Petlan) [RHEL-77935]
- perf jevents: Add tool event json under a common architecture (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Move expr literals to tool_pmu (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Rename perf_tool_event__* to tool_pmu__* (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Rename enum perf_tool_event to tool_pmu_event (Michael Petlan) [RHEL-77935]
- perf tool_pmu: Factor tool events into their own PMU (Michael Petlan) [RHEL-77935]
- perf parse-events: Expose/rename config_term_name (Michael Petlan) [RHEL-77935]
- perf pmu: Allow hardcoded terms to be applied to attributes (Michael Petlan) [RHEL-77935]
- perf pmu: Simplify an asprintf error message (Michael Petlan) [RHEL-77935]
- perf tools: Remove unused color_fwrite_lines (Michael Petlan) [RHEL-77935]
- perf test x86: Fix typo in intel-pt-test (Michael Petlan) [RHEL-77935]
- perf probe: Remove unused add_perf_probe_events (Michael Petlan) [RHEL-77935]
- perf test attr: Add back missing topdown events (Michael Petlan) [RHEL-77935]
- perf arm-spe: Dump metadata with version 2 (Michael Petlan) [RHEL-77935]
- perf arm-spe: Support metadata version 2 (Michael Petlan) [RHEL-77935]
- perf arm-spe: Save per CPU information in metadata (Michael Petlan) [RHEL-77935]
- perf arm-spe: Calculate meta data size (Michael Petlan) [RHEL-77935]
- perf arm-spe: Define metadata header version 2 (Michael Petlan) [RHEL-77935]
- perf list: update option desc in man page (Michael Petlan) [RHEL-77935]
- perf test: Restore sample rate for perf_event_attr (Michael Petlan) [RHEL-77935]
- perf/test: perf test 86 fails on s390 (Michael Petlan) [RHEL-77935]
- tools/perf: Allow inherit + PERF_SAMPLE_READ when opening events (Michael Petlan) [RHEL-77935]
- tools/perf: Correctly calculate sample period for inherited SAMPLE_READ values (Michael Petlan) [RHEL-77935]
- perf test: Skip not fail syscall tp fields test when insufficient permissions (Michael Petlan) [RHEL-77935]
- perf test: Skip not fail tp fields test when insufficient permissions (Michael Petlan) [RHEL-77935]
- perf test: Fix memory leaks on event-times error paths (Michael Petlan) [RHEL-77935]
- perf stat: Fix affinity memory leaks on error path (Michael Petlan) [RHEL-77935]
- perf jevents: Don't stop at the first matched pmu when searching a events table (Michael Petlan) [RHEL-77935]
- perf tests: Add more topdown events regroup tests (Michael Petlan) [RHEL-77935]
- perf tests: Add topdown events counting and sampling tests (Michael Petlan) [RHEL-77935]
- perf tests: Add leader sampling test in record tests (Michael Petlan) [RHEL-77935]
- perf x86/topdown: Don't move topdown metric events in group (Michael Petlan) [RHEL-77935]
- perf x86/topdown: Correct leader selection with sample_read enabled (Michael Petlan) [RHEL-77935]
- perf x86/topdown: Complete topdown slots/metrics events check (Michael Petlan) [RHEL-77935]
- perf evsel: Reduce a variables scope (Michael Petlan) [RHEL-77935]
- perf vender events arm64: Use "Topdown" as topdown metric group name (Michael Petlan) [RHEL-77935]
- perf test: Use ARRAY_SIZE for array length (Michael Petlan) [RHEL-77935]
- perf/test: Speed up test case perf annotate basic tests (Michael Petlan) [RHEL-77935]
- perf mem: Fix printing PERF_MEM_LVLNUM_{L2_MHB|MSC} (Michael Petlan) [RHEL-77935]
- perf sched replay: Remove unused parts of the code (Michael Petlan) [RHEL-77935]
- libperf: Explicitly specify install-html dependencies (Michael Petlan) [RHEL-77935]
- perf test: Add a test for default perf stat command (Michael Petlan) [RHEL-77935]
- perf test: Make stat test work on DT devices (Michael Petlan) [RHEL-77935]
- perf evsel: Remove pmu_name (Michael Petlan) [RHEL-77935]
- perf evsel x86: Make evsel__has_perf_metrics work for legacy events (Michael Petlan) [RHEL-77935]
- perf stat: Remove evlist__add_default_attrs use strings (Michael Petlan) [RHEL-77935]
- perf stat: Uniquify event name improvements (Michael Petlan) [RHEL-77935]
- perf evsel: Add alternate_hw_config and use in evsel__match (Michael Petlan) [RHEL-77935]
- perf test: Ignore security failures in all PMU test (Michael Petlan) [RHEL-77935]
- perf symbol: Do not fixup end address of labels (Michael Petlan) [RHEL-77935]
- perf vendor events arm64: imx95: add imx95_bandwidth_usage.lpddr4x metric (Michael Petlan) [RHEL-77935]
- perf stat: Stop repeating when ref_perf_stat() returns -1 (Michael Petlan) [RHEL-77935]
- perf stat: Close cork_fd when create_perf_stat_counter() failed (Michael Petlan) [RHEL-77935]
- perf evsel: display dmesg command of showing a hardcoded path (Michael Petlan) [RHEL-77935]
- perf test: cs-etm: Test Coresight disassembly script (Michael Petlan) [RHEL-77935]
- perf scripts python cs-etm: Add start and stop arguments (Michael Petlan) [RHEL-77935]
- perf scripts python cs-etm: Improve arguments (Michael Petlan) [RHEL-77935]
- perf scripts python cs-etm: Update to use argparse (Michael Petlan) [RHEL-77935]
- perf scripting python: Add function to get a config value (Michael Petlan) [RHEL-77935]
- perf cs-etm: Use new OpenCSD consistency checks (Michael Petlan) [RHEL-77935]
- perf cs-etm: Don't flush when packet_queue fills up (Michael Petlan) [RHEL-77935]
- perf test: Be more tolerant of metricgroup failures (Michael Petlan) [RHEL-77935]
- perf tools: update expected diff for lib/list_sort.c (Michael Petlan) [RHEL-77935]
- tools/lib/list_sort: remove unnecessary header includes (Michael Petlan) [RHEL-77935]
- lib/list_sort: remove unnecessary header includes (Michael Petlan) [RHEL-77935]
- libsubcmd: Silence compiler warning (Michael Petlan) [RHEL-77935]
- perf/x86/intel: Fix bitmask of OCR and FRONTEND events for LNC (Michael Petlan) [RHEL-77935]
- perf/x86/intel/ds: Add PEBS format 6 (Michael Petlan) [RHEL-77935]
- perf/x86/intel/uncore: Add Clearwater Forest support (Michael Petlan) [RHEL-77935]
- perf/x86/intel/ds: Unconditionally drain PEBS DS when changing PEBS_DATA_CFG (Michael Petlan) [RHEL-77935]
- perf/hw_breakpoint: use ERR_PTR_PCPU(), IS_ERR_PCPU() and PTR_ERR_PCPU() macros (Michael Petlan) [RHEL-77935]
- powerpc/perf: Add per-task/process monitoring to vpa_pmu driver (Michael Petlan) [RHEL-77935]
- powerpc/kvm: Add vpa latency counters to kvm_vcpu_arch (Michael Petlan) [RHEL-77935]
- docs: ABI: sysfs-bus-event_source-devices-vpa-pmu: Document sysfs event format entries for vpa_pmu (Michael Petlan) [RHEL-77935]
- powerpc/perf: Add perf interface to expose vpa counters (Michael Petlan) [RHEL-77935]
- redhat/configs: enable VPA_PMU on PowerPC (Michael Petlan) [RHEL-77935]
- perf/core: Correct perf sampling with guest VMs (Michael Petlan) [RHEL-77935]
- perf/x86: Refactor misc flag assignments (Michael Petlan) [RHEL-77935]
- perf/powerpc: Use perf_arch_instruction_pointer() (Michael Petlan) [RHEL-77935]
- perf/core: Hoist perf_instruction_pointer() and perf_misc_flags() (Michael Petlan) [RHEL-77935]
- perf/arm: Drop unused functions (Michael Petlan) [RHEL-77935]
- perf/x86/amd/uncore: Avoid a false positive warning about snprintf truncation in amd_uncore_umc_ctx_init (Michael Petlan) [RHEL-77935]
- perf/x86/intel: Do not enable large PEBS for events with aux actions or aux sampling (Michael Petlan) [RHEL-77935]
- perf/x86/intel/pt: Add support for pause / resume (Michael Petlan) [RHEL-77935]
- perf/core: Add aux_pause, aux_resume, aux_start_paused (Michael Petlan) [RHEL-77935]
- perf/x86/intel/pt: Fix buffer full but size is 0 case (Michael Petlan) [RHEL-77935]
- perf/x86/rapl: Clean up cpumask and hotplug (Michael Petlan) [RHEL-77935]
- perf/x86/rapl: Move the pmu allocation out of CPU hotplug (Michael Petlan) [RHEL-77935]
- perf/x86/amd: Warn only on new bits set (Michael Petlan) [RHEL-77935]
- perf/x86/intel: Add PMU support for ArrowLake-H (Michael Petlan) [RHEL-77935]
- perf/x86/intel: Support hybrid PMU with multiple atom uarchs (Michael Petlan) [RHEL-77935]
- x86/cpu/intel: Define helper to get CPU core native ID (Michael Petlan) [RHEL-77935]
- perf/x86: Refine hybrid_pmu_type defination (Michael Petlan) [RHEL-77935]
- perf/arm_pmuv3: Add PMUv3.9 per counter EL0 access control (Michael Petlan) [RHEL-77935]

* Thu Apr 10 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-73.el10]
- x86/topology: Use x86_sched_itmt_flags for PKG domain unconditionally (Steve Best) [RHEL-53783]
- x86/topology: Remove x86_smt_flags and use cpu_smt_flags directly (Steve Best) [RHEL-53783]
- x86/itmt: Move the "sched_itmt_enabled" sysctl to debugfs (Steve Best) [RHEL-53783]
- x86/cpu: Enable SD_ASYM_PACKING for PKG domain on AMD (Steve Best) [RHEL-53783]
- x86/cpufeatures: Add X86_FEATURE_AMD_HETEROGENEOUS_CORES (Steve Best) [RHEL-53783]
- x86/itmt: Use guard() for itmt_update_mutex (Steve Best) [RHEL-53783]
- x86/itmt: Convert "sysctl_sched_itmt_enabled" to boolean (Steve Best) [RHEL-53783]
- selftests: net: bump GRO timeout for gro/setup_veth (Hangbin Liu) [RHEL-84558]
- selftests: net: bpf_offload: add 'libbpf_global' to ignored maps (Hangbin Liu) [RHEL-84558]
- selftests: net: fix error message in bpf_offload (Hangbin Liu) [RHEL-84558]
- selftests: openvswitch: don't hardcode the drop reason subsys (Hangbin Liu) [RHEL-84558]
- selftests: net: report output format as TAP 13 in Python tests (Hangbin Liu) [RHEL-84558]
- selftests/net: deflake GRO tests (Hangbin Liu) [RHEL-84558]
- selftests/net: only print passing message in GRO tests when tests pass (Hangbin Liu) [RHEL-84558]
- selftests/net: have `gro.sh -t` return a correct exit code (Hangbin Liu) [RHEL-84558]
- selftests: net: Fix minor typos in MPTCP and psock tests (Hangbin Liu) [RHEL-84558]
- selftests: net: Fix few spelling mistakes (Hangbin Liu) [RHEL-84558]
- selftests: net: fix grammar in reuseaddr_ports_exhausted.c log message (Hangbin Liu) [RHEL-84558]
- selftests: net: suppress ReST file generation when building selftests (Hangbin Liu) [RHEL-84558]
- selftests: net: give up on the cmsg_time accuracy on slow machines (Hangbin Liu) [RHEL-84558]
- selftests/net/ipsec: Fix Null pointer dereference in rtattr_pack() (Hangbin Liu) [RHEL-84558]
- selftests/net/forwarding: teamd command not found (Hangbin Liu) [RHEL-84558]
- selftests: drv-net: assume stats refresh is 0 if no ethtool -c support (Hangbin Liu) [RHEL-84558]
- selftests: forwarding: add a pvid_change test to bridge_vlan_unaware (Hangbin Liu) [RHEL-84558]
- selftests/net: call sendmmsg via udpgso_bench.sh (Hangbin Liu) [RHEL-84558]
- selftests: net: test extacks in netlink dumps (Hangbin Liu) [RHEL-84558]
- selftests: net: add more info to error in bpf_offload (Hangbin Liu) [RHEL-84558]
- selftests/net: Fix ./ns-XXXXXX not cleanup (Hangbin Liu) [RHEL-84558]
- selftests: net: add new ioam tests (Hangbin Liu) [RHEL-84558]
- selftests: net: remove ioam tests (Hangbin Liu) [RHEL-84558]
- selftests: net: csum: Clean up recv_verify_packet_ipv6 (Hangbin Liu) [RHEL-84558]
- Fix mmu notifiers for range-based invalidates (Charles Mirabile) [RHEL-83460]
- netfilter: nf_conncount: Fully initialize struct nf_conncount_tuple in insert_tree() (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_conncount: garbage collection is not skipped when jiffies wrap around (CKI Backport Bot) [RHEL-84544]
- netfilter: nft_flow_offload: update tcp state flags under lock (CKI Backport Bot) [RHEL-84544]
- netfilter: nft_flow_offload: clear tcp MAXACK flag before moving to slowpath (CKI Backport Bot) [RHEL-84544]
- netfilter: conntrack: rework offload nf_conn timeout extension logic (CKI Backport Bot) [RHEL-84544]
- netfilter: conntrack: remove skb argument from nf_ct_refresh (CKI Backport Bot) [RHEL-84544]
- netfilter: conntrack: add conntrack event timestamp (CKI Backport Bot) [RHEL-84544]
- netfilter: xt_hashlimit: htable_selective_cleanup() optimization (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: make destruction work queue pernet (CKI Backport Bot) [RHEL-84544]
- netfilter: nft_exthdr: fix offset with ipv4_find_option() (CKI Backport Bot) [RHEL-84544]
- netfilter: nft_ct: Use __refcount_inc() for per-CPU nft_ct_pcpu_template. (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: allocate element update information dynamically (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: switch trans_elem to real flex array (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: prepare nft audit for set element compaction (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: prepare for multiple elements in nft_trans_elem structure (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: add nft_trans_commit_list_add_elem helper (CKI Backport Bot) [RHEL-84544]
- netfilter: nf_tables: prefer nft_trans_elem_alloc helper (CKI Backport Bot) [RHEL-84544]
- netfilter: nfnetlink: Report extack policy errors for batched ops (CKI Backport Bot) [RHEL-84544]
- padata: avoid UAF for reorder_work (Waiman Long) [RHEL-81531] {CVE-2025-21726}
- padata: fix UAF in padata_reorder (Waiman Long) [RHEL-81531]
- padata: add pd get/put refcnt helper (Waiman Long) [RHEL-81531]
- padata: fix sysfs store callback check (Waiman Long) [RHEL-81531]
- padata: Clean up in padata_do_multithreaded() (Waiman Long) [RHEL-81531]
- RDMA/core: Support link status events dispatching (Kamal Heib) [RHEL-78090]
- RDMA/core: Add ib_query_netdev_port() to query netdev port by IB device. (Kamal Heib) [RHEL-78090]
- RDMA/core: Remove unused ib_copy_path_rec_from_user (Kamal Heib) [RHEL-78090]
- RDMA/core: Remove unused ibdev_printk (Kamal Heib) [RHEL-78090]
- RDMA/core: Remove unused ib_find_exact_cached_pkey (Kamal Heib) [RHEL-78090]
- RDMA/core: Remove unused ib_ud_header_unpack (Kamal Heib) [RHEL-78090]
- RDMA/srp: Fix error handling in srp_add_port (Kamal Heib) [RHEL-78090]
- net: Add options as a flexible array to struct ip_tunnel_info (Paolo Valerio) [RHEL-64164]
- ip_tunnel: Use ip_tunnel_info() helper instead of 'info + 1' (Paolo Valerio) [RHEL-64164]
- redhat: drop Y issues from changelog (Jan Stancek)
- vxlan: check vxlan_vnigroup_init() return value (CKI Backport Bot) [RHEL-81519] {CVE-2025-21790}
- selftests/mm: run_vmtests.sh: fix half_ufd_size_MB calculation (Rafael Aquini) [RHEL-80077]
- selftests: bonding: fix incorrect mac address (Hangbin Liu) [RHEL-59463]
- bonding: fix incorrect MAC address setting to receive NS messages (Hangbin Liu) [RHEL-59463]
- mm/hugetlb: fix hugepage allocation for interleaved memory nodes (CKI Backport Bot) [RHEL-62726]
- main.c: fix initcall blacklisted (Tomas Henzl) [RHEL-83271]
- pm: cpupower: remove hard-coded topology depth values (Steve Best) [RHEL-86398]
- pm: cpupower: Fix cmd_monitor() error legs to free cpu_topology (Steve Best) [RHEL-86398]
- cpupower: monitor: Exit with error status if execvp() fail (Steve Best) [RHEL-86398]
- tools/power turbostat: v2025.05.06 (Steve Best) [RHEL-86246]
- tools/power turbostat: disable "cpuidle" invocation counters, by default (Steve Best) [RHEL-86246]
- tools/power turbostat: re-factor sysfs code (Steve Best) [RHEL-86246]
- tools/power turbostat: Restore GFX sysfs fflush() call (Steve Best) [RHEL-86246]
- tools/power turbostat: report CoreThr per measurement interval (Steve Best) [RHEL-86246]
- tools/power turbostat: Increase CPU_SUBSET_MAXCPUS to 8192 (Steve Best) [RHEL-86246]
- tools/power turbostat: Add idle governor statistics reporting (Steve Best) [RHEL-86246]
- tools/power turbostat: Fix names matching (Steve Best) [RHEL-86246]
- tools/power turbostat: Allow Zero return value for some RAPL registers (Steve Best) [RHEL-86246]
- tools/power turbostat: Clustered Uncore MHz counters should honor show/hide options (Steve Best) [RHEL-86246]
- x86/cpu: Fix #define name for Intel CPU model 0x5A (Steve Best) [RHEL-86246]
- vxlan: Fix uninit-value in vxlan_vnifilter_dump() (Guillaume Nault) [RHEL-84555]
- NFS: Fix potential buffer overflowin nfs_sysfs_link_rpc_client() (CKI Backport Bot) [RHEL-81067] {CVE-2024-54456}
- net: fix NULL pointer dereference in l3mdev_l3_rcv (Davide Caratti) [RHEL-84550]
- ipvlan: ensure network headers are in skb linear part (Davide Caratti) [RHEL-84550] {CVE-2025-21891}
- tipc: Reduce scope for the variable “fdefq” in tipc_link_tnl_prepare() (Xin Long) [RHEL-84567]
- tipc: re-order conditions in tipc_crypto_key_rcv() (Xin Long) [RHEL-84567]
- net: tipc: remove one synchronize_net() from tipc_nametbl_stop() (Xin Long) [RHEL-84567]
- pnfs/flexfiles: retry getting layout segment for reads (Benjamin Coddington) [RHEL-77609]
- nfs: fix incorrect error handling in LOCALIO (Benjamin Coddington) [RHEL-77609]
- nfs: probe for LOCALIO when v3 client reconnects to server (Benjamin Coddington) [RHEL-77609]
- nfs: probe for LOCALIO when v4 client reconnects to server (Benjamin Coddington) [RHEL-77609]
- nfs/localio: remove redundant code and simplify LOCALIO enablement (Benjamin Coddington) [RHEL-77609]
- nfs_common: add nfs_localio trace events (Benjamin Coddington) [RHEL-77609]
- nfs_common: track all open nfsd_files per LOCALIO nfs_client (Benjamin Coddington) [RHEL-77609]
- nfs_common: rename nfslocalio nfs_uuid_lock to nfs_uuids_lock (Benjamin Coddington) [RHEL-77609]
- nfsd: nfsd_file_acquire_local no longer returns GC'd nfsd_file (Benjamin Coddington) [RHEL-77609]
- nfsd: rename nfsd_serv_ prefixed methods and variables with nfsd_net_ (Benjamin Coddington) [RHEL-77609]
- nfsd: update percpu_ref to manage references on nfsd_net (Benjamin Coddington) [RHEL-77609]
- nfs: cache all open LOCALIO nfsd_file(s) in client (Benjamin Coddington) [RHEL-77609]
- nfs_common: move localio_lock to new lock member of nfs_uuid_t (Benjamin Coddington) [RHEL-77609]
- nfs_common: rename functions that invalidate LOCALIO nfs_clients (Benjamin Coddington) [RHEL-77609]
- nfsd: add nfsd_file_{get,put} to 'nfs_to' nfsd_localio_operations (Benjamin Coddington) [RHEL-77609]
- nfs/localio: add direct IO enablement with sync and async IO support (Benjamin Coddington) [RHEL-77609]
- NFS: RHEL-10 disable localio (Benjamin Coddington) [RHEL-80503]

* Wed Apr 09 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-72.el10]
- mei: me: add panther lake P DID (Steve Best) [RHEL-79719]
- s390/diag: Move diag.c to diag specific folder (Mete Durlu) [RHEL-72674]
- s390/diag324: Retrieve power readings via diag 0x324 (Mete Durlu) [RHEL-72674]
- s390/diag: Create misc device /dev/diag (Mete Durlu) [RHEL-72674]
- powerpc/pseries/iommu: memory notifier incorrectly adds TCEs for pmemory (Mamatha Inamdar) [RHEL-85949]
- rtc: pcf85063: fix potential OOB write in PCF85063 NVMEM read (CKI Backport Bot) [RHEL-82459] {CVE-2024-58069}
- PCI: vmd: Make vmd_dev::cfg_lock a raw_spinlock_t type (Myron Stowe) [RHEL-83150]
- redhat/configs: disable CONFIG_NVME_TARGET_PCI_EPF (Maurizio Lombardi) [RHEL-83544]
- nvmet: pci-epf: Do not add an IRQ vector if not needed (Maurizio Lombardi) [RHEL-83544]
- nvmet: pci-epf: Set NVMET_PCI_EPF_Q_LIVE when a queue is fully created (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: fix stuck reset on concurrent DPC and HP (Maurizio Lombardi) [RHEL-83544]
- block: change blk_mq_add_to_batch() third argument type to bool (Maurizio Lombardi) [RHEL-83544]
- nvme: move error logging from nvme_end_req() to __nvme_end_req() (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: fix signedness bug in nvme_tcp_init_connection() (Maurizio Lombardi) [RHEL-83544]
- nvmet-tcp: Fix a possible sporadic response drops in weakly ordered arch (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: fix potential memory corruption in nvme_tcp_recv_pdu() (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: Fix a C2HTermReq error message (Maurizio Lombardi) [RHEL-83544]
- nvmet: remove old function prototype (Maurizio Lombardi) [RHEL-83544]
- nvme-ioctl: fix leaked requests on mapping error (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: skip CMB blocks incompatible with PCI P2P DMA (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: clean up CMBMSC when registering CMB fails (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: fix possible UAF in nvme_tcp_poll (Maurizio Lombardi) [RHEL-83544]
- nvme: only allow entering LIVE from CONNECTING state (Maurizio Lombardi) [RHEL-83544]
- nvme-fc: rely on state transitions to handle connectivity loss (Maurizio Lombardi) [RHEL-83544]
- apple-nvme: Support coprocessors left idle (Maurizio Lombardi) [RHEL-83544]
- apple-nvme: Release power domains when probe fails (Maurizio Lombardi) [RHEL-83544]
- nvmet: Use enum definitions instead of hardcoded values (Maurizio Lombardi) [RHEL-83544]
- nvme: Cleanup the definition of the controller config register fields (Maurizio Lombardi) [RHEL-83544]
- nvme/ioctl: add missing space in err message (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: fix connect failure on receiving partial ICResp PDU (Maurizio Lombardi) [RHEL-83544]
- nvme: tcp: Fix compilation warning with W=1 (Maurizio Lombardi) [RHEL-83544]
- nvmet: pci-epf: Avoid RCU stalls under heavy workload (Maurizio Lombardi) [RHEL-83544]
- nvmet: pci-epf: Do not uselessly write the CSTS register (Maurizio Lombardi) [RHEL-83544]
- nvmet: pci-epf: Correctly initialize CSTS when enabling the controller (Maurizio Lombardi) [RHEL-83544]
- nvmet-rdma: recheck queue state is LIVE in state lock in recv done (Maurizio Lombardi) [RHEL-83544]
- nvmet: Fix crash when a namespace is disabled (Maurizio Lombardi) [RHEL-83544] {CVE-2025-21850}
- nvme-tcp: add basic support for the C2HTermReq PDU (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: quirk Acer FA100 for non-uniqueue identifiers (Maurizio Lombardi) [RHEL-83544]
- nvme-fc: use ctrl state getter (Maurizio Lombardi) [RHEL-83544]
- nvme: make nvme_tls_attrs_group static (Maurizio Lombardi) [RHEL-83544]
- nvmet: add a missing endianess conversion in nvmet_execute_admin_connect (Maurizio Lombardi) [RHEL-83544]
- nvmet: the result field in nvmet_alloc_ctrl_args is little endian (Maurizio Lombardi) [RHEL-83544]
- nvmet: fix a memory leak in controller identify (Maurizio Lombardi) [RHEL-83544]
- nvme-fc: do not ignore connectivity loss during connecting (Maurizio Lombardi) [RHEL-83544]
- nvme: handle connectivity loss in nvme_set_queue_count (Maurizio Lombardi) [RHEL-83544]
- nvme-fc: go straight to connecting state when initializing (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: Add TUXEDO IBP Gen9 to Samsung sleep quirk (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: Add TUXEDO InfinityFlex to Samsung sleep quirk (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: remove redundant dma frees in hmb (Maurizio Lombardi) [RHEL-83544]
- nvmet: fix rw control endian access (Maurizio Lombardi) [RHEL-83544]
- nvme: fix bogus kzalloc() return check in nvme_init_effects_log() (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: use correct size to free the hmb buffer (Maurizio Lombardi) [RHEL-83544]
- nvme: Add error path for xa_store in nvme_init_effects (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: fix comment typo (Maurizio Lombardi) [RHEL-83544]
- nvmet: New NVMe PCI endpoint function target driver (Maurizio Lombardi) [RHEL-83544]
- nvmet: Implement arbitration feature support (Maurizio Lombardi) [RHEL-83544]
- nvmet: Implement interrupt config feature support (Maurizio Lombardi) [RHEL-83544]
- nvmet: Implement interrupt coalescing feature support (Maurizio Lombardi) [RHEL-83544]
- nvmet: Implement host identifier set feature support (Maurizio Lombardi) [RHEL-83544]
- nvmet: Introduce get/set_feature controller operations (Maurizio Lombardi) [RHEL-83544]
- nvmet: Do not require SGL for PCI target controller commands (Maurizio Lombardi) [RHEL-83544]
- nvmet: Add support for I/O queue management admin commands (Maurizio Lombardi) [RHEL-83544]
- nvmet: Introduce nvmet_sq_create() and nvmet_cq_create() (Maurizio Lombardi) [RHEL-83544]
- nvmet: Introduce nvmet_req_transfer_len() (Maurizio Lombardi) [RHEL-83544]
- nvmet: Improve nvmet_alloc_ctrl() interface and implementation (Maurizio Lombardi) [RHEL-83544]
- nvme: Add PCI transport type (Maurizio Lombardi) [RHEL-83544]
- nvmet: Add drvdata field to struct nvmet_ctrl (Maurizio Lombardi) [RHEL-83544]
- nvmet: Introduce nvmet_get_cmd_effects_admin() (Maurizio Lombardi) [RHEL-83544]
- nvmet: Export nvmet_update_cc() and nvmet_cc_xxx() helpers (Maurizio Lombardi) [RHEL-83544]
- nvmet: Add vendor_id and subsys_vendor_id subsystem attributes (Maurizio Lombardi) [RHEL-83544]
- nvme: Move opcode string helper functions declarations (Maurizio Lombardi) [RHEL-83544]
- nvme: change return type of nvme_poll_cq() to bool (Maurizio Lombardi) [RHEL-83544]
- nvme: Add error check for xa_store in nvme_get_effects_log (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: Fix I/O queue cpu spreading for multiple controllers (Maurizio Lombardi) [RHEL-83544]
- nvmet: handle rw's limited retry flag (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: remove nvme_tcp_destroy_io_queues() (Maurizio Lombardi) [RHEL-83544]
- nvmet-loop: avoid using mutex in IO hotpath (Maurizio Lombardi) [RHEL-83544]
- nvmet: propagate npwg topology (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: 512 byte aligned dma pool segment quirk (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: simplify nvme_tcp_teardown_io_queues() (Maurizio Lombardi) [RHEL-83544]
- nvme-tcp: no need to quiesce admin_q in nvme_tcp_teardown_io_queues() (Maurizio Lombardi) [RHEL-83544]
- nvme-rdma: unquiesce admin_q before destroy it (Maurizio Lombardi) [RHEL-83544] {CVE-2024-49569}
- nvme-tcp: fix the memleak while create new ctrl failed (Maurizio Lombardi) [RHEL-83544] {CVE-2024-56632}
- nvmet: replace kmalloc + memset with kzalloc for data allocation (Maurizio Lombardi) [RHEL-83544]
- nvme-fabrics: handle zero MAXCMD without closing the connection (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: remove two deallocate zeroes quirks (Maurizio Lombardi) [RHEL-83544]
- nvme: don't apply NVME_QUIRK_DEALLOCATE_ZEROES when DSM is not supported (Maurizio Lombardi) [RHEL-83544]
- nvmet: use kzalloc instead of ZERO_PAGE in nvme_execute_identify_ns_nvm() (Maurizio Lombardi) [RHEL-83544]
- nvme: tuning pr code by using defined structs and macros (Maurizio Lombardi) [RHEL-83544]
- nvme: introduce change ptpl and iekey definition (Maurizio Lombardi) [RHEL-83544]
- nvme-fabrics: fix kernel crash while shutting down controller (Maurizio Lombardi) [RHEL-83544] {CVE-2024-53169}
- Revert "nvme: make keep-alive synchronous operation" (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: use sgls for all user requests if possible (Maurizio Lombardi) [RHEL-83544]
- nvme: define the remaining used sgls constants (Maurizio Lombardi) [RHEL-83544]
- nvme-pci: add support for sgl metadata (Maurizio Lombardi) [RHEL-83544]
- nvme/multipath: Fix RCU list traversal to use SRCU primitive (Maurizio Lombardi) [RHEL-83544]
- nvmet: add tracing of reservation commands (Maurizio Lombardi) [RHEL-83544]
- nvme: parse reservation commands's action and rtype to string (Maurizio Lombardi) [RHEL-83544]
- nvmet: report ns's vwc not present (Maurizio Lombardi) [RHEL-83544]
- nvme: check ns's volatile write cache not present (Maurizio Lombardi) [RHEL-83544]
- nvme: add rotational support (Maurizio Lombardi) [RHEL-83544]
- nvme: use command set independent id ns if available (Maurizio Lombardi) [RHEL-83544]
- nvmet: support for csi identify ns (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement rotational media information log (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement endurance groups (Maurizio Lombardi) [RHEL-83544]
- nvmet: declare 2.1 version compliance (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement crto property (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement supported features log (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement supported log pages (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement active command set ns list (Maurizio Lombardi) [RHEL-83544]
- nvmet: implement id ns for nvm command set (Maurizio Lombardi) [RHEL-83544]
- nvmet: support reservation feature (Maurizio Lombardi) [RHEL-83544]
- redhat/configs: enable CONFIG_AMD_3D_VCACHE for x86 on RHEL (Steve Best) [RHEL-67850]
- platform/x86/amd: amd_3d_vcache: Add AMD 3D V-Cache optimizer driver (Steve Best) [RHEL-67850]

* Tue Apr 08 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-71.el10]
- KVM: arm64: Unconditionally save+flush host FPSIMD/SVE/SME state (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Apply RESx settings to sysreg reset values (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Always evaluate HCR_EL2 using sanitising accessors (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix alignment of kvm_hyp_memcache allocations (Sebastian Ott) [RHEL-82297]
- tools headers: Sync arm64 kvm header with the kernel sources (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Initialize SCTLR_EL1 in __kvm_hyp_init_cpu() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Initialize HCR_EL2.E2H early (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Ensure a VMID is allocated before programming VTTBR_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix tcr_el2 initialisation in hVHE mode (Sebastian Ott) [RHEL-82297]
- KVM: arm64: vgic: Hoist SGI/PPI alloc from vgic_init() to kvm_create_vgic() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: timer: Drop warning on failed interrupt signalling (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Convert timer offset VA when accessed in HYP code (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Simplify warning in kvm_arch_vcpu_load_fp() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix __pkvm_host_mkyoung_guest() return value (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Simplify np-guest hypercalls (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Improve error handling from check_host_shared_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: timer: Don't adjust the EL2 virtual timer offset (Sebastian Ott) [RHEL-82297]
- KVM: arm64: timer: Correctly handle EL1 timer emulation when !FEAT_ECV (Sebastian Ott) [RHEL-82297]
- KVM: arm64: timer: Always evaluate the need for a soft timer (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix nested S2 MMU structures reallocation (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fail protected mode init if no vgic hardware is present (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Flush/sync debug state in protected mode (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Flush hyp bss section after initialization of variables in bss (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix selftests after sysreg field name update (Sebastian Ott) [RHEL-82297]
- coresight: Pass guest TRFCR value to KVM (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Support trace filtering for guests (Sebastian Ott) [RHEL-82297]
- KVM: arm64: coresight: Give TRBE enabled state to KVM (Sebastian Ott) [RHEL-82297]
- coresight: trbe: Remove redundant disable call (Sebastian Ott) [RHEL-82297]
- arm64/sysreg/tools: Move TRFCR definitions to sysreg (Sebastian Ott) [RHEL-82297]
- tools: arm64: Update sysreg.h header files (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Explicitly handle BRBE traps as UNDEFINED (Sebastian Ott) [RHEL-82297]
- KVM: arm64: vgic: Use str_enabled_disabled() in vgic_v3_probe() (Sebastian Ott) [RHEL-82297]
- arm64: kvm: Introduce nvhe stack size constants (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix nVHE stacktrace VA bits mask (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix FEAT_MTE in pKVM (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Work around x1e's CNTVOFF_EL2 bogosity (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Sanitise CNTHCTL_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Propagate CNTHCTL_EL2.EL1NV{P,V}CT bits (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Add trap routing for CNTHCTL_EL2.EL1{NVPCT,NVVCT,TVT,TVCT} (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Handle counter access early in non-HYP context (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Accelerate EL0 counter accesses from hypervisor context (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Accelerate EL0 timer read accesses when FEAT_ECV in use (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Use FEAT_ECV to trap access to EL0 timers (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Publish emulated timer interrupt state in the in-memory state (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Sync nested timer state with FEAT_NV2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Add handling of EL2-specific timer registers (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Advertise the lack of AArch32 EL0 support (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Use kvm_vcpu_has_feature() directly for struct kvm (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Convert the SVE guest vcpu flag to a vm flag (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove PtrAuth guest vcpu flag (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix the value of the CPTR_EL2 RES1 bitmask for nVHE (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Refactor kvm_reset_cptr_el2() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Calculate cptr_el2 traps on activating traps (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove redundant setting of HCR_EL2 trap bit (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove fixed_config.h header (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Rework specifying restricted features for protected VMs (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Set protected VM traps based on its view of feature registers (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix RAS trapping in pKVM for protected VMs (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Initialize feature id registers for protected VMs (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Use KVM extension checks for allowed protected VM capabilities (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove KVM_ARM_VCPU_POWER_OFF from protected VMs allowed features in pKVM (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Move checking protected vcpu features to a separate function (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Group setting traps for protected VMs by control register (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Consolidate allowed and restricted VM feature checks (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Plumb the pKVM MMU in KVM (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce the EL1 pKVM MMU (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_tlb_flush_vmid() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_mkyoung_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_test_clear_young_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_wrprotect_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_relax_guest_perms() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_unshare_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_host_share_guest() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Introduce __pkvm_vcpu_{load,put}() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add {get,put}_pkvm_hyp_vm() helpers (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Make kvm_pgtable_stage2_init() a static inline function (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Pass walk flags to kvm_pgtable_stage2_relax_perms (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Pass walk flags to kvm_pgtable_stage2_mkyoung (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Move host page ownership tracking to the hyp vmemmap (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Make hyp_page::order a u8 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Move enum pkvm_page_state to memory.h (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Change the layout of enum pkvm_page_state (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Promote guest ownership for DBGxVR/DBGxCR reads (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fold DBGxVR/DBGxCR accessors into common set (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Avoid reading ID_AA64DFR0_EL1 for debug save/restore (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Honor MDCR_EL2.TDE routing for debug exceptions (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Manage software step state at load/put (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Don't hijack guest context MDSCR_EL1 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Compute MDCR_EL2 at vcpu_load() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Reload vCPU for accesses to OSLAR_EL1 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Use debug_owner to track if debug regs need save/restore (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove vestiges of debug_ptr (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Remove debug tracepoints (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Select debug state to save/restore based on debug owner (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Clean up KVM_SET_GUEST_DEBUG handler (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Evaluate debug owner at vcpu_load() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Write MDCR_EL2 directly from kvm_arm_setup_mdcr_el2() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Move host SME/SVE tracking flags to host data (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Track presence of SPE/TRBE in kvm_host_data instead of vCPU (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Get rid of __kvm_get_mdcr_el2() and related warts (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Drop MDSCR_EL1_DEBUG_MASK (Sebastian Ott) [RHEL-82297]
- arm64/kvm: Avoid invalid physical addresses to signal owner updates (Sebastian Ott) [RHEL-82297]
- arm64/kvm: Configure HYP TCR.PS/DS based on host stage1 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Only apply PMCR_EL0.P to the guest range of counters (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Reload PMU events upon MDCR_EL2.HPME change (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Use KVM_REQ_RELOAD_PMU to handle PMCR_EL0.E change (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add unified helper for reprogramming counters by mask (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Always check the state from hyp_ack_unshare() (Sebastian Ott) [RHEL-82297]
- arm64: Fix usage of new shifted MDCR_EL2 values (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Use MDCR_EL2.HPME to evaluate overflow of hyp counters (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Mark set_sysreg_masks() as inline to avoid build failure (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Make L1Ip feature in CTR_EL0 writable from userspace (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Reprogram PMU events affected by nested transition (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Apply EL2 event filtering when in hyp context (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Honor MDCR_EL2.HLP (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Honor MDCR_EL2.HPME (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add helpers to determine if PMC counts at a given EL (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Adjust range of accessible PMCs according to HPMN (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Rename kvm_pmu_valid_counter_mask() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Advertise support for FEAT_HPMN0 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Describe trap behaviour of MDCR_EL2.HPMN (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Honor MDCR_EL2.{TPM, TPMCR} in Host EL0 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Reinject traps that take effect in Host EL0 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Rename BEHAVE_FORWARD_ANY (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Allow coarse-grained trap combos to use complex traps (Sebastian Ott) [RHEL-82297]
- arm64: sysreg: Add new definitions for ID_AA64DFR0_EL1 (Sebastian Ott) [RHEL-82297]
- arm64: sysreg: Migrate MDCR_EL2 definition to table (Sebastian Ott) [RHEL-82297]
- arm64: sysreg: Describe ID_AA64DFR2_EL1 fields (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Describe RES0/RES1 bits of MDCR_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: selftests: Test ID_AA64PFR0.MPAM isn't completely ignored (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Disable MPAM visibility by default and ignore VMM writes (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add a macro for creating filtered sys_reg_descs entries (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix missing traps of guest accesses to the MPAM registers (Sebastian Ott) [RHEL-82297]
- arm64: cpufeature: discover CPU support for MPAM (Sebastian Ott) [RHEL-82297]
- arm64: head.S: Initialise MPAM EL2 registers and disable traps (Sebastian Ott) [RHEL-82297]
- arm64/sysreg: Convert existing MPAM sysregs and add the remaining entries (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Handle WXN attribute (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Handle stage-1 permission overlays (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Make PAN conditions part of the S1 walk context (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Disable hierarchical permissions when POE is enabled (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add POE save/restore for AT emulation fast-path (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add save/restore support for POR_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add basic support for POR_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add kvm_has_s1poe() helper (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Subject S1PIE/S1POE registers to HCR_EL2.{TVM,TRVM} (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Drop bogus CPTR_EL2.E0POE trap routing (Sebastian Ott) [RHEL-82297]
- arm64: Add encoding for POR_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Rely on visibility to let PIR*_ELx/TCR2_ELx UNDEF (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Hide S1PIE registers from userspace when disabled for guests (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Hide TCR2_EL1 from userspace when disabled for guests (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Define helper for EL2 registers with custom visibility (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add a composite EL2 visibility helper (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Implement AT S1PIE support (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Disable hierarchical permissions when S1PIE is enabled (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Split S1 permission evaluation into direct and hierarchical parts (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add AT fast-path support for S1PIE (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Handle PIR{,E0}_EL2 traps (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add save/restore for PIR{,E0}_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add PIR{,E0}_EL2 to the sysreg arrays (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add save/restore for TCR2_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Sanitise TCR2_EL2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Save/Restore vEL2 sysregs (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add TCR2_EL2 to the sysreg arrays (Sebastian Ott) [RHEL-82297]
- arm64: Define ID_AA64MMFR1_EL1.HAFDBS advertising FEAT_HAFT (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Extend masking facility to arbitrary registers (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Handle CNTHCTL_EL2 specially (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nv: Add missing EL2->EL1 mappings in get_el2_to_el1_mapping() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Drop useless struct s2_mmu in __kvm_at_s1e2() (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Don't mark "struct page" accessed when making SPTE young (Sebastian Ott) [RHEL-82297]
- KVM: arm64: nvhe: Pass through PSCI v1.3 SYSTEM_OFF2 call (Sebastian Ott) [RHEL-82297]
- KVM: selftests: Add test for PSCI SYSTEM_OFF2 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add support for PSCI v1.2 and v1.3 (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Add PSCI v1.3 SYSTEM_OFF2 function for hibernation (Sebastian Ott) [RHEL-82297]
- arm64: Remove VNCR definition for PIRE0_EL2 (Sebastian Ott) [RHEL-82297]
- arm64: Add encoding for PIRE0_EL2 (Sebastian Ott) [RHEL-82297]
- arm64: Drop SKL0/SKL1 from TCR2_EL2 (Sebastian Ott) [RHEL-82297]
- firmware/psci: Add definitions for PSCI v1.3 specification (Sebastian Ott) [RHEL-82297]
- KVM: arm64: Fix set_id_regs selftest for ASIDBITS becoming unwritable (Sebastian Ott) [RHEL-82297]
- redhat/configs: Enable CONFIG_VDPA_USER on RHEL10 (Cindy Lu) [RHEL-76477]

* Wed Apr 02 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-70.el10]
- PCI/ACPI: Constify 'struct bin_attribute' (Myron Stowe) [RHEL-85241]
- PCI/P2PDMA: Constify 'struct bin_attribute' (Myron Stowe) [RHEL-85241]
- PCI/VPD: Constify 'struct bin_attribute' (Myron Stowe) [RHEL-85241]
- PCI/sysfs: Constify 'struct bin_attribute' (Myron Stowe) [RHEL-85241]
- cpu: Remove spurious NULL in attribute_group definition (Myron Stowe) [RHEL-85241]
- s390/con3215: Remove spurious NULL in attribute_group definition (Myron Stowe) [RHEL-85241]
- perf: arm-ni: Remove spurious NULL in attribute_group definition (Myron Stowe) [RHEL-85241]
- driver core: Constify bin_attribute definitions (Myron Stowe) [RHEL-85241]
- sysfs: attribute_group: allow registration of const bin_attribute (Myron Stowe) [RHEL-85241]
- cdx: Fix cdx_mmap_resource() after constifying attr in ->mmap() (Myron Stowe) [RHEL-85241]
- driver core: Constify attribute arguments of binary attributes (Myron Stowe) [RHEL-85241]
- sysfs: bin_attribute: add const read/write callback variants (Myron Stowe) [RHEL-85241]
- sysfs: implement all BIN_ATTR_* macros in terms of __BIN_ATTR() (Myron Stowe) [RHEL-85241]
- sysfs: treewide: constify attribute callback of bin_attribute::llseek() (Myron Stowe) [RHEL-85241]
- sysfs: treewide: constify attribute callback of bin_attribute::mmap() (Myron Stowe) [RHEL-85241]
- sysfs: treewide: constify attribute callback of bin_is_visible() (Myron Stowe) [RHEL-85241]
- nvmem: core: calculate bin_attribute size through bin_size() (Myron Stowe) [RHEL-85241]
- PCI/sysfs: Calculate bin_attribute size through bin_size() (Myron Stowe) [RHEL-85241]
- sysfs: introduce callback attribute_group::bin_size (Myron Stowe) [RHEL-85241]
- sysfs: explicitly pass size to sysfs_add_bin_file_mode_ns() (Myron Stowe) [RHEL-85241]
- sched/stats: Print domain name in /proc/schedstat (Phil Auld) [RHEL-24185]
- docs: Update Schedstat version to 17 (Phil Auld) [RHEL-24185]
- sched/fair: Cleanup in migrate_degrades_locality() to improve readability (Phil Auld) [RHEL-24185]
- sched: Report the different kinds of imbalances in /proc/schedstat (Phil Auld) [RHEL-24185]
- sched: Move sched domain name out of CONFIG_SCHED_DEBUG (Phil Auld) [RHEL-24185]
- sched/fair: Fix value reported by hot tasks pulled in /proc/schedstat (Phil Auld) [RHEL-24185]
- redhat: selftests/bpf: Add cpuv4 variant (Viktor Malik) [RHEL-82993]
- bonding: delete always true device check (Hangbin Liu) [RHEL-84541]
- Revert "io_uring/uring_cmd: defer SQE copying until it's needed" (Jeff Moyer) [RHEL-82698] {CVE-2025-21837}
- ALSA: hda/tas2781: Fix index issue in tas2781 hda SPI driver (CKI Backport Bot) [RHEL-81723]
- ALSA: hda/tas2781: Update tas2781 hda SPI driver (CKI Backport Bot) [RHEL-81723]
- redhat/configs: Enable CONFIG_CPUFREQ_ARCH_CUR_FREQ (Jennifer Berringer) [RHEL-80968]
- arch_topology: init capacity_freq_ref to 0 (Jennifer Berringer) [RHEL-80968]
- arm64: Utilize for_each_cpu_wrap for reference lookup (Jennifer Berringer) [RHEL-80968]
- arm64: Update AMU-based freq scale factor on entering idle (Jennifer Berringer) [RHEL-80968]
- arm64: Provide an AMU-based version of arch_freq_get_on_cpu (Jennifer Berringer) [RHEL-80968]
- cpufreq: Introduce an optional cpuinfo_avg_freq sysfs entry (Jennifer Berringer) [RHEL-80968]
- cpufreq: Allow arch_freq_get_on_cpu to return an error (Jennifer Berringer) [RHEL-80968]
- arm64: amu: Delay allocating cpumask for AMU FIE support (Jennifer Berringer) [RHEL-80968]
- Revert "cxl/acpi: Fix load failures due to single window creation failure" (John W. Linville) [RHEL-82540]
- selftests: livepatch: test livepatching a kprobed function (Ryan Sullivan) [RHEL-80216]
- selftests: livepatch: save and restore kprobe state (Ryan Sullivan) [RHEL-80216]
- selftests: livepatch: rename KLP_SYSFS_DIR to SYSFS_KLP_DIR (Ryan Sullivan) [RHEL-80216]
- PCI: layerscape: Fix arg_count to syscon_regmap_lookup_by_phandle_args() (Myron Stowe) [RHEL-83611]
- misc: pci_endpoint_test: Fix pci_endpoint_test_bars_read_bar() error handling (Myron Stowe) [RHEL-83611]
- tools/Makefile: Remove pci target (Myron Stowe) [RHEL-83611]
- PCI: Avoid FLR for Mediatek MT7922 WiFi (Myron Stowe) [RHEL-83611]
- PCI: Fix BUILD_BUG_ON usage for old gcc (Myron Stowe) [RHEL-83611]
- PCI/ASPM: Fix L1SS saving (Myron Stowe) [RHEL-83611]
- PCI: Restore original INTX_DISABLE bit by pcim_intx() (Myron Stowe) [RHEL-83611]
- Documentation: Fix pci=config_acs= example (Myron Stowe) [RHEL-83611]
- PCI: Remove redundant PCI_VSEC_HDR and PCI_VSEC_HDR_LEN_SHIFT (Myron Stowe) [RHEL-83611]
- PCI: Don't include 'pm_wakeup.h' directly (Myron Stowe) [RHEL-83611]
- PCI: Update code comment on PCI_EXP_LNKCAP_SLS for PCIe r3.0 (Myron Stowe) [RHEL-83611]
- PCI: xilinx-cpm: Add support for Versal CPM5 Root Port Controller 1 (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: xilinx-cpm: Add compatible string for CPM5 host1 (Myron Stowe) [RHEL-83611]
- PCI: rockchip: Refactor rockchip_pcie_disable_clocks() signature (Myron Stowe) [RHEL-83611]
- PCI: rockchip: Simplify reset control handling by using reset_control_bulk*() function (Myron Stowe) [RHEL-83611]
- PCI: rockchip: Simplify clock handling by using clk_bulk*() functions (Myron Stowe) [RHEL-83611]
- PCI: rcar-ep: Fix incorrect variable used when calling devm_request_mem_region() (Myron Stowe) [RHEL-83611]
- PCI: mvebu: Enable module autoloading (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: microchip,pcie-host: Allow dma-noncoherent (Myron Stowe) [RHEL-83611]
- PCI: microchip: Set inbound address translation for coherent or non-coherent mode (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Enable async probe by default (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Avoid PCIe resetting via PERST# for Airoha EN7581 SoC (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Rely on msleep() in mtk_pcie_en7581_power_up() (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Move reset delay in mtk_pcie_en7581_power_up() (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Add comment about initialization order in mtk_pcie_en7581_power_up() (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Move reset/assert callbacks in .power_up() (Myron Stowe) [RHEL-83611]
- PCI: mediatek-gen3: Rely on clk_bulk_prepare_enable() in mtk_pcie_en7581_power_up() (Myron Stowe) [RHEL-83611]
- PCI: layerscape: Use syscon_regmap_lookup_by_phandle_args (Myron Stowe) [RHEL-83611]
- PCI: imx6: Clean up comments and whitespace (Myron Stowe) [RHEL-83611]
- PCI: imx6: Remove surplus imx7d_pcie_init_phy() function (Myron Stowe) [RHEL-83611]
- PCI: imx6: Add missing reference clock disable logic (Myron Stowe) [RHEL-83611]
- PCI: imx6: Deassert apps_reset in imx_pcie_deassert_core_reset() (Myron Stowe) [RHEL-83611]
- PCI: imx6: Skip controller_id generation logic for i.MX7D (Myron Stowe) [RHEL-83611]
- PCI: imx6: Fetch dbi2 and iATU base addesses from DT (Myron Stowe) [RHEL-83611]
- PCI: imx6: Configure PHY based on Root Complex or Endpoint mode (Myron Stowe) [RHEL-83611]
- PCI: imx6: Add Refclk for i.MX95 PCIe (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: fsl,imx6q-pcie: Add Refclk for i.MX95 RC (Myron Stowe) [RHEL-83611]
- PCI: imx6: Add i.MX8Q PCIe Endpoint (EP) support (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: fsl,imx6q-pcie-ep: Add compatible string fsl,imx8q-pcie-ep (Myron Stowe) [RHEL-83611]
- PCI: dwc: Simplify config resource lookup (Myron Stowe) [RHEL-83611]
- of: address: Add parent_bus_addr to struct of_pci_range (Myron Stowe) [RHEL-83611]
- PCI: imx6: Add i.MX8MQ, i.MX8Q and i.MX95 PM support (Myron Stowe) [RHEL-83611]
- PCI: imx6: Use DWC common suspend resume method (Myron Stowe) [RHEL-83611]
- PCI: dwc: Add dw_pcie_suspend_noirq(), dw_pcie_resume_noirq() stubs for !CONFIG_PCIE_DW_HOST (Myron Stowe) [RHEL-83611]
- PCI: dwc: Remove LTSSM state test in dw_pcie_suspend_noirq() (Myron Stowe) [RHEL-83611]
- PCI: dwc: Always stop link in the dw_pcie_suspend_noirq (Myron Stowe) [RHEL-83611]
- PCI: dw-rockchip: Don't wait for link since we can detect Link Up (Myron Stowe) [RHEL-83611]
- PCI: dw-rockchip: Enumerate endpoints based on dll_link_up IRQ (Myron Stowe) [RHEL-83611]
- PCI: qcom: Update ICC and OPP values after Link Up event (Myron Stowe) [RHEL-83611]
- PCI: qcom: Don't wait for link if we can detect Link Up (Myron Stowe) [RHEL-83611]
- PCI: dwc: Don't wait for link up if driver can detect Link Up event (Myron Stowe) [RHEL-83611]
- PCI: dwc: Fix potential truncation in dw_pcie_edma_irq_verify() (Myron Stowe) [RHEL-83611]
- PCI: dra7xx: Use syscon_regmap_lookup_by_phandle_args (Myron Stowe) [RHEL-83611]
- PCI: apple: Convert to {en,dis}able_device() callbacks (Myron Stowe) [RHEL-83611]
- PCI: host-generic: Allow {en,dis}able_device() to be provided via pci_ecam_ops (Myron Stowe) [RHEL-83611]
- PCI: imx6: Add IOMMU and ITS MSI support for i.MX95 (Myron Stowe) [RHEL-83611]
- PCI: Add enable_device() and disable_device() callbacks for bridges (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: qcom: Document the IPQ5424 PCIe controller (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: qcom,pcie-sm8550: Document 'global' interrupt (Myron Stowe) [RHEL-83611]
- dt-bindings: PCI: mobiveil: Convert mobiveil-pcie.txt to YAML (Myron Stowe) [RHEL-83611]
- selftests: pci_endpoint: Migrate to Kselftest framework (Myron Stowe) [RHEL-83611]
- selftests: Move PCI Endpoint tests from tools/pci to Kselftests (Myron Stowe) [RHEL-83611]
- misc: pci_endpoint_test: Fix IOCTL return value (Myron Stowe) [RHEL-83611]
- misc: pci_endpoint_test: Remove redundant 'remainder' test (Myron Stowe) [RHEL-83611]
- misc: pci_endpoint_test: Add consecutive BAR test (Myron Stowe) [RHEL-83611]
- misc: pci_endpoint_test: Add support for capabilities (Myron Stowe) [RHEL-83611]
- PCI: endpoint: pci-epf-test: Add support for capabilities (Myron Stowe) [RHEL-83611]
- PCI: endpoint: pci-epf-test: Fix check for DMA MEMCPY test (Myron Stowe) [RHEL-83611]
- PCI: endpoint: pci-epf-test: Set dma_chan_rx pointer to NULL on error (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Verify that requested BAR size is a power of two (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Add size check for fixed size BARs in pci_epc_set_bar() (Myron Stowe) [RHEL-83611]
- PCI: artpec6: Implement dw_pcie_ep operation get_features (Myron Stowe) [RHEL-83611]
- PCI: dwc: ep: Add 'address' alignment to 'size' check in dw_pcie_prog_ep_inbound_atu() (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Finish virtual EP removal in pci_epf_remove_vepf() (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Simplify pci_epc_get() (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Destroy the EPC device in devm_pci_epc_destroy() (Myron Stowe) [RHEL-83611]
- PCI: endpoint: Replace magic number '6' by PCI_STD_NUM_BARS (Myron Stowe) [RHEL-83611]
- PCI: switchtec: Add Microchip PCI100X device IDs (Myron Stowe) [RHEL-83611]
- PCI: Avoid putting some root ports into D3 on TUXEDO Sirius Gen1 (Myron Stowe) [RHEL-83611]
- PCI/sysfs: Remove unnecessary zero in initializer (Myron Stowe) [RHEL-83611]
- PCI/sysfs: Use __free() in reset_method_store() (Myron Stowe) [RHEL-83611]
- PCI/sysfs: Move reset related sysfs code to correct file (Myron Stowe) [RHEL-83611]
- PCI: of_property: Rename struct of_pci_range to of_pci_range_entry (Myron Stowe) [RHEL-83611]
- sparc/PCI: Update reference to devm_of_pci_get_host_bridge_resources() (Myron Stowe) [RHEL-83611]
- PCI: of: Simplify devm_of_pci_get_host_bridge_resources() interface (Myron Stowe) [RHEL-83611]
- PCI: of: Drop 'No bus range found' message (Myron Stowe) [RHEL-83611]
- PCI: Unexport of_pci_parse_bus_range() (Myron Stowe) [RHEL-83611]
- PCI: Add pcie_print_tlp_log() to print TLP Header and Prefix Log (Myron Stowe) [RHEL-83611]
- PCI: Add TLP Prefix reading to pcie_read_tlp_log() (Myron Stowe) [RHEL-83611]
- PCI: Store number of supported End-End TLP Prefixes (Myron Stowe) [RHEL-83611]
- PCI: Use unsigned int i in pcie_read_tlp_log() (Myron Stowe) [RHEL-83611]
- PCI: Use same names in pcie_read_tlp_log() prototype and definition (Myron Stowe) [RHEL-83611]
- PCI: Add defines for TLP Header/Prefix log sizes (Myron Stowe) [RHEL-83611]
- PCI: Move TLP Log handling to its own file (Myron Stowe) [RHEL-83611]
- PCI: Don't expose pcie_read_tlp_log() outside PCI subsystem (Myron Stowe) [RHEL-83611]
- PCI/DPC: Quirk PIO log size for Intel Raptor Lake-P (Myron Stowe) [RHEL-83611]
- PCI: Remove devres from pci_intx() (Myron Stowe) [RHEL-83611]
- net/ethernet: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- HID: amd_sfh: Use always-managed version of pcim_intx() (Myron Stowe) [RHEL-83611]
- wifi: qtnfmac: use always-managed version of pcim_intx() (Myron Stowe) [RHEL-83611]
- ata: Use always-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- PCI/MSI: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- vfio/pci: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- misc: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- ntb: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- drivers/xen: Use never-managed version of pci_intx() (Myron Stowe) [RHEL-83611]
- PCI: Export pci_intx_unmanaged() and pcim_intx() (Myron Stowe) [RHEL-83611]
- PCI: Encourage resource request API users to supply driver name (Myron Stowe) [RHEL-83611]
- PCI/ASPM: Save parent L1SS config in pci_save_aspm_l1ss_state() (Myron Stowe) [RHEL-83611]
- platform/x86/intel/pmc: Remove unneeded extern keyword in header (Steve Best) [RHEL-47465]
- platform/x86/intel/pmc: Remove unnecessary declarations in header (Steve Best) [RHEL-47465]
- platform/x86/intel/pmc: Add Panther Lake support to intel_pmc_core (Steve Best) [RHEL-47465]
- platform/x86:intel/pmc: Move arch specific action to init function (Steve Best) [RHEL-47465]
- platform/x86/intel/pmc: Add Arrow Lake U/H support to intel_pmc_core driver (Steve Best) [RHEL-47465]
- platform/x86/intel/pmc: Remove simple init functions (Steve Best) [RHEL-47465]
- platform/x86:intel/pmc: Create generic_core_init() for all platforms (Steve Best) [RHEL-47465]
- platform/x86/intel/pmc: Remove duplicate enum (Steve Best) [RHEL-47465]
- platform/x86:intel/pmc: Make tgl_core_generic_init() static (Steve Best) [RHEL-47465]
- nfsd: fix UAF when access ex_uuid or ex_stats (Olga Kornievskaia) [RHEL-80508] {CVE-2024-53216}
- SUNRPC: no need get cache ref when protected by rcu (Olga Kornievskaia) [RHEL-80508] {CVE-2024-53216}
- nfsd: no need get cache ref when protected by rcu (Olga Kornievskaia) [RHEL-80508] {CVE-2024-53216}
- SUNRPC: introduce cache_check_rcu to help check in rcu context (Olga Kornievskaia) [RHEL-80508] {CVE-2024-53216}
- net/sched: cls_api: fix error handling causing NULL dereference (CKI Backport Bot) [RHEL-83372] {CVE-2025-21857}
- af_packet: fix vlan_get_protocol_dgram() vs MSG_PEEK (Davide Caratti) [RHEL-80306] {CVE-2024-57901}
- redhat: kabi: update stablelist checksums (Čestmír Kalina) [RHEL-80552]
- shrinker: include rh_kabi.h (Čestmír Kalina) [RHEL-80552]
- mm/memcg: Exclude mem_cgroup/obj_cgroup pointer from kABI signature computation (Waiman Long) [RHEL-80552]
- net: stmmac: dwmac-tegra: Read iommu stream id from device tree (Izabela Bakollari) [RHEL-75653] {CVE-2025-21663}
- Revert "smb: client: fix chmod(2) regression with ATTR_READONLY" (Jan Stancek)
- crypto: api - Fix larval relookup type and mask (Herbert Xu) [RHEL-78993]

* Fri Mar 28 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-69.el10]
- redhat/configs: Enable CONFIG_BLK_CGROUP_PUNT_BIO (Neal Gompa) [RHEL-79711]
- block/Kconfig: Allow selecting BLK_CGROUP_PUNT_BIO (Neal Gompa) [RHEL-79711]
- perf script: Fix hangup in offline flamegraph report (Michael Petlan) [RHEL-57021]
- perf script: force stdin for flamegraph in live mode (Michael Petlan) [RHEL-57021]
- smb: client: fix regression with guest option (Paulo Alcantara) [RHEL-83856]
- KVM: selftests: Allow running a single iteration of dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Fix an off-by-one in the number of dirty_log_test iterations (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Set per-iteration variables at the start of each iteration (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Tighten checks around prev iter's last dirty page in ring (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Ensure guest writes min number of pages in dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: sefltests: Verify value of dirty_log_test last page isn't bogus (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Collect *all* dirty entries in each dirty_log_test iteration (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Print (previous) last_page on dirty page value mismatch (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Use continue to handle all "pass" scenarios in dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Post to sem_vcpu_stop if and only if vcpu_stop is true (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Keep dirty_log_test vCPU in guest until it needs to stop (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Honor "stop" request in dirty ring test (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Limit dirty_log_test's s390x workaround to s390x (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Continuously reap dirty ring while vCPU is running (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Read per-page value into local var when verifying dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Precisely track number of dirty/clear pages for each iteration (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Drop stale srandom() initialization from dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Drop signal/kick from dirty ring testcase (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Sync dirty_log_test iteration to guest *before* resuming (Maxim Levitsky) [RHEL-58941]
- KVM: selftests: Support multiple write retires in dirty_log_test (Maxim Levitsky) [RHEL-58941]
- KVM: VMX: read the PML log in the same order as it was written (Maxim Levitsky) [RHEL-58941]
- KVM: VMX: refactor PML terminology (Maxim Levitsky) [RHEL-58941]
- crypto: pcrypt - Call crypto layer directly when padata_do_parallel() return -EBUSY (Herbert Xu) [RHEL-80114] {CVE-2024-56690}
- erofs: fix blksize < PAGE_SIZE for file-backed mounts (Ian Kent) [RHEL-82421] {CVE-2024-56750}
- platform/x86/intel/vsec: Add support for Panther Lake (Steve Best) [RHEL-47411]
- bonding: report duplicate MAC address in all situations (Hangbin Liu) [RHEL-73803]
- ice: Fix signedness bug in ice_init_interrupt_scheme() (Petr Oros) [RHEL-80554]
- ice: init flow director before RDMA (Petr Oros) [RHEL-80554]
- ice: simplify VF MSI-X managing (Petr Oros) [RHEL-80554]
- ice: enable_rdma devlink param (Petr Oros) [RHEL-80554]
- ice: treat dyn_allowed only as suggestion (Petr Oros) [RHEL-80554]
- ice, irdma: move interrupts code to irdma (Petr Oros) [RHEL-80554]
- ice: get rid of num_lan_msix field (Petr Oros) [RHEL-80554]
- ice: remove splitting MSI-X between features (Petr Oros) [RHEL-80554]
- ice: devlink PF MSI-X max and min parameter (Petr Oros) [RHEL-80554]
- ice: ice_probe: init ice_adapter after HW init (Petr Oros) [RHEL-80554]
- ice: minor: rename goto labels from err to unroll (Petr Oros) [RHEL-80554]
- ice: split ice_init_hw() out from ice_init_dev() (Petr Oros) [RHEL-80554]
- ice: c827: move wait for FW to ice_init_hw() (Petr Oros) [RHEL-80554]
- ipv6: use RCU protection in ip6_default_advmss() (Guillaume Nault) [RHEL-81574] {CVE-2025-21765}
- net: add dev_net_rcu() helper (Guillaume Nault) [RHEL-81574] {CVE-2025-21765}
- objtool: Add bch2_trans_unlocked_error() to bcachefs noreturns (Radomir Vrbovsky) [RHEL-80715]
- objtool: Exclude __tracepoints data from ENDBR checks (Radomir Vrbovsky) [RHEL-80715]
- kbuild: Add Propeller configuration for kernel build (Radomir Vrbovsky) [RHEL-80715]
- AutoFDO: Enable machine function split optimization for AutoFDO (Radomir Vrbovsky) [RHEL-80715]
- AutoFDO: Enable -ffunction-sections for the AutoFDO build (Radomir Vrbovsky) [RHEL-80715]
- vmlinux.lds.h: Add markers for text_unlikely and text_hot sections (Radomir Vrbovsky) [RHEL-80715]
- openrisc: place exception table at the head of vmlinux (Radomir Vrbovsky) [RHEL-80715]
- vmlinux.lds.h: Adjust symbol ordering in text output section (Radomir Vrbovsky) [RHEL-80715]
- objtool: Fix unreachable instruction warnings for weak functions (Radomir Vrbovsky) [RHEL-80715]
- kbuild: Add AutoFDO support for Clang build (Radomir Vrbovsky) [RHEL-80715]
- reiserfs: The last commit (Radomir Vrbovsky) [RHEL-80715]
- objtool: Also include tools/include/uapi (Radomir Vrbovsky) [RHEL-80715]
- objtool: Detect non-relocated text references (Radomir Vrbovsky) [RHEL-80715]
- arch/x86/kernel/setup.c: fix rh_check_supported (Tomas Henzl) [RHEL-80866]
- intel_idle: Handle older CPUs, which stop the TSC in deeper C states, correctly (Steve Best) [RHEL-79459]
- intel_idle: add Clearwater Forest SoC support (Steve Best) [RHEL-79459]
- selftests: fib_nexthops: do not mark skipped tests as failed (Hangbin Liu) [RHEL-80288]

* Mon Mar 24 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-68.el10]
- platform/x86/intel: pmc: fix ltr decode in pmc_core_ltr_show() (Steve Best) [RHEL-79463]
- platform/x86: intel/pmc: Fix ioremap() of bad address (Steve Best) [RHEL-79463]
- x86/tsc: Move away from TSC leaf magic numbers (Steve Best) [RHEL-79463]
- x86/cpu: Move TSC CPUID leaf definition (Steve Best) [RHEL-79463]
- vrf: use RCU protection in l3mdev_l3_out() (Guillaume Nault) [RHEL-81545] {CVE-2025-21791}
- powerpc/pseries/vas: Add close() callback in vas_vm_ops struct (Mamatha Inamdar) [RHEL-83836]
- async_xor: Remove unused 'async_xor_val' (Nigel Croxon) [RHEL-83951]
- md/raid10: wait barrier before returning discard request with REQ_NOWAIT (Nigel Croxon) [RHEL-83951]
- md/md-bitmap: fix wrong bitmap_limit for clustermd when write sb (Nigel Croxon) [RHEL-83951]
- md/raid1,raid10: don't ignore IO flags (Nigel Croxon) [RHEL-83951]
- md/raid5: merge reshape_progress checking inside get_reshape_loc() (Nigel Croxon) [RHEL-83951]
- md: fix mddev uaf while iterating all_mddevs list (Nigel Croxon) [RHEL-83951]
- md: switch md-cluster to use md_submodle_head (Nigel Croxon) [RHEL-83951]
- md: switch personalities to use md_submodule_head (Nigel Croxon) [RHEL-83951]
- md: don't export md_cluster_ops (Nigel Croxon) [RHEL-83951]
- md/md-cluster: cleanup md_cluster_ops reference (Nigel Croxon) [RHEL-83951]
- md: introduce struct md_submodule_head and APIs (Nigel Croxon) [RHEL-83951]
- md: only include md-cluster.h if necessary (Nigel Croxon) [RHEL-83951]
- md: merge common code into find_pers() (Nigel Croxon) [RHEL-83951]
- md/raid1: fix memory leak in raid1_run() if no active rdev (Nigel Croxon) [RHEL-83951]
- md: ensure resync is prioritized over recovery (Nigel Croxon) [RHEL-83951]
- tpm: Change to kvalloc() in eventlog/acpi.c (CKI Backport Bot) [RHEL-81492] {CVE-2024-58005}
- dpll: add clock quality level attribute and op (Petr Oros) [RHEL-77874]
- i2c: i801: Add support for Intel Panther Lake (Steve Best) [RHEL-47425]

* Fri Mar 21 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-67.el10]
- Bluetooth: btbcm: Fix NULL deref in btbcm_get_board_name() (CKI Backport Bot) [RHEL-81378] {CVE-2024-57988}
- Bluetooth: MGMT: Fix slab-use-after-free Read in mgmt_remove_adv_monitor_sync (CKI Backport Bot) [RHEL-81510] {CVE-2024-58013}
- ipvlan: Fix use-after-free in ipvlan_get_iflink(). (CKI Backport Bot) [RHEL-77888] {CVE-2025-21652}
- usbnet: ipheth: document scope of NCM implementation (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: fix DPE OoB read (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: break up NCM header size computation (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: refactor NCM datagram loop (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: use static NDP16 location in URB (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: check that DPE points past NCM header (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- usbnet: ipheth: fix possible overflow in DPE length check (Jose Ignacio Tornos Martinez) [RHEL-81349 RHEL-81435 RHEL-81565] {CVE-2025-21741 CVE-2025-21743 CVE-2025-21742}
- workqueue: Put the pwq after detaching the rescuer from the pool (CKI Backport Bot) [RHEL-81475] {CVE-2025-21786}
- netfilter: nf_tables: reject mismatching sum of field_len with set key length (CKI Backport Bot) [RHEL-82492] {CVE-2025-21826}
- pktgen: Avoid out-of-bounds access in get_imix_entries (CKI Backport Bot) [RHEL-77232] {CVE-2025-21680}
- Bluetooth: btrtl: check for NULL in btrtl_setup_realtek() (CKI Backport Bot) [RHEL-81271] {CVE-2024-57987}

* Wed Mar 19 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-66.el10]
- crypto: tegra - do not transfer req when tegra init fails (Herbert Xu) [RHEL-82479] {CVE-2024-58075}
- NFSD: fix hang in nfsd4_shutdown_callback (Olga Kornievskaia) [RHEL-81295] {CVE-2025-21795}
- x86/xen: add FRAME_END to xen_hypercall_hvm() (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: fix xen_hypercall_hvm() to not clobber %%rbx (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- compiler.h: Move C string helpers into C-only kernel section (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/static-call: Remove early_boot_irqs_disabled check to fix Xen PVH dom0 (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/asm: Make serialize() always_inline (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/static-call: fix 32-bit build (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: remove hypercall page (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: use new hypercall functions instead of hypercall page (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: add central hypercall functions (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: don't do PV iret hypercall through hypercall page (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/static-call: provide a way to do very early static-call updates (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- objtool/x86: allow syscall instruction (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86: make get_cpu_vendor() accessible from Xen code (Vitaly Kuznetsov) [RHEL-76329] {CVE-2024-53241}
- x86/xen: Avoid relocatable quantities in Xen ELF notes (Vitaly Kuznetsov) [RHEL-76329]
- compiler.h: Fix undefined BUILD_BUG_ON_ZERO() (Vitaly Kuznetsov) [RHEL-76329]
- scsi: storvsc: Set correct data length for sending SCSI command without payload (Cathy Avery) [RHEL-82461]
- locking/lockdep: Add kasan_check_byte() check in lock_acquire() (Waiman Long) [RHEL-78669]
- locking/lockdep: Disable KASAN instrumentation of lockdep.c (Waiman Long) [RHEL-78669]
- redhat/configs: Enable CONFIG_KASAN_INLINE for RT debug kernel (Waiman Long) [RHEL-78669]
- Add CONFIG_OF_PARTITION entry (Ming Lei) [RHEL-79456]
- nvme-pci: don't use dma_alloc_noncontiguous with 0 merge boundary (Ming Lei) [RHEL-79456]
- btrfs: zoned: calculate max_extent_size properly on non-zoned setup (Ming Lei) [RHEL-79456]
- btrfs: handle bio_split() errors (Ming Lei) [RHEL-79456]
- arm64: patching: avoid early page_to_phys() (Ming Lei) [RHEL-79456]
- block: fix 'kmem_cache of name 'bio-108' already exists' (Ming Lei) [RHEL-79456]
- block: Remove zone write plugs when handling native zone append writes (Ming Lei) [RHEL-79456]
- block: make segment size limit workable for > 4K PAGE_SIZE (Ming Lei) [RHEL-79456]
- block: fix NULL pointer dereferenced within __blk_rq_map_sg (Ming Lei) [RHEL-79456]
- block/merge: remove unnecessary min() with UINT_MAX (Ming Lei) [RHEL-79456]
- partitions: mac: fix handling of bogus partition table (Ming Lei) [RHEL-79456]
- block: cleanup and fix batch completion adding conditions (Ming Lei) [RHEL-79456]
- drivers/block/sunvdc.c: update the correct AIP call (Ming Lei) [RHEL-79456]
- block: force noio scope in blk_mq_freeze_queue (Ming Lei) [RHEL-79456]
- block: fix nr_hw_queue update racing with disk addition/removal (Ming Lei) [RHEL-79456]
- block: get rid of request queue ->sysfs_dir_lock (Ming Lei) [RHEL-79456]
- loop: don't clear LO_FLAGS_PARTSCAN on LOOP_SET_STATUS{,64} (Ming Lei) [RHEL-79456]
- blk-mq: create correct map for fallback case (Ming Lei) [RHEL-79456]
- block: don't revert iter for -EIOCBQUEUED (Ming Lei) [RHEL-79456]
- block: Don't trim an atomic write (Ming Lei) [RHEL-79456]
- block: Add common atomic writes enable flag (Ming Lei) [RHEL-79456]
- block: limit disk max sectors to (LLONG_MAX >> 9) (Ming Lei) [RHEL-79456]
- block: Change blk_stack_atomic_writes_limits() unit_min check (Ming Lei) [RHEL-79456]
- block: Ensure start sector is aligned for stacking atomic writes (Ming Lei) [RHEL-79456]
- blk-mq: Move more error handling into blk_mq_submit_bio() (Ming Lei) [RHEL-79456]
- block: Reorder the request allocation code in blk_mq_submit_bio() (Ming Lei) [RHEL-79456]
- partitions: ldm: remove the initial kernel-doc notation (Ming Lei) [RHEL-79456]
- blk-cgroup: rwstat: fix kernel-doc warnings in header file (Ming Lei) [RHEL-79456]
- blk-cgroup: fix kernel-doc warnings in header file (Ming Lei) [RHEL-79456]
- block: mark GFP_NOIO around sysfs ->store() (Ming Lei) [RHEL-79456]
- loop: remove the use_dio field in struct loop_device (Ming Lei) [RHEL-79456]
- loop: don't freeze the queue in loop_update_dio (Ming Lei) [RHEL-79456]
- loop: allow loop_set_status to re-enable direct I/O (Ming Lei) [RHEL-79456]
- loop: open code the direct I/O flag update in loop_set_dio (Ming Lei) [RHEL-79456]
- loop: only write back pagecache when starting to to use direct I/O (Ming Lei) [RHEL-79456]
- loop: create a lo_can_use_dio helper (Ming Lei) [RHEL-79456]
- loop: update commands in loop_set_status still referring to transfers (Ming Lei) [RHEL-79456]
- loop: move updating lo_flags out of loop_set_status_from_info (Ming Lei) [RHEL-79456]
- nbd: don't allow reconnect after disconnect (Ming Lei) [RHEL-79456]
- block: simplify tag allocation policy selection (Ming Lei) [RHEL-79456]
- block: remove BLK_MQ_F_NO_SCHED (Ming Lei) [RHEL-79456]
- block: remove blk_mq_init_bitmaps (Ming Lei) [RHEL-79456]
- block: better split mq vs non-mq code in add_disk_fwnode (Ming Lei) [RHEL-79456]
- block: add a dma mapping iterator (Ming Lei) [RHEL-79456]
- block: use page_to_phys in bvec_phys (Ming Lei) [RHEL-79456]
- asm-generic: add an optional pfn_valid check to page_to_phys (Ming Lei) [RHEL-79456]
- asm-generic: provide generic page_to_phys and phys_to_page implementations (Ming Lei) [RHEL-79456]
- block: remove blk_rq_bio_prep (Ming Lei) [RHEL-79456]
- block: remove bio_add_pc_page (Ming Lei) [RHEL-79456]
- ps3disk: Do not use dev->bounce_size before it is set (Ming Lei) [RHEL-79456]
- block: retry call probe after request_module in blk_request_module (Ming Lei) [RHEL-79456]
- kyber: constify sysfs attributes (Ming Lei) [RHEL-79456]
- block, bfq: constify sysfs attributes (Ming Lei) [RHEL-79456]
- block: mq-deadline: Constify sysfs attributes (Ming Lei) [RHEL-79456]
- elevator: Enable const sysfs attributes (Ming Lei) [RHEL-79456]
- blk-zoned: Split queue_zone_wplugs_show() (Ming Lei) [RHEL-79456]
- blk-zoned: Improve the queue reference count strategy documentation (Ming Lei) [RHEL-79456]
- blk-zoned: Document locking assumptions (Ming Lei) [RHEL-79456]
- blk-zoned: Minimize #include directives (Ming Lei) [RHEL-79456]
- block: remove BLK_MQ_F_SHOULD_MERGE (Ming Lei) [RHEL-79456]
- blk-mq: remove unused queue mapping helpers (Ming Lei) [RHEL-79456]
- virtio: blk/scsi: replace blk_mq_virtio_map_queues with blk_mq_map_hw_queues (Ming Lei) [RHEL-79456]
- nvme: replace blk_mq_pci_map_queues with blk_mq_map_hw_queues (Ming Lei) [RHEL-79456]
- scsi: replace blk_mq_pci_map_queues with blk_mq_map_hw_queues (Ming Lei) [RHEL-79456]
- blk-mq: introduce blk_mq_map_hw_queues (Ming Lei) [RHEL-79456]
- virtio: hookup irq_get_affinity callback (Ming Lei) [RHEL-79456]
- PCI: hookup irq_get_affinity callback (Ming Lei) [RHEL-79456]
- driver core: bus: add irq_get_affinity callback to bus_type (Ming Lei) [RHEL-79456]
- blktrace: remove redundant return at end of function (Ming Lei) [RHEL-79456]
- block: Delete bio_set_prio() (Ming Lei) [RHEL-79456]
- block: Delete bio_prio() (Ming Lei) [RHEL-79456]
- blktrace: move copy_[to|from]_user() out of ->debugfs_lock (Ming Lei) [RHEL-79456]
- blktrace: don't centralize grabbing q->debugfs_mutex in blk_trace_ioctl (Ming Lei) [RHEL-79456]
- null_blk: Add rotational feature support (Ming Lei) [RHEL-79456]
- block: track queue dying state automatically for modeling queue freeze lockdep (Ming Lei) [RHEL-79456]
- block: don't verify queue freeze manually in elevator_init_mq() (Ming Lei) [RHEL-79456]
- block: track disk DEAD state automatically for modeling queue freeze lockdep (Ming Lei) [RHEL-79456]
- block: remove unnecessary check in blk_unfreeze_check_owner() (Ming Lei) [RHEL-79456]
- block, bfq: fix waker_bfqq UAF after bfq_split_bfqq() (Ming Lei) [RHEL-79456]
- cdrom: Fix typo, 'devicen' to 'device' (Ming Lei) [RHEL-79456]
- ublk: detach gendisk from ublk device if add_disk() fails (Ming Lei) [RHEL-79456]
- block: avoid to reuse `hctx` not removed from cpuhp callback list (Ming Lei) [RHEL-79456]
- block: Revert "block: Fix potential deadlock while freezing queue and acquiring sysfs_lock" (Ming Lei) [RHEL-79456]
- nvme: use blk_validate_block_size() for max LBA check (Ming Lei) [RHEL-79456]
- block/bdev: use helper for max block size check (Ming Lei) [RHEL-79456]
- block: Fix potential deadlock while freezing queue and acquiring sysfs_lock (Ming Lei) [RHEL-79456]
- blk-mq: Clean up blk_mq_requeue_work() (Ming Lei) [RHEL-79456]
- mq-deadline: Remove a local variable (Ming Lei) [RHEL-79456]
- blk-iocost: Avoid using clamp() on inuse in __propagate_weights() (Ming Lei) [RHEL-79456]
- block: Make bio_iov_bvec_set() accept pointer to const iov_iter (Ming Lei) [RHEL-79456]
- block: get wp_offset by bdev_offset_from_zone_start (Ming Lei) [RHEL-79456]
- blk-cgroup: Fix UAF in blkcg_unpin_online() (Ming Lei) [RHEL-79456]
- MAINTAINERS: update Coly Li's email address (Ming Lei) [RHEL-79456]
- blk-mq: move cpuhp callback registering out of q->sysfs_lock (Ming Lei) [RHEL-79456]
- blk-mq: register cpuhp callback after hctx is added to xarray table (Ming Lei) [RHEL-79456]
- virtio-blk: don't keep queue frozen during system suspend (Ming Lei) [RHEL-79456]
- block: rnull: add missing MODULE_DESCRIPTION (Ming Lei) [RHEL-79456]
- block: Don't allow an atomic write be truncated in blkdev_write_iter() (Ming Lei) [RHEL-79456]
- block: Add bdev atomic write limits helpers (Ming Lei) [RHEL-79456]
- fs/block: Check for IOCB_DIRECT in generic_atomic_write_valid() (Ming Lei) [RHEL-79456]
- block/fs: Pass an iocb to generic_atomic_write_valid() (Ming Lei) [RHEL-79456]
- brd: decrease the number of allocated pages which discarded (Ming Lei) [RHEL-79456]
- block, bfq: fix bfqq uaf in bfq_limit_depth() (Ming Lei) [RHEL-79456]
- mq-deadline: don't call req_get_ioprio from the I/O completion handler (Ming Lei) [RHEL-79456]
- block: Remove extra part pointer NULLify in blk_rq_init() (Ming Lei) [RHEL-79456]
- block: return bool from get_disk_ro and bdev_read_only (Ming Lei) [RHEL-79456]
- block: remove a duplicate definition for bdev_read_only (Ming Lei) [RHEL-79456]
- block: return bool from blk_rq_aligned (Ming Lei) [RHEL-79456]
- block: return unsigned int from blk_lim_dma_alignment_and_pad (Ming Lei) [RHEL-79456]
- block: return unsigned int from queue_dma_alignment (Ming Lei) [RHEL-79456]
- block: return unsigned int from bdev_io_opt (Ming Lei) [RHEL-79456]
- block: req->bio is always set in the merge code (Ming Lei) [RHEL-79456]
- block: don't bother checking the data direction for merges (Ming Lei) [RHEL-79456]
- block: blk-mq: fix uninit-value in blk_rq_prep_clone and refactor (Ming Lei) [RHEL-79456]
- block: Add extra checks in blk_validate_atomic_write_limits() (Ming Lei) [RHEL-79456]
- ublk: fix error code for unsupported command (Ming Lei) [RHEL-79456]
- block: Drop granularity check in queue_limit_discard_alignment() (Ming Lei) [RHEL-79456]
- block: return unsigned int from bdev_io_min (Ming Lei) [RHEL-79456]
- block: fix uaf for flush rq while iterating tags (Ming Lei) [RHEL-79456]
- blk-settings: round down io_opt to physical_block_size (Ming Lei) [RHEL-79456]
- rust: block: simplify Result<()> in validate_block_size return (Ming Lei) [RHEL-79456]
- block: make struct rq_list available for !CONFIG_BLOCK (Ming Lei) [RHEL-79456]
- block/genhd: use seq_put_decimal_ull for diskstats decimal values (Ming Lei) [RHEL-79456]
- block: don't reorder requests in blk_mq_add_to_batch (Ming Lei) [RHEL-79456]
- block: don't reorder requests in blk_add_rq_to_plug (Ming Lei) [RHEL-79456]
- block: add a rq_list type (Ming Lei) [RHEL-79456]
- block: remove rq_list_move (Ming Lei) [RHEL-79456]
- virtio_blk: reverse request order in virtio_queue_rqs (Ming Lei) [RHEL-79456]
- nvme-pci: reverse request order in nvme_queue_rqs (Ming Lei) [RHEL-79456]
- btrfs: validate queue limits (Ming Lei) [RHEL-79456]
- block: remove the ioprio field from struct request (Ming Lei) [RHEL-79456]
- block: remove the write_hint field from struct request (Ming Lei) [RHEL-79456]
- nvme-multipath: don't bother clearing max_hw_zone_append_sectors (Ming Lei) [RHEL-79456]
- block: pre-calculate max_zone_append_sectors (Ming Lei) [RHEL-79456]
- block: lift bio_is_zone_append to bio.h (Ming Lei) [RHEL-79456]
- block: fix bio_split_rw_at to take zone_write_granularity into account (Ming Lei) [RHEL-79456]
- block: take chunk_sectors into account in bio_split_write_zeroes (Ming Lei) [RHEL-79456]
- block: Handle bio_split() errors in bio_submit_split() (Ming Lei) [RHEL-79456]
- block: Error an attempt to split an atomic write in bio_split() (Ming Lei) [RHEL-79456]
- block: Rework bio_split() return value (Ming Lei) [RHEL-79456]
- ublk: fix ublk_ch_mmap() for 64K page size (Ming Lei) [RHEL-79456]
- s390/dasd: Fix typo in comment (Ming Lei) [RHEL-79456]
- s390/dasd: fix redundant /proc/dasd* entries removal (Ming Lei) [RHEL-79456]
- block: don't verify IO lock for freeze/unfreeze in elevator_init_mq() (Ming Lei) [RHEL-79456]
- block: always verify unfreeze lock on the owner task (Ming Lei) [RHEL-79456]
- rbd: unfreeze queue after marking disk as dead (Ming Lei) [RHEL-79456]
- block: remove blk_freeze_queue() (Ming Lei) [RHEL-79456]
- nvme: add reservation command's defines (Ming Lei) [RHEL-79456]
- Revert "block: pre-calculate max_zone_append_sectors" (Ming Lei) [RHEL-79456]
- mtip32xx: Replace deprecated PCI functions (Ming Lei) [RHEL-79456]
- nvme-core: remove repeated wq flags (Ming Lei) [RHEL-79456]
- nvmet: make nvmet_wq visible in sysfs (Ming Lei) [RHEL-79456]
- nvme-pci: use dma_alloc_noncontigous if possible (Ming Lei) [RHEL-79456]
- nvme-pci: fix freeing of the HMB descriptor table (Ming Lei) [RHEL-79456]
- block: update blk_stack_limits documentation (Ming Lei) [RHEL-79456]
- lib/iov_iter: fix bvec iterator setup (Ming Lei) [RHEL-79456]
- lib/iov_iter.c: initialize bi.bi_idx before iterating over bvec (Ming Lei) [RHEL-79456]
- blk-integrity: remove seed for user mapped buffers (Ming Lei) [RHEL-79456]
- brd: defer automatic disk creation until module initialization succeeds (Ming Lei) [RHEL-79456]
- iov_iter: don't require contiguous pages in iov_iter_extract_bvec_pages (Ming Lei) [RHEL-79456]
- block: model freeze & enter queue as lock for supporting lockdep (Ming Lei) [RHEL-79456]
- nvme: core: switch to non_owner variant of start_freeze/unfreeze queue (Ming Lei) [RHEL-79456]
- blk-mq: add non_owner variant of start_freeze/unfreeze queue APIs (Ming Lei) [RHEL-79456]
- blk-mq: Unexport blk_mq_flush_busy_ctxs() (Ming Lei) [RHEL-79456]
- blk-mq: Make blk_mq_quiesce_tagset() hold the tag list mutex less long (Ming Lei) [RHEL-79456]
- block: remove redundant explicit memory barrier from rq_qos waiter and waker (Ming Lei) [RHEL-79456]
- nvme: use helpers to access io_uring cmd space (Ming Lei) [RHEL-79456]
- block: flush all throttled bios when deleting the cgroup (Ming Lei) [RHEL-79456]
- block: fix ordering between checking BLK_MQ_S_STOPPED request adding (Ming Lei) [RHEL-79456]
- block: fix ordering between checking QUEUE_FLAG_QUIESCED request adding (Ming Lei) [RHEL-79456]
- block: fix missing dispatching request when queue is started or unquiesced (Ming Lei) [RHEL-79456]
- Revert "blk-throttle: Fix IO hang for a corner case" (Ming Lei) [RHEL-79456]
- block: replace call_rcu by kfree_rcu for simple kmem_cache_free callback (Ming Lei) [RHEL-79456]
- Documentation: ublk: document UBLK_F_USER_RECOVERY_FAIL_IO (Ming Lei) [RHEL-79456]
- ublk: support device recovery without I/O queueing (Ming Lei) [RHEL-79456]
- ublk: merge stop_work and quiesce_work (Ming Lei) [RHEL-79456]
- ublk: refactor recovery configuration flag helpers (Ming Lei) [RHEL-79456]
- ublk: check recovery flags for validity (Ming Lei) [RHEL-79456]
- block: add partition uuid into uevent as "PARTUUID" (Ming Lei) [RHEL-79456]
- block: move issue side time stamping to blk_account_io_start() (Ming Lei) [RHEL-79456]
- dt-bindings: mmc: Document support for partition table in mmc-card (Ming Lei) [RHEL-79456]
- block: add support for partition table defined in OF (Ming Lei) [RHEL-79456]
- mmc: block: attach partitions fwnode if found in mmc-card (Ming Lei) [RHEL-79456]
- block: introduce add_disk_fwnode() (Ming Lei) [RHEL-79456]
- docs: block: Document support for read-only partition in cmdline part (Ming Lei) [RHEL-79456]
- block: add support for defining read-only partitions (Ming Lei) [RHEL-79456]
- block: kill blk_do_io_stat() helper (Ming Lei) [RHEL-79456]
- block: remove 'req->part' check for stats accounting (Ming Lei) [RHEL-79456]
- block: remove redundant passthrough check in blk_mq_need_time_stamp() (Ming Lei) [RHEL-79456]
- block: export blk_validate_limits (Ming Lei) [RHEL-62933]
- block: set issue time stamp based on queue state (Ming Lei) [RHEL-62933]
- loop: fix queue freeze vs limits lock order (Ming Lei) [RHEL-62933]
- loop: refactor queue limits updates (Ming Lei) [RHEL-62933]
- usb-storage: fix queue freeze vs limits lock order (Ming Lei) [RHEL-62933]
- nbd: fix queue freeze vs limits lock order (Ming Lei) [RHEL-62933]
- nvme: fix queue freeze vs limits lock order (Ming Lei) [RHEL-62933]
- block: fix queue freeze vs limits lock order in sysfs store methods (Ming Lei) [RHEL-62933]
- block: add a store_limit operations for sysfs entries (Ming Lei) [RHEL-62933]
- block: don't update BLK_FEAT_POLL in __blk_mq_update_nr_hw_queues (Ming Lei) [RHEL-62933]
- block: check BLK_FEAT_POLL under q_usage_count (Ming Lei) [RHEL-62933]
- block: add a queue_limits_commit_update_frozen helper (Ming Lei) [RHEL-62933]
- block: fix docs for freezing of queue limits updates (Ming Lei) [RHEL-62933]
- block: pre-calculate max_zone_append_sectors (Ming Lei) [RHEL-62933]
- block: remove the max_zone_append_sectors check in blk_revalidate_disk_zones (Ming Lei) [RHEL-62933]
- block: remove bio_add_zone_append_page (Ming Lei) [RHEL-62933]
- block: remove zone append special casing from the direct I/O path (Ming Lei) [RHEL-62933]
- block: Replace sprintf() with sysfs_emit() (Ming Lei) [RHEL-62933]
- block: Fix queue_iostats_passthrough_show() (Ming Lei) [RHEL-62933]
- block: enable passthrough command statistics (Ming Lei) [RHEL-62933]
- block: move iostat check into blk_acount_io_start() (Ming Lei) [RHEL-62933]
- block: return void from the queue_sysfs_entry load_module method (Ming Lei) [RHEL-62933]
- loop: Fix ABBA locking race (Ming Lei) [RHEL-62933]
- loop: Simplify discard granularity calc (Ming Lei) [RHEL-62933]
- loop: Use bdev limit helpers for configuring discard (Ming Lei) [RHEL-62933]
- block: add a bdev_limits helper (Ming Lei) [RHEL-62933]
- PCI: dwc: ep: Prevent changing BAR size/flags in pci_epc_set_bar() (Myron Stowe) [RHEL-81557] {CVE-2024-58006}
- PCI: dwc: ep: Write BAR_MASK before iATU registers in pci_epc_set_bar() (Myron Stowe) [RHEL-81557]
- exfat: fix out-of-bounds access of directory entries (CKI Backport Bot) [RHEL-78928] {CVE-2024-53147}
- RDMA/nldev: Set error code in rdma_nl_notify_event (Kamal Heib) [RHEL-77879]
- RDMA/core: Fix ENODEV error for iWARP test over vlan (Kamal Heib) [RHEL-77879]
- IB/cm: Rework sending DREQ when destroying a cm_id (Kamal Heib) [RHEL-77879]
- IB/cm: Do not hold reference on cm_id unless needed (Kamal Heib) [RHEL-77879]
- IB/cm: Explicitly mark if a response MAD is a retransmission (Kamal Heib) [RHEL-77879]
- RDMA/nldev: Add IB device and net device rename events (Kamal Heib) [RHEL-77879]
- RDMA/core: Move ib_uverbs_file struct to uverbs_types.h (Kamal Heib) [RHEL-77879]
- RDMA/core: Add device ufile cleanup operation (Kamal Heib) [RHEL-77879]
- RDMA/core: Implement RoCE GID port rescan and export delete function (Kamal Heib) [RHEL-77879]
- RDMA: Use ethtool string helpers (Kamal Heib) [RHEL-77879]
- RDMA/ipoib: Use the networking stack default for txqueuelen (Kamal Heib) [RHEL-77879]
- RDMA/core: Provide rdma_user_mmap_disassociate() to disassociate mmap pages (Kamal Heib) [RHEL-77879]
- PCI: rockchip-ep: Fix error code in rockchip_pcie_ep_init_ob_mem() (Myron Stowe) [RHEL-74285]
- PCI: rockchip: Add missing fields descriptions for struct rockchip_pcie_ep (Myron Stowe) [RHEL-74285]
- PCI/bwctrl: Fix NULL pointer deref on unbind and bind (Myron Stowe) [RHEL-74285]
- PCI/bwctrl: Enable only if more than one speed is supported (Myron Stowe) [RHEL-74285]
- PCI: Honor Max Link Speed when determining supported speeds (Myron Stowe) [RHEL-74285]
- PCI/pwrctrl: Unregister platform device only if one actually exists (Myron Stowe) [RHEL-74285]
- PCI: Fix typos (Myron Stowe) [RHEL-74285]
- tools: PCI: Fix incorrect printf format specifiers (Myron Stowe) [RHEL-74285]
- PCI: Simplify pci_create_slot() logic (Myron Stowe) [RHEL-74285]
- PCI: Fix reset_method_store() memory leak (Myron Stowe) [RHEL-74285] {CVE-2024-56745}
- PCI: hotplug: Remove "Returns" kerneldoc from void functions (Myron Stowe) [RHEL-74285]
- PCI: hotplug: Reorganize kerneldoc parameter names (Myron Stowe) [RHEL-74285]
- PCI: tegra194: Move controller cleanups to pex_ep_event_pex_rst_deassert() (Myron Stowe) [RHEL-74285] {CVE-2024-53152}
- PCI: rockchip-ep: Handle PERST# signal in EP mode (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Improve link training (Myron Stowe) [RHEL-74285]
- PCI: rockship-ep: Implement the pci_epc_ops::stop_link() operation (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Refactor endpoint link training enable (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Refactor rockchip_pcie_ep_probe() MSI-X hiding (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Refactor rockchip_pcie_ep_probe() memory allocations (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Rename rockchip_pcie_parse_ep_dt() (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Fix MSI IRQ data mapping (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Implement the pci_epc_ops::align_addr() operation (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Improve rockchip_pcie_ep_map_addr() (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Improve rockchip_pcie_ep_unmap_addr() (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Use a macro to define EP controller .align feature (Myron Stowe) [RHEL-74285]
- PCI: rockchip-ep: Fix address translation unit programming (Myron Stowe) [RHEL-74285]
- PCI: qcom: Disable ASPM L0s for X1E80100 (Myron Stowe) [RHEL-74285]
- PCI: qcom: Remove BDF2SID mapping config for SC8280X family SoC (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: qcom,pcie-x1e80100: Add 'global' interrupt (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: qcom: Move OPP table to qcom,pcie-common.yaml (Myron Stowe) [RHEL-74285]
- PCI: qcom: Add support for IPQ9574 (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: qcom: Document the IPQ9574 PCIe controller (Myron Stowe) [RHEL-74285]
- PCI: qcom-ep: Move controller cleanups to qcom_pcie_perst_deassert() (Myron Stowe) [RHEL-74285] {CVE-2024-53153}
- PCI: qcom: Enable MSI interrupts together with Link up if 'Global IRQ' is supported (Myron Stowe) [RHEL-74285]
- PCI: microchip: Add support for using either Root Port 1 or 2 (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: microchip,pcie-host: Add reg for Root Port 2 (Myron Stowe) [RHEL-74285]
- PCI: mediatek-gen3: Remove unneeded semicolon (Myron Stowe) [RHEL-74285]
- PCI: mediatek-gen3: Add support for restricting link width (Myron Stowe) [RHEL-74285]
- PCI: mediatek-gen3: Add support for setting max-link-speed limit (Myron Stowe) [RHEL-74285]
- PCI: keystone: Add link up check to ks_pcie_other_map_bus() (Myron Stowe) [RHEL-74285]
- PCI: keystone: Set mode as Root Complex for "ti,keystone-pcie" compatible (Myron Stowe) [RHEL-74285]
- PCI: j721e: Deassert PERST# after a delay of PCIE_T_PVPERL_MS milliseconds (Myron Stowe) [RHEL-74285]
- PCI: j721e: Add PCIe support for J722S SoC (Myron Stowe) [RHEL-74285]
- PCI: imx6: Fix suspend/resume support on i.MX6QDL (Myron Stowe) [RHEL-74285] {CVE-2024-57809}
- PCI: dwc: ep: Fix advertised resizable BAR size regression (Myron Stowe) [RHEL-74285]
- PCI: dwc: Use of_property_present() for non-boolean properties (Myron Stowe) [RHEL-74285]
- PCI: dwc: endpoint: Clear outbound address on unmap (Myron Stowe) [RHEL-74285]
- PCI: cadence: Lower severity of message when phy-names property is absent in DTS (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Fix pci_epc_map map_size kerneldoc string (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Clear secondary (not primary) EPC in pci_epc_remove_epf() (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Fix PCI domain ID release in pci_epc_destroy() (Myron Stowe) [RHEL-74285] {CVE-2024-56561}
- PCI: endpoint: epf-mhi: Avoid NULL dereference if DT lacks 'mmio' (Myron Stowe) [RHEL-74285] {CVE-2024-56689}
- PCI: endpoint: Remove surplus return statement from pci_epf_test_clean_dma_chan() (Myron Stowe) [RHEL-74285]
- PCI: dwc: ep: Use align addr function for dw_pcie_ep_raise_{msi,msix}_irq() (Myron Stowe) [RHEL-74285]
- PCI: endpoint: test: Synchronously cancel command handler work (Myron Stowe) [RHEL-74285]
- PCI: dwc: endpoint: Implement the pci_epc_ops::align_addr() operation (Myron Stowe) [RHEL-74285]
- PCI: endpoint: test: Use pci_epc_mem_map/unmap() (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Update documentation (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Introduce pci_epc_mem_map()/unmap() (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Improve pci_epc_mem_alloc_addr() (Myron Stowe) [RHEL-74285]
- PCI: endpoint: Introduce pci_epc_function_is_valid() (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: snps,dw-pcie: Drop "#interrupt-cells" from example (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: qcom,pcie-sm8550: Add SAR2130P compatible (Myron Stowe) [RHEL-74285]
- dt-bindings: PCI: mediatek-gen3: Allow exact number of clocks only (Myron Stowe) [RHEL-74285]
- PCI: Add ACS quirk for Wangxun FF5xxx NICs (Myron Stowe) [RHEL-74285]
- PCI: Detect and trust built-in Thunderbolt chips (Myron Stowe) [RHEL-74285]
- PCI: Improve pdev_sort_resources() warning message (Myron Stowe) [RHEL-74285]
- PCI: Add ALIGN_DOWN_IF_NONZERO() helper (Myron Stowe) [RHEL-74285]
- PCI: Use align and resource helpers, and SZ_* in quirk_s3_64M() (Myron Stowe) [RHEL-74285]
- PCI: Use resource_set_{range,size}() helpers (Myron Stowe) [RHEL-74285]
- resource: Add resource set range and size helpers (Myron Stowe) [RHEL-74285]
- PCI: Warn if a running device is unaware of reset (Myron Stowe) [RHEL-74285]
- PCI: Add 'reset_subordinate' to reset hierarchy below bridge (Myron Stowe) [RHEL-74285]
- PCI/pwrctrl: Rename pwrctrl functions and structures (Myron Stowe) [RHEL-74285]
- PCI/pwrctrl: Rename pwrctl files to pwrctrl (Myron Stowe) [RHEL-74285]
- PCI/pwrctl: Remove pwrctl device without iterating over all children of pwrctl parent (Myron Stowe) [RHEL-74285]
- PCI/pwrctl: Ensure that pwrctl drivers are probed before PCI client drivers (Myron Stowe) [RHEL-74285]
- PCI/pwrctl: Create pwrctl device only if at least one power supply is present (Myron Stowe) [RHEL-74285]
- PCI/pwrctl: Use of_platform_device_create() to create pwrctl devices (Myron Stowe) [RHEL-74285]
- PCI: Enable runtime PM of the host bridge (Myron Stowe) [RHEL-74285]
- PCI: starfive: Enable controller runtime PM before probing host bridge (Myron Stowe) [RHEL-74285]
- PCI: of_property: Assign PCI instead of CPU bus address to dynamic PCI nodes (Myron Stowe) [RHEL-74285]
- PCI: Unexport pci_walk_bus_locked() (Myron Stowe) [RHEL-74285]
- PCI: Convert __pci_walk_bus() to be recursive (Myron Stowe) [RHEL-74285]
- PCI: Move __pci_walk_bus() mutex to where we need it (Myron Stowe) [RHEL-74285]
- PCI: Make pci_destroy_dev() concurrent safe (Myron Stowe) [RHEL-74285]
- PCI: Make pci_stop_dev() concurrent safe (Myron Stowe) [RHEL-74285]
- PCI: Fix use-after-free of slot->bus on hot remove (Myron Stowe) [RHEL-74285] {CVE-2024-53194}
- PCI: cpqphp: Simplify PCI_ScanBusForNonBridge() (Myron Stowe) [RHEL-74285]
- PCI: cpqphp: Use define to read class/revision dword (Myron Stowe) [RHEL-74285]
- PCI: cpqphp: Use pci_bus_read_dev_vendor_id() to detect presence (Myron Stowe) [RHEL-74285]
- PCI: cpqphp: Fix PCIBIOS_* return value confusion (Myron Stowe) [RHEL-74285]
- PCI: cpqphp: Remove unused struct ctrl_dbg.ctrl (Myron Stowe) [RHEL-74285]
- PCI: cpcihp: Remove unused struct cpci_hp_controller_ops.hardware_test (Myron Stowe) [RHEL-74285]
- PCI: Simplify pci_read_bridge_bases() logic (Myron Stowe) [RHEL-74285]
- PCI: Move struct pci_bus_resource into bus.c (Myron Stowe) [RHEL-74285]
- PCI: Remove unused PCI_SUBTRACTIVE_DECODE (Myron Stowe) [RHEL-74285]
- PCI: acpiphp_ampere_altra: Switch back to struct platform_driver::remove() (Myron Stowe) [RHEL-74285]
- PCI: controller: Switch back to struct platform_driver::remove() (Myron Stowe) [RHEL-74285]
- ethernet: cavium: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- gpio: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- fpga/dfl-pci.c: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- PCI: Deprecate pcim_iounmap_regions() (Myron Stowe) [RHEL-74285]
- PCI: Make pcim_iounmap_region() a public function (Myron Stowe) [RHEL-74285]
- PCI: Remove pcim_iomap_regions_request_all() (Myron Stowe) [RHEL-74285]
- ALSA: korg1212: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- serial: rp2: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- ntb: idt: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- wifi: iwlwifi: replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- intel_th: pci: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- crypto: marvell - replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- crypto: qat - replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- ata: ahci: Replace deprecated PCI functions (Myron Stowe) [RHEL-74285]
- PCI: Make pcim_request_all_regions() a public function (Myron Stowe) [RHEL-74285]
- PCI/DOE: Poll DOE Busy bit for up to 1 second in pci_doe_send_req() (Myron Stowe) [RHEL-74285]
- PCI: Drop duplicate pcie_get_speed_cap(), pcie_get_width_cap() declarations (Myron Stowe) [RHEL-74285]
- selftests/pcie_bwctrl: Create selftests (Myron Stowe) [RHEL-74285]
- thermal: Add PCIe cooling driver (Myron Stowe) [RHEL-74285]
- PCI/bwctrl: Add pcie_set_target_speed() to set PCIe Link Speed (Myron Stowe) [RHEL-74285]
- PCI/bwctrl: Re-add BW notification portdrv as PCIe BW controller (Myron Stowe) [RHEL-74285]
- PCI: Abstract LBMS seen check into pcie_lbms_seen() (Myron Stowe) [RHEL-74285]
- PCI: Refactor pcie_update_link_speed() (Myron Stowe) [RHEL-74285]
- PCI: Store all PCIe Supported Link Speeds (Myron Stowe) [RHEL-74285]
- PCI: Protect Link Control 2 Register with RMW locking (Myron Stowe) [RHEL-74285]
- Documentation PCI: Reformat RMW ops documentation (Myron Stowe) [RHEL-74285]
- PCI/ASPM: Add notes about enabling PCI-PM L1SS to pci_enable_link_state(_locked) (Myron Stowe) [RHEL-74285]
- PCI/ASPM: Disable L1 before disabling L1 PM Substates (Myron Stowe) [RHEL-74285]

* Tue Mar 18 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-65.el10]
- EDAC/{i10nm,skx,skx_common}: Support UV systems (Aristeu Rozanski) [RHEL-73781]
- Documentation/sysctl: Add timer_migration to kernel.rst (Phil Auld) [RHEL-77929]
- ASoC: SOF: Intel: hda-dai: Ensure DAI widget is valid during params (CKI Backport Bot) [RHEL-81442] {CVE-2024-58012}
- EDAC/amd64: Simplify ECC check on unified memory controllers (Aristeu Rozanski) [RHEL-73050]
- perf test record+probe_libc_inet_pton: Make test resilient (Jakub Brnak) [RHEL-74339]
- Revert "selftests/mm: remove local __NR_* definitions" (Li Wang) [RHEL-79766]
- Enable Intel VPU driver for RHEL (Fabien Dupont) [RHEL-38582]
- arm64: cacheinfo: Avoid out-of-bounds write to cacheinfo array (Radu Rendec) [RHEL-80226]
- smb: client: fix chmod(2) regression with ATTR_READONLY (Jay Shin) [RHEL-82677 RHEL-80534]
- kabi: enable check-kabi (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol zap_vma_ptes to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_uses_need_wakeup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_tx_release to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_tx_peek_release_desc_batch to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_tx_peek_desc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_tx_completed to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_set_tx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_set_rx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_get_pool_from_qid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xsk_clear_rx_need_wakeup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_set_rxq_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_raw_get_dma to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_fill_cb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_dma_unmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_dma_map to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_can_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xp_alloc_batch to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_warn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_set_features_flag to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_rxq_info_unreg_mem_model to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_rxq_info_unreg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_rxq_info_reg_mem_model to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __xdp_rxq_info_reg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_rxq_info_is_reg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_return_frame_rx_napi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_return_frame_bulk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_return_frame to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_return_buff to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_master_redirect to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_flush_frame_bulk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_features_set_redirect_target to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_features_clear_redirect_target to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_do_redirect to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_do_flush to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xdp_convert_zc_to_xdp_frame to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_store to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_load to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __xa_insert to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_find_after to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_find to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_erase to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol xa_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __xa_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_return_thunk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rsi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rdx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rdi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rcx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rbx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rbp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_rax to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r9 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r8 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r15 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r14 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r13 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r12 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r11 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __x86_indirect_thunk_r10 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol x86_cpu_to_apicid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __warn_printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol wake_up_process to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __wake_up to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol wait_for_completion_timeout to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol wait_for_completion_io_timeout to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol wait_for_completion_interruptible to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol wait_for_completion to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vzalloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vsprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vsnprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vscnprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vm_munmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vm_mmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vmemmap_base to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vmalloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vmalloc_node_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vmalloc_base to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vmalloc_array_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vlan_dev_vlan_id to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vlan_dev_real_dev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __virt_addr_valid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vfs_unlink to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vfs_mknod to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vfs_mkdir to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vfs_fsync_range to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol vfree to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_undefined to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_teardown_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_setup_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_possible_blades to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __uv_hub_info_list to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_get_hubless_system to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __uv_cpu_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_obj_count to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_install_heap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_get_pci_topology to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_get_master_nasid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_get_heapsize to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_get_geoinfo to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_enum_ports to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol uv_bios_enum_objs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol usleep_range_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol up_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol up_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol up to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_switchdev_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_switchdev_blocking_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_netevent_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_netdevice_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_netdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_kprobe to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_inetaddr_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_inet6addr_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_chrdev_region to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __unregister_chrdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol unregister_blkdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol udp_tunnel_nic_ops to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __udelay to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_unregister_driver to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_termios_encode_baud_rate to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_std_termios to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_register_driver to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_port_link_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_port_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_port_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_flip_buffer_push to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_driver_kref_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tty_buffer_request_room to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tty_alloc_driver to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tsc_khz to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol try_module_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __trace_trigger_soft_disabled to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_raw_output_prep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_print_bitmask_seq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tracepoint_xdp_exception to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tracepoint_mmap_lock_start_locking to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tracepoint_mmap_lock_released to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tracepoint_mmap_lock_acquire_returned to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_handle_return to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_reg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_raw_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_printf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_ignore_this_pid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_buffer_reserve to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_event_buffer_commit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_array_set_clr_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_array_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol trace_array_get_by_name to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol touch_softlockup_watchdog to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tls_validate_xmit_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tls_get_record to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tls_encrypt_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tls_device_sk_destruct to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timer_shutdown_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timer_shutdown to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timer_delete_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timer_delete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timecounter_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timecounter_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol timecounter_cyc2time to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol time64_to_tm to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tcp_gro_complete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __tasklet_schedule to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tasklet_kill to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol tasklet_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sys_tz to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol system_wq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol system_unbound_wq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol system_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_streq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_remove_group to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_remove_file_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_remove_bin_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __sysfs_match_string to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_emit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_create_group to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_create_file_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sysfs_create_bin_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol synchronize_rcu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol synchronize_net to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol synchronize_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sync_blockdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __symbol_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __symbol_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol switchdev_handle_port_obj_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol switchdev_handle_port_obj_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol switchdev_handle_port_attr_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __sw_hweight64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __sw_hweight32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol submit_bio_noacct to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strstr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strsep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strrchr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strnlen to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strncpy_from_user to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strncpy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strncmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strncasecmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strlen to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strlcat to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strim to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strcspn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strcpy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strcmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strchr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strcat to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol strcasecmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol static_key_slow_inc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol static_key_slow_dec to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol static_key_enable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol static_key_disable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol static_key_count to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol starget_for_each_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __stack_chk_fail to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sscanf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sort to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol softnet_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sock_gen_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sn_region_size to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol snprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sn_partition_id to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol smp_call_function_single_async to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol smp_call_function_single to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol smp_call_function_many to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol slab_build_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sk_skb_reason_drop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sk_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_tstamp_tx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_realloc_headroom to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_queue_tail to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_push to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_pull to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __skb_pad to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __skb_gso_segment to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __skb_flow_dissect to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_dequeue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_copy_header to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_copy_expand to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_copy_bits to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_copy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_clone_tx_timestamp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_clone to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_checksum_help to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol skb_add_rx_frag_netmem to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sk_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sized_strscpy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol single_release to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol single_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_write_to_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_strtoul to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_strtol to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_attr_release to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol simple_attr_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol si_meminfo to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_pcopy_to_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_pcopy_from_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_next to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_nents to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_miter_stop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_miter_start to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_miter_next to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_copy_to_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_copy_from_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sg_copy_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_user_nice to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_normalized_timespec64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_memory_wc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_cpus_allowed_ptr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_capacity to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol set_blocksize to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_release to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __seq_puts to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_putc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_printf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol seq_lseek to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol send_sig to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol secpath_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sdev_prefix_printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCT__tp_func_xdp_exception to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCT__preempt_schedule_notrace to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCT__preempt_schedule to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCT__might_resched to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCT__cond_resched to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_unblock_requests to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_scan_target to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_scan_host to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_sanitize_inquiry_string to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_rescan_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_remove_target to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_remove_host to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_remove_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_print_command to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_normalize_sense to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsilun_to_int to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __scsi_iterate_devices to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_is_sdev_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_is_host_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_is_fc_rport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_host_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_host_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_host_busy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_host_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_get_vpd_page to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_done to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_dma_unmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_dma_map to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_device_type to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_device_set_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_device_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_device_lookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_device_from_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_change_queue_depth to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_build_sense_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_build_sense to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_block_requests to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_add_host_with_dma to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scsi_add_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scnprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol scmd_printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __SCK__tp_func_xdp_exception to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol schedule_timeout_uninterruptible to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol schedule_timeout to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol schedule to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sched_clock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_rphy_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_rphy_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_remove_host to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_release_transport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_delete_phy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_delete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_alloc_num to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_add_phy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_port_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_phy_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_phy_delete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_phy_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_phy_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_expander_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_end_device_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_attach_transport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol sas_ata_ncq_prio_supported to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rtnl_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rtnl_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rtnl_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rtnl_is_locked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rps_may_expire_flow to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol round_jiffies to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol root_device_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __root_device_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rht_bucket_nested_insert to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __rht_bucket_nested to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_walk_stop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_walk_start_check to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_walk_next to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_walk_exit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_walk_enter to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_insert_slow to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_init_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rhashtable_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol reset_devices to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol request_threaded_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __request_region to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __request_module to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol request_firmware_nowait to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol request_firmware to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol remove_wait_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol remove_proc_entry to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol remap_pfn_range to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __release_region to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol release_firmware to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_switchdev_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_switchdev_blocking_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_reboot_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_netevent_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_netdevice_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_netdevice to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_netdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_kprobe to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_inetaddr_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_inet6addr_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol register_chrdev_region to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __register_chrdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __register_blkdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __refrigerator to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol refcount_warn_saturate to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rcuref_get_slowpath to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __rcu_read_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __rcu_read_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rb_next to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol rb_first to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_write_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_write_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_write_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_write_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_unlock_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_unlock_bh to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_lock_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_lock_bh to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_spin_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_read_unlock_irqrestore to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_read_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_read_lock_irqsave to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _raw_read_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ___ratelimit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol radix_tree_lookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol queue_work_on to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol queue_limits_commit_update to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol queue_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol qdisc_reset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __put_user_8 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __put_user_4 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __put_user_2 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol put_disk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __put_devmap_managed_folio_refs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol put_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptrs_per_p4d to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_schedule_worker to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_parse_header to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_find_pin to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_clock_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_clock_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_clock_index to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_clock_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ptp_classify_raw to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ___pskb_trim to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __pskb_pull_tail to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pskb_expand_head to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol proc_remove to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol proc_mkdir to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol proc_create_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol proc_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol priv_to_devlink to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __printk_ratelimit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol print_hex_dump to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol prepare_to_wait_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol prepare_to_wait to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol prepare_creds to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pm_schedule_suspend to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __pm_runtime_resume to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __pm_runtime_idle to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pldmfw_op_pci_match_record to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pldmfw_flash_image to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pid_task to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_validate_pause to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_support_asym_pause to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_stop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_start_aneg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_start to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol physical_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_set_max_speed to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_set_asym_pause to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phys_base to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_mii_ioctl to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_ethtool_ksettings_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_ethtool_ksettings_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_disconnect to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_connect to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol phy_attached_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pgdir_shift to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol perf_trace_run_bpf_submit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol perf_trace_buf_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __per_cpu_offset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcpu_hot to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcpu_alloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcix_set_mmrbc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_write_config_word to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_write_config_dword to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_write_config_byte to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_wake_from_d3 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_wait_for_pending_transaction to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_vpd_find_ro_info_keyword to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_vpd_check_csum to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_vpd_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_vfs_assigned to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_unregister_driver to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_try_set_mwi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_sriov_set_totalvfs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_set_power_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_set_mwi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_set_master to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_select_bars to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_save_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_restore_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_restore_msi_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_reset_bus to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_request_selected_regions to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_request_regions to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_release_selected_regions to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_release_regions to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __pci_register_driver to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_read_vpd to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_read_config_word to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_read_config_dword to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_read_config_byte to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_prepare_to_sleep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_num_vf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_msix_free_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_msix_can_alloc_dyn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_msix_alloc_irq_at to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcim_iomap_table to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcim_iomap_regions to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcim_enable_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_irq_vector to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_irq_get_affinity to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_iov_virtfn_devfn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_iounmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_ioremap_bar to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_iomap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_get_slot to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_get_dsn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_get_domain_bus_and_slot to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_get_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_free_irq_vectors to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_find_ext_capability to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_find_capability to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_set_readrq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_print_link_status to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_wake to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_sriov to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_msix_range to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_msi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_device_mem to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_enable_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_get_readrq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_flr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_capability_write_word to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_capability_read_word to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_capability_read_dword to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_capability_clear_and_set_word_unlocked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pcie_capability_clear_and_set_word_locked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_disable_sriov to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_disable_rom to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_disable_msix to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_disable_msi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_disable_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_dev_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_dev_present to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_device_is_present to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_dev_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_clear_mwi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_clear_master to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_choose_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_cfg_access_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_cfg_access_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_bus_type to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_alloc_irq_vectors_affinity to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_alloc_irq_vectors to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol pci_aer_clear_nonfatal_status to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol path_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_ushort to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_ulong to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_ullong to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_uint to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_long to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_int to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_charp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_byte to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_ops_bool to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol param_array_ops to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol panic_notifier_list to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol panic to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_put_unrefed_netmem to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_disable_direct_recycling to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_alloc_pages to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_pool_alloc_frag to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_offset_base to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol page_frag_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __page_frag_cache_drain to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_unregister_targetport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_register_targetport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_rcv_ls_req to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_rcv_fcp_req to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_rcv_fcp_abort to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvmet_fc_invalidate_host to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_unregister_remoteport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_unregister_localport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_set_remoteport_devloss to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_rescan_remoteport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_register_remoteport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_register_localport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_rcv_ls_req to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nvme_fc_io_getuuid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __num_online_cpus to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol numa_node to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ns_to_timespec64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nr_cpu_ids to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol noop_llseek to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol node_to_cpumask_map to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol node_states to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __node_distance to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol nla_find to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol net_ratelimit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_tx_wake_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_tx_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_tx_stop_all_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_tx_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_set_xps_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_set_tso_max_size to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_set_tso_max_segs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_set_real_num_tx_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_set_real_num_rx_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_schedule_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_rx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_receive_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_queue_set_napi to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __netif_napi_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_napi_add_weight to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_get_num_default_rss_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_device_detach to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_device_attach to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_carrier_on to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netif_carrier_off to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol net_dim_get_rx_moderation to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol net_dim to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_warn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_walk_all_upper_dev_rcu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_update_features to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_unbind_sb_channel to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_state_change to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_set_tc_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_set_sb_channel to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_set_num_tc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_rx_handler_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_rx_handler_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_rss_key_fill to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_reset_tc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_refcnt_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_port_same_parent_id to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_pick_tx to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_notice to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_master_upper_dev_get_rcu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_master_upper_dev_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_features_change to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_err to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_crit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_core_stats_inc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol netdev_bind_sb_channel_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __netdev_alloc_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __netdev_alloc_frag_align to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __neigh_event_send to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol neigh_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ndo_dflt_fdb_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ndo_dflt_bridge_getlink to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __ndelay to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_schedule_prep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __napi_schedule_irqoff to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __napi_schedule to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_gro_receive to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_enable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_disable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_consume_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_complete_done to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_build_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol napi_alloc_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __napi_alloc_frag_align to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol names_cachep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mutex_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mutex_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mutex_lock_interruptible to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mutex_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mutex_is_locked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __mutex_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol msleep_interruptible to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol msleep to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __msecs_to_jiffies to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mpi_read_raw_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mpi_powm to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mpi_get_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mpi_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mpi_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol module_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol module_layout to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __module_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mod_timer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mod_delayed_work_on to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mmu_notifier_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mmu_notifier_get_locked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mmput to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __mmap_lock_do_trace_start_locking to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __mmap_lock_do_trace_released to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __mmap_lock_do_trace_acquire_returned to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mlx5_core_uplink_netdev_event_replay to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mlx5_core_access_reg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mlx5_blocking_notifier_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mlx5_blocking_notifier_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol misc_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol misc_deregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol metadata_dst_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol metadata_dst_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mem_section to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_kmalloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_kfree to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_free_slab to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_create_node_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_alloc_slab to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mempool_alloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memory_read_from_buffer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memmove to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memdup_user_nul to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memdup_user to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memcpy_toio to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memcpy_fromio to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memcpy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memcmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memchr_inv to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol memchr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mds_idle_clear to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdio_mii_ioctl to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __mdiobus_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_get_phy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_c45_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_c45_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdiobus_alloc_size to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol mdio45_probe to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol lookup_one_len to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol local_clock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __local_bh_enable_ip to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __list_del_entry_valid_or_report to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __list_add_valid_or_report to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol libie_rx_pt_lut to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol libeth_rx_recycle_slow to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol libeth_rx_fq_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol libeth_rx_fq_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kvfree_call_rcu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_with_offset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_ts64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_seconds to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_real_ts64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_real_seconds to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get_raw_ts64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ktime_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_use_mm to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_unuse_mm to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_stop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_should_stop to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_queue_work to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_queue_delayed_work to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_destroy_worker to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_create_worker to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_create_on_node to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_complete_and_exit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_cancel_work_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_cancel_delayed_work_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kthread_bind to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtoull to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtouint to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtou8 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtou16 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtos16 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtoll to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtoint to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kstrtobool to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ksize to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol krealloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_uevent_env to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_uevent to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_set_name to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_init_and_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_get_unless_zero to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kobject_create_and_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmemdup_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmem_cache_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmem_cache_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmem_cache_create_args to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmem_cache_alloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmalloc_size_roundup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_node_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_large_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_large_node_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kmalloc_caches to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_cache_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __kmalloc_cache_node_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kill_pid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kill_pgrp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kill_fasync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kfree_sensitive to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kfree to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kexec_crash_loaded to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kern_path_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kern_path to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kernel_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kernel_sigaction to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kernel_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol kasprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol jiffies_to_usecs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol jiffies_to_msecs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol jiffies to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol iter_div_u64_rem to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol is_vmalloc_addr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol is_uv_system to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_set_affinity_notifier to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_set_affinity to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_poll_sched to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_poll_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_poll_enable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_poll_disable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_poll_complete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_modify_status to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol irq_cpu_rmap_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __irq_apply_affinity_hint to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ipv6_skip_exthdr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ipv6_find_hdr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ipv6_ext_hdr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol iput to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ip_route_output_flow to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ip_queue_xmit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ip_compute_csum to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ip6_route_output_flags to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ip6_dst_hoplimit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __iowrite64_copy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol iounmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ioremap_wc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ioremap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __ioread32_copy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol iomem_resource to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol invalidate_bdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol int_to_scsilun to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __init_waitqueue_head to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol init_wait_entry to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol init_uts_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol init_user_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol init_timer_key to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __init_swait_queue_head to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __init_rwsem to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol init_net to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __inet_lookup_established to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol inet_del_protocol to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol inet_add_protocol to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __inet6_lookup_established to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ilookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol idr_remove to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol idr_find to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol idr_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol idr_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ida_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ida_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ida_alloc_range to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol I_BDEV to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol i2c_smbus_write_byte_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol i2c_smbus_read_byte_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol i2c_new_client_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol i2c_del_adapter to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol i2c_bit_add_bus to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hwmon_notify_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hwmon_device_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hwmon_device_register_with_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hwmon_device_register_with_groups to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hwmon_device_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __hw_addr_unsync_dev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __hw_addr_sync_dev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __hw_addr_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hugetlb_optimize_vmemmap_key to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hrtimer_start_range_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hrtimer_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hrtimer_forward to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol hrtimer_cancel to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol gnss_register_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol gnss_put_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol gnss_insert_raw to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol gnss_deregister_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol gnss_allocate_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_zeroed_page_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_user_pages_remote to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __get_user_4 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __get_user_2 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_random_u32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_random_u16 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_random_bytes to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_free_pages_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_device_system_crosststamp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol get_cpu_idle_time to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol generic_file_write_iter to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol generic_file_read_iter to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fs_bio_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol freezing_slow_path to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_percpu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_pages to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __free_pages to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_netdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_irq_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol free_cpumask_var to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fput to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __fortify_panic to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __folio_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __flush_workqueue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flush_work to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flush_signals to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_vlan to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_tcp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_pppoe to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_ports to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_l2tpv3 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_ipv6_addrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_ipv4_addrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_ip to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_icmp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_eth_addrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_ports to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_opts to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_keyid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_ipv6_addrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_ipv4_addrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_ip to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_enc_control to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_cvlan to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_control to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_rule_match_basic to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_keys_dissector to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_indr_dev_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_indr_dev_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_indr_block_cb_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_block_cb_setup_simple to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol flow_block_cb_lookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fixed_size_llseek to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol firmware_request_nowarn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol finish_wait to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol find_vma to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol find_pid_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_next_zero_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_next_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_next_and_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_last_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_first_zero_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _find_first_bit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol filp_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol filp_close to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol file_ns_capable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol file_bdev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fget to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __fentry__ to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_vport_terminate to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_vport_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_remove_host to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_remote_port_rolechg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_remote_port_delete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_remote_port_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_release_transport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_host_post_vendor_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_host_post_event to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_host_fpin_rcv to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_get_event_number to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_eh_timed_out to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_eh_should_retry_cmd to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_block_scsi_eh to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_block_rport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fc_attach_transport to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol fasync_helper to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol event_triggers_call to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol eth_validate_addr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol eth_type_trans to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_sprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_rxfh_context_lost to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_puts to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_params_from_link_mode to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_op_get_ts_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_op_get_link to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_intersect_link_masks to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_forced_speed_maps_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_convert_link_mode_to_legacy_u32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ethtool_convert_legacy_u32_to_link_mode to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol eth_platform_get_mac_address to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol eth_get_headlen to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol ether_setup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol enable_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol empty_zero_page to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol emergency_restart to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol elfcorehdr_addr to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dynamic_pr_debug to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dynamic_netdev_dbg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dynamic_dev_dbg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dump_stack to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dst_release to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol driver_remove_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol driver_for_each_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol driver_create_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dql_reset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dql_completed to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dput to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_on_pin_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_on_pin_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_pin_change_ntf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_netdev_pin_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_netdev_pin_clear to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_device_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_device_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_device_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_device_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dpll_device_change_ntf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_write_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_read_trylock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down_interruptible to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol downgrade_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol down to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol do_trace_netlink_extack to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol done_path_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dmi_get_system_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dmi_find_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_unmap_sg_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_unmap_page_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dma_sync_single_for_device to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dma_sync_single_for_cpu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_set_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_set_coherent_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_pool_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_pool_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_pool_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_pool_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dmam_free_coherent to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_map_sg_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_map_page_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dmam_alloc_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_get_required_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_free_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dma_alloc_attrs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol disable_irq_nosync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol disable_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dget_parent to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_warn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_uc_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_uc_add_excl to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_uc_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_trans_start to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_set_promiscuity to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_set_name to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_set_mtu to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_set_mac_address to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_remove_pack to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __dev_queue_xmit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_printk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_open to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_notice to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_request_threaded_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_mdiobus_alloc_size to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_kmemdup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_kmalloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_kfree to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_kasprintf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_hwmon_device_register_with_groups to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devm_free_irq to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_mc_del_global to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_mc_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_mc_add_global to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_mc_add_excl to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_mc_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devmap_managed_key to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __devm_add_action to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_unlock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_region_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_region_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_rate_nodes_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_rate_node_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_rate_leaf_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_rate_leaf_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_port_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_port_register_with_ops to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_port_fn_devlink_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_params_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_params_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_nested_devlink_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_remote_reload_actions_performed to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_priv to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_port_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_port_register_with_ops to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_port_attrs_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_params_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_params_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_info_version_stored_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_info_version_running_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_info_version_fixed_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_info_serial_number_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_info_board_serial_number_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_reporter_state_update to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_reporter_recovery_done to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_reporter_priv to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_reporter_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_reporter_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_health_report to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_fmsg_u32_pair_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_fmsg_string_pair_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_fmsg_pair_nest_start to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_fmsg_pair_nest_end to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_fmsg_binary_pair_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_flash_update_timeout_notify to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_flash_update_status_notify to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devlink_alloc_ns to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol devl_assert_locked to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_kfree_skb_irq_reason to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_kfree_skb_any_reason to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_wakeup_disable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_show_string to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_set_wakeup_enable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_set_wakeup_capable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_remove_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_initialize to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_create_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_add_disk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol device_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_get_stats to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_get_by_name to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_err to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_driver_string to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _dev_crit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_close to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_addr_mod to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_addr_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_addr_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dev_add_pack to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol destroy_workqueue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol del_gendisk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol delayed_work_timer_fn to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol default_wake_function to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol default_llseek to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_remove to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_lookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_create_u32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_create_file to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_create_dir to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_create_devm_seqfile to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_attr_write to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol debugfs_attr_read to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcbnl_ieee_notify to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcb_ieee_setapp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcb_ieee_getapp_prio_dscp_mask_map to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcb_ieee_getapp_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcb_ieee_delapp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dcb_getapp to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dca_unregister_notify to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dca_remove_requester to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dca_register_notify to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dca_add_requester to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol dca3_get_tag to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol current_work to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _ctype to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol csum_partial to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol csum_ipv6_magic to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crypto_shash_update to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crypto_shash_final to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crypto_destroy_tfm to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crypto_alloc_shash to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crc_t10dif to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol crc32_le to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpu_sibling_map to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpu_present_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpu_possible_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpu_online_mask to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpumask_next_wrap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpumask_local_spread to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpu_khz to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpu_info to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpuhp_state_remove_instance to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpuhp_state_add_instance to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpuhp_setup_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __cpuhp_remove_state to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpufreq_quick_get to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cpu_bit_bitmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _copy_to_user to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __copy_overflow to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _copy_from_user to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol consume_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __const_udelay to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol const_pcpu_hot to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol complete_all to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol complete to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol commit_creds to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol clock_t_to_jiffies to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol class_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol class_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol class_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol class_create to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __check_object_size to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cdev_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cdev_del to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cdev_alloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cdev_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cc_mkdec to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol capable to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cancel_work_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cancel_delayed_work_sync to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cancel_delayed_work to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol call_usermodehelper to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol call_switchdev_notifiers to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol call_netdevice_notifiers to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol cachemode2protval to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol byte_rev_table to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol build_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_update to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_remove to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_lookup to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_last to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_insert to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_get_prev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_geo64 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_geo32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol btree_destroy to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bsg_setup_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bsg_remove_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bsg_job_done to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __break_lease to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_warn_invalid_xdp_action to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_trace_run8 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_trace_run4 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_trace_run3 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_trace_run2 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_trace_run1 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_stats_enabled_key to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_prog_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_prog_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_master_redirect_enabled_key to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bpf_dispatcher_xdp_func to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol boot_cpu_data to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blockdev_superblock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_status_to_errno to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_start_plug to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_stack_limits to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_queue_rq_timeout to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_mq_unique_tag to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_mq_tagset_busy_iter to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_mq_pci_map_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_mq_map_queues to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blk_finish_plug to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol blkcg_get_fc_appid to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __blk_alloc_disk to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_zalloc to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_xor to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_weight to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_subset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_set to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_print_to_pagebuf to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_parselist to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_or to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_intersects to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_from_arr32 to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bitmap_find_next_zero_area_off to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_equal to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_clear to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_andnot to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __bitmap_and to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bioset_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bioset_exit to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_put to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_endio to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_clone_blkg_association to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_associate_blkg to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_alloc_clone to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bio_alloc_bioset to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _bin2bcd to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bdev_thaw to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bdev_freeze to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bdev_file_open_by_path to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol bdev_file_open_by_dev to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol auxiliary_driver_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __auxiliary_driver_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol auxiliary_device_init to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __auxiliary_device_add to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol autoremove_wake_function to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol atomic_notifier_chain_unregister to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol atomic_notifier_chain_register to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol _atomic_dec_and_lock to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol argv_split to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol argv_free to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol arch_touch_nmi_watchdog to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_workqueue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __alloc_skb to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_pages_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol __alloc_pages_noprof to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_netdev_mqs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_etherdev_mqs to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_cpu_rmap to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_cpumask_var_node to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol alloc_chrdev_region to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol add_wait_queue_exclusive to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol add_wait_queue to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol add_timer to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol acpi_get_table to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol acpi_disabled to stablelist (Čestmír Kalina) [RHEL-79881]
- kabi: add symbol abort_creds to stablelist (Čestmír Kalina) [RHEL-79881]
- nfs: Fix oops in nfs_netfs_init_request() when copying to cache (Olga Kornievskaia) [RHEL-77295] {CVE-2024-57927}
- rhel_files: ensure all qdiscs are in modules-core (Davide Caratti) [RHEL-80112]
- wifi: mt76: mt7925: add handler to hif suspend/resume event (Jose Ignacio Tornos Martinez) [RHEL-79087]
- wifi: mt76: mt7925: fix CLC command timeout when suspend/resume (Jose Ignacio Tornos Martinez) [RHEL-79087]
- wifi: mt76: mt7925: fix the unfinished command of regd_notifier before suspend (Jose Ignacio Tornos Martinez) [RHEL-79087]
- configs: enable FW_CACHE on centos-stream/rhel 10 for nouveau (Dave Airlie) [RHEL-80281]
- fs/proc: fix softlockup in __read_vmcore (part 2) (Baoquan He) [RHEL-79110] {CVE-2025-21694}
- phy: tegra: xusb: reset VBUS & ID OVERRIDE (Rupinderjit Singh) [RHEL-80387]
- kernel.spec: add missing tools-libs on s390x (Jan Stancek) [RHEL-81118]
- pps: Fix a use-after-free (Michal Schmidt) [RHEL-77270]

* Thu Mar 13 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-64.el10]
- media: ipu-bridge: Remove unneeded conditional compilations (Kate Hsuan) [RHEL-77180 RHEL-77309]
- ACPI: bus: change the prototype for acpi_get_physical_device_location (Kate Hsuan) [RHEL-77309]
- media: ov2740: Add regulator support (Kate Hsuan) [RHEL-77309]
- media: ov2740: Add powerdown GPIO support (Kate Hsuan) [RHEL-77309]
- media: ov2740: Add camera orientation and sensor rotation controls (Kate Hsuan) [RHEL-77309]
- media: ov2740: Debug log chip ID (Kate Hsuan) [RHEL-77309]
- media: mc: fix endpoint iteration (Kate Hsuan) [RHEL-77309]
- media: ccs: Fail the probe on CCS static data parser failure (Kate Hsuan) [RHEL-77309]
- media: ccs: Print a warning on CCS static data parser failure (Kate Hsuan) [RHEL-77309]
- media: intel/ipu6: move some boot messages to debug level (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: intel/ipu6: remove cpu latency qos request on error (Kate Hsuan) [RHEL-77309 RHEL-81387] {CVE-2024-58004}
- media: ccs: Fix cleanup order in ccs_probe() (Kate Hsuan) [RHEL-77309]
- media: dt-bindings: Add property to describe CSI-2 C-PHY line orders (Kate Hsuan) [RHEL-77309]
- media: v4l: fwnode: Parse MiPI DisCo for C-PHY line-orders (Kate Hsuan) [RHEL-77309]
- media: ccs: Clean up parsed CCS static data on parse failure (Kate Hsuan) [RHEL-77309]
- media: ccs: Fix CCS static data parsing for large block sizes (Kate Hsuan) [RHEL-77309]
- media: replace obsolete hans.verkuil@cisco.com alias (Kate Hsuan) [RHEL-77309]
- media: ipu6: make the ipu6_mmu_unmap() as a void function (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: optimize the IPU6 MMU unmapping flow (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: optimize the IPU6 MMU mapping flow (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: move the l2_unmap() up before l2_map() (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: mc: Rename pad as origin in __media_pipeline_start() (Kate Hsuan) [RHEL-77309]
- media: intel/ipu6: remove buttress ish structure (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: intel/ipu6: do not handle interrupts when device is disabled (Kate Hsuan) [RHEL-77180 RHEL-77309] {CVE-2024-56680}
- media: gspca: ov534-ov772x: Fix off-by-one error in set_frame_rate() (Kate Hsuan) [RHEL-77309]
- media: i2c: Drop HAS_EVENTS and event handlers (Kate Hsuan) [RHEL-77309]
- media: v4l2-subdev: Refactor events (Kate Hsuan) [RHEL-77309]
- media: Documentation: ipu6: remove the dma_ops part from the doc (Kate Hsuan) [RHEL-77309]
- media: ipu6: use PFN_UP() and sg_virt() for code simplicity (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: remove architecture DMA ops dependency in Kconfig (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: use the IPU6 DMA mapping APIs to do mapping (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: not override the dma_ops of device in driver (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: Fix DMA and physical address debugging messages for 32-bit (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ov2740: Don't log ov2740_check_hwcfg() errors twice (Kate Hsuan) [RHEL-77309]
- convert media_request_get_by_fd() (Kate Hsuan) [RHEL-77309]
- media: vb2: fix confusing log message (Kate Hsuan) [RHEL-77309]
- media: vb2: Fix comment (Kate Hsuan) [RHEL-77309]
- media: v4l2-core: constify the class struct (Kate Hsuan) [RHEL-77309]
- media: v4l2-core: v4l2-dv-timings: check cvt/gtf result (Kate Hsuan) [RHEL-77309]
- media: common: saa7146: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: platform: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: rtl2832_sdr: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: video-i2c: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: usb: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: pci: drop vb2_ops_wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: videobuf2-core: update vb2_thread if wait_finish/prepare are NULL (Kate Hsuan) [RHEL-77309]
- media: ipu6: remove redundant dependency in Kconfig (Kate Hsuan) [RHEL-77180 RHEL-77309]
- media: ipu6: fix the wrong type casting and 64-bit division (Kate Hsuan) [RHEL-77180 RHEL-77309]
- v4l2-subdev: Return -EOPNOTSUPP for unsupported pad type in call_get_frame_desc() (Kate Hsuan) [RHEL-77309]
- media: i2c: Fix typos in comments across various files (Kate Hsuan) [RHEL-77309]
- media: videodev2: Add flag to unconditionally enumerate pixel formats (Kate Hsuan) [RHEL-77309]
- media: vb2: use lock if wait_prepare/finish are NULL (Kate Hsuan) [RHEL-77309]
- media: vb2: vb2_core_queue_init(): sanity check lock and wait_prepare/finish (Kate Hsuan) [RHEL-77309]
- media: pwc: set lock before calling vb2_queue_init() (Kate Hsuan) [RHEL-77309]
- media: Documentation: Improve v4l2_subdev_{en,dis}able_streams documentation (Kate Hsuan) [RHEL-77309]
- media: Documentation: tx-rx: Fix formatting (Kate Hsuan) [RHEL-77309]
- media: Documentation: Update {enable,disable}_streams documentation (Kate Hsuan) [RHEL-77309]
- media: Documentation: Deprecate s_stream video op, update docs (Kate Hsuan) [RHEL-77309]
- media: v4l2-core: add v4l2_debugfs_if_alloc/free() (Kate Hsuan) [RHEL-77309]
- media: v4l2-core: add v4l2_debugfs_root() (Kate Hsuan) [RHEL-77309]
- media: v4l: Add luma 16-bit interlaced pixel format (Kate Hsuan) [RHEL-77309]
- media: netup_unidvb: switch to use devm_spi_alloc_host() (Kate Hsuan) [RHEL-77309]
- redhat/configs: Disable CONFIG_PKEY for zfcpdump configs (Mete Durlu) [RHEL-78341]
- RDMA/mana_ib: Allocate PAGE aligned doorbell index (Maxim Levitsky) [RHEL-80097]
- net: mana: Cleanup "mana" debugfs dir after cleanup of all children (Maxim Levitsky) [RHEL-80097]
- net: mana: Fix irq_contexts memory leak in mana_gd_setup_irqs (Maxim Levitsky) [RHEL-80097]
- net: mana: Fix memory leak in mana_gd_setup_irqs (Maxim Levitsky) [RHEL-80097]
- net :mana :Request a V2 response version for MANA_QUERY_GF_STAT (Maxim Levitsky) [RHEL-80097]
- net: mana: use ethtool string helpers (Maxim Levitsky) [RHEL-80097]
- net: mana: Enable debugfs files for MANA device (Maxim Levitsky) [RHEL-80097]
- net: mana: Add get_link and get_link_ksettings in ethtool (Maxim Levitsky) [RHEL-80097]
- net: mana: Increase the DEF_RX_BUFFERS_PER_QUEUE to 1024 (Maxim Levitsky) [RHEL-80097]

* Tue Mar 11 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-63.el10]
- block: Ensure start sector is aligned for stacking atomic writes (Nigel Croxon) [RHEL-73721]

* Mon Mar 10 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-62.el10]
- s390/pci: Fix handling of isolated VFs (Mete Durlu) [RHEL-81936]
- s390/pci: Pull search for parent PF out of zpci_iov_setup_virtfn() (Mete Durlu) [RHEL-81936]
- s390/pci: Fix SR-IOV for PFs initially in standby (Mete Durlu) [RHEL-81936]
- selftests/net: ensure mptcp is enabled in netns (Hangbin Liu) [RHEL-80379]
- netfs: Fix the (non-)cancellation of copy when cache is temporarily disabled (CKI Backport Bot) [RHEL-75660] {CVE-2024-57941}
- netfs: Fix ceph copy to cache on write-begin (CKI Backport Bot) [RHEL-75655] {CVE-2024-57942}
- Bluetooth: btusb: Add new VID/PID 13d3/3628 for MT7925 (Bastien Nocera) [RHEL-79457]
- Bluetooth: btmtk: Fix failed to send func ctrl for MediaTek devices. (Bastien Nocera) [RHEL-79457]
- Bluetooth: btmtk: avoid UAF in btmtk_process_coredump (Bastien Nocera) [RHEL-79457] {CVE-2024-56653}
- Bluetooth: btmtk: adjust the position to init iso data anchor (Bastien Nocera) [RHEL-79457] {CVE-2024-53238}
- Bluetooth: btusb: mediatek: change the conditions for ISO interface (Bastien Nocera) [RHEL-79457]
- Bluetooth: btusb: mediatek: add intf release flow when usb disconnect (Bastien Nocera) [RHEL-79457] {CVE-2024-56757}
- Bluetooth: btusb: mediatek: add callback function in btusb_disconnect (Bastien Nocera) [RHEL-79457]
- Bluetooth: btusb: mediatek: move Bluetooth power off command position (Bastien Nocera) [RHEL-79457]
- redhat/configs: Enable Mediatek Bluetooth USB drivers (Bastien Nocera) [RHEL-79457]
- scsi: qla2xxx: Fix use after free on unload (Ewan D. Milne) [RHEL-76090] {CVE-2024-56623}
- scsi: sg: Fix slab-use-after-free read in sg_release() (Ewan D. Milne) [RHEL-76089] {CVE-2024-56631}
- CVE-2025-1272: security: Re-enable lockdown LSM in some setup_arch() (Lenny Szubowicz) [RHEL-78975] {CVE-2025-1272}

* Fri Mar 07 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-61.el10]
- af_packet: fix vlan_get_tci() vs MSG_PEEK (CKI Backport Bot) [RHEL-80305] {CVE-2024-57902}
- smb: client: fix chmod(2) regression with ATTR_READONLY (Paulo Alcantara) [RHEL-80534]
- sched_ext: Fix incorrect autogroup migration detection (CKI Backport Bot) [RHEL-81482] {CVE-2025-21771}
- PCI: vmd: Set devices to D0 before enabling PM L1 Substates (Myron Stowe) [RHEL-47437]
- PCI: vmd: Add DID 8086:B06F and 8086:B60B for Intel client SKUs (Myron Stowe) [RHEL-47437]
- kernel.spec: add missing tools-libs on s390x (Jan Stancek) [RHEL-80626]
- arm64: cacheinfo: Avoid out-of-bounds write to cacheinfo array (CKI Backport Bot) [RHEL-81669] {CVE-2025-21785}
- kexec/crash: no crash update when kexec in progress (Mamatha Inamdar) [RHEL-76749]
- md/raid*: Fix the set_queue_limits implementations (Nigel Croxon) [RHEL-73721]
- md: Fix linear_set_limits() (Nigel Croxon) [RHEL-73721]
- md/md-bitmap: Synchronize bitmap_get_stats() with bitmap lifetime (CKI Backport Bot) [RHEL-81540] {CVE-2025-21712}
- md/md-linear: Fix a NULL vs IS_ERR() bug in linear_add() (Nigel Croxon) [RHEL-73721]
- md/md-bitmap: move bitmap_{start, end}write to md upper layer (Nigel Croxon) [RHEL-73721]
- md/raid5: implement pers->bitmap_sector() (Nigel Croxon) [RHEL-73721]
- md: add a new callback pers->bitmap_sector() (Nigel Croxon) [RHEL-73721]
- md/md-bitmap: remove the last parameter for bimtap_ops->endwrite() (Nigel Croxon) [RHEL-73721]
- md/md-bitmap: factor behind write counters out from bitmap_{start/end}write() (Nigel Croxon) [RHEL-73721]
- md: Replace deprecated kmap_atomic() with kmap_local_page() (Nigel Croxon) [RHEL-73721]
- md/raid10: Atomic write support (Nigel Croxon) [RHEL-73721]
- md/raid1: Atomic write support (Nigel Croxon) [RHEL-73721]
- md/raid0: Atomic write support (Nigel Croxon) [RHEL-73721]
- block: Support atomic writes limits for stacked devices (Nigel Croxon) [RHEL-73721]
- md/raid5: Increase r5conf.cache_name size (Nigel Croxon) [RHEL-73721]
- md/raid10: Handle bio_split() errors (Nigel Croxon) [RHEL-73721]
- md/raid1: Handle bio_split() errors (Nigel Croxon) [RHEL-73721]
- md/raid0: Handle bio_split() errors (Nigel Croxon) [RHEL-73721]
- md/raid5: Wait sync io to finish before changing group cnt (Nigel Croxon) [RHEL-73721]
- md/md-bitmap: Add missing destroy_work_on_stack() (Nigel Croxon) [RHEL-73721]
- md/raid5: don't set Faulty rdev for blocked_rdev (Nigel Croxon) [RHEL-73721]
- md/raid10: don't wait for Faulty rdev in wait_blocked_rdev() (Nigel Croxon) [RHEL-73721]
- md/raid1: don't wait for Faulty rdev in wait_blocked_rdev() (Nigel Croxon) [RHEL-73721]
- md/raid1: factor out helper to handle blocked rdev from raid1_write_request() (Nigel Croxon) [RHEL-73721]
- md: don't record new badblocks for faulty rdev (Nigel Croxon) [RHEL-73721]
- md: don't wait faulty rdev in md_wait_for_blocked_rdev() (Nigel Croxon) [RHEL-73721]
- md: add a new helper rdev_blocked() (Nigel Croxon) [RHEL-73721]
- md/raid5-ppl: Use atomic64_inc_return() in ppl_new_iounit() (Nigel Croxon) [RHEL-73721]
- RDMA/mlx5: Fix a WARN during dereg_mr for DM type (Benjamin Poirier) [RHEL-41204]
- arm64: mm: Fix zone_dma_limit calculation (Luiz Capitulino) [RHEL-71568]
- uki: enable FIPS mode (Vitaly Kuznetsov) [RHEL-80149]

* Wed Mar 05 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-60.el10]
- idpf: call set_real_num_queues in idpf_open (CKI Backport Bot) [RHEL-79464]
- tracing: Fix bad hist from corrupting named_triggers list (Tomas Glozar) [RHEL-80060]
- net/smc: support ipv4 mapped ipv6 addr client for smc-r v2 (Mete Durlu) [RHEL-79809]
- af_packet: fix vlan_get_protocol_dgram() vs MSG_PEEK (CKI Backport Bot) [RHEL-74125] {CVE-2024-57901}
- cxgb4: use port number to set mac addr (CKI Backport Bot) [RHEL-75473]
- Documentation/powerpc/fadump: add additional parameter feature details (Mamatha Inamdar) [RHEL-70827]
- powerpc: increase MIN RMA size for CAS negotiation (Mamatha Inamdar) [RHEL-70827]
- powerpc/fadump: fix additional param memory reservation for HASH MMU (Mamatha Inamdar) [RHEL-70827]
- powerpc: export MIN RMA size (Mamatha Inamdar) [RHEL-70827]
- scsi: mpi3mr: Update driver version to 8.12.1.0.50 (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Synchronous access b/w reset and tm thread for reply queue (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Avoid reply queue full condition (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Fix possible crash when setting up bsg fails (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Handling of fault code for insufficient power (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Start controller indexing from 0 (Chandrakanth Patil) [RHEL-30789]
- scsi: mpi3mr: Fix corrupt config pages PHY state is switched in sysfs (Chandrakanth Patil) [RHEL-30789] {CVE-2024-57804}
- scsi: mpi3mr: Synchronize access to ioctl data buffer (Chandrakanth Patil) [RHEL-30789]
- redhat: regenerate self-test data for new RHDISTGIT_BRANCH (Patrick Talbert)

* Mon Mar 03 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-59.el10]
- gpu: host1x: Fix a use of uninitialized mutex (Rupinderjit Singh) [RHEL-67594]
- selftests/memfd: add test for mapping write-sealed memfd read-only (Rafael Aquini) [RHEL-77292] {CVE-2024-57937}
- mm: reinstate ability to map write-sealed memfd mappings read-only (Rafael Aquini) [RHEL-77292] {CVE-2024-57937}
- bonding: Correctly support GSO ESP offload (CKI Backport Bot) [RHEL-74426]
- redhat: adjust rhel branch name (Jan Stancek)
- redhat: set defaults for RHEL 10.0 (Jan Stancek)
- Revert "x86/kvm: Override default caching mode for SEV-SNP and TDX" (Vitaly Kuznetsov) [RHEL-76109]

* Thu Feb 27 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-58.el10]
- quota: flush quota_release_work upon quota writeback (CKI Backport Bot) [RHEL-73465]
- s390/topology: Improve topology detection (Mete Durlu) [RHEL-76349]

* Tue Feb 25 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-57.el10]
- cpufreq/amd-pstate-ut: Add fix for min freq unit test (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Fix cpufreq_policy ref counting (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Fix max_perf updation with schedutil (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Remove the goto label in amd_pstate_update_limits (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Fix per-policy boost flag incorrect when fail (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Refactor max frequency calculation (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Fix prefcore rankings (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Drop boost_state variable (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Set different default EPP policy for Epyc and Ryzen (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Drop ret variable from amd_pstate_set_energy_pref_index() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Always write EPP value when updating perf (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Cache EPP value and use that everywhere (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Move limit updating code (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Change amd_pstate_update_perf() to return an int (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: store all values in cpudata struct in khz (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Only update the cached value in msr_set_epp() on success (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Use FIELD_PREP and FIELD_GET macros (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Drop cached epp_policy variable (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: convert mutex use to guard() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Add trace event for EPP perf updates (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Merge amd_pstate_epp_cpu_offline() and amd_pstate_epp_offline() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Remove the cppc_state check in offline/online functions (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Refactor amd_pstate_epp_reenable() and amd_pstate_epp_offline() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Move the invocation of amd_pstate_update_perf() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Convert the amd_pstate_get/set_epp() to static calls (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Use boost numerator for upper bound of frequencies (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Store the boost numerator as highest perf again (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Detect preferred core support before driver registration (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Move registration after static function call update (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Push adjust_perf vfunc init into cpu_init (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Align offline flow of shared memory and MSR based systems (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Call cppc_set_epp_perf in the reenable function (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Do not attempt to clear MSR_AMD_CPPC_ENABLE (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Rename functions that enable CPPC (Steve Best) [RHEL-75925]
- amd-pstate: Switch to amd-pstate by default on some Server platforms (Steve Best) [RHEL-75925]
- amd-pstate: Set min_perf to nominal_perf for active mode performance gov (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Remove the redundant amd_pstate_set_driver() call (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Remove the switch case in amd_pstate_init() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Call amd_pstate_set_driver() in amd_pstate_register_driver() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Call amd_pstate_register() in amd_pstate_init() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Set the initial min_freq to lowest_nonlinear_freq (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Remove the redundant verify() function (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Drop needless EPP initialization (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Use amd_pstate_update_min_max_limit() for EPP limits (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Don't update CPPC request in amd_pstate_cpu_boost_update() (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Fix non kerneldoc comment (Steve Best) [RHEL-75925]
- cpufreq/amd-pstate: Rename MSR and shared memory specific functions (Steve Best) [RHEL-75925]
- x86/cpufeatures: Rename X86_FEATURE_FAST_CPPC to have AMD prefix (Steve Best) [RHEL-75925]
- tools/power turbostat: version 2025.02.02 (Steve Best) [RHEL-77986]
- tools/power turbostat: Add CPU%%c1e BIC for CWF (Steve Best) [RHEL-77986]
- tools/power turbostat: Harden one-shot mode against cpu offline (Steve Best) [RHEL-77986]
- tools/power turbostat: Fix forked child affinity regression (Steve Best) [RHEL-77986]
- tools/power turbostat: Add tcore clock PMT type (Steve Best) [RHEL-77986]
- tools/power turbostat: version 2025.01.14 (Steve Best) [RHEL-77986]
- tools/power turbostat: Allow adding PMT counters directly by sysfs path (Steve Best) [RHEL-77986]
- tools/power turbostat: Allow mapping multiple PMT files with the same GUID (Steve Best) [RHEL-77986]
- tools/power turbostat: Add PMT directory iterator helper (Steve Best) [RHEL-77986]
- tools/power turbostat: Extend PMT identification with a sequence number (Steve Best) [RHEL-77986]
- tools/power turbostat: Return default value for unmapped PMT domains (Steve Best) [RHEL-77986]
- tools/power turbostat: Check for non-zero value when MSR probing (Steve Best) [RHEL-77986]
- tools/power turbostat: Enhance turbostat self-performance visibility (Steve Best) [RHEL-77986]
- tools/power turbostat: Add fixed RAPL PSYS divisor for SPR (Steve Best) [RHEL-77986]
- tools/power turbostat: Fix PMT mmaped file size rounding (Steve Best) [RHEL-77986]
- tools/power turbostat: Remove SysWatt from DISABLED_BY_DEFAULT (Steve Best) [RHEL-77986]
- tools/power turbostat: Add an NMI column (Steve Best) [RHEL-77986]
- tools/power turbostat: add Busy%% to "show idle" (Steve Best) [RHEL-77986]
- tools/power turbostat: Introduce --force parameter (Steve Best) [RHEL-77986]
- tools/power turbostat: Improve --help output (Steve Best) [RHEL-77986]
- tools/power turbostat: Exit on unsupported Vendors (Steve Best) [RHEL-77986]
- tools/power turbostat: Exit on unsupported Intel models (Steve Best) [RHEL-77986]
- tools/power turbostat: update turbostat(8) (Steve Best) [RHEL-77986]
- tools/power turbostat: Add initial support for ClearwaterForest (Steve Best) [RHEL-77986]
- tools/power turbostat: Add initial support for PantherLake (Steve Best) [RHEL-77986]
- tools/power turbostat: 2024.11.30 (Steve Best) [RHEL-77986]
- tools/power turbostat: Add RAPL psys as a built-in counter (Steve Best) [RHEL-77986]
- tools/power turbostat: Fix child's argument forwarding (Steve Best) [RHEL-77986]
- tools/power turbostat: Force --no-perf in --dump mode (Steve Best) [RHEL-77986]
- tools/power turbostat: Add support for /sys/class/drm/card1 (Steve Best) [RHEL-77986]
- tools/power turbostat: Cache graphics sysfs file descriptors during probe (Steve Best) [RHEL-77986]
- tools/power turbostat: Consolidate graphics sysfs access (Steve Best) [RHEL-77986]
- tools/power turbostat: Remove unnecessary fflush() call (Steve Best) [RHEL-77986]
- tools/power turbostat: Enhance platform divergence description (Steve Best) [RHEL-77986]
- tools/power turbostat: Remove PC3 support on Lunarlake (Steve Best) [RHEL-77986]
- tools/power turbostat: Rename arl_features to lnl_features (Steve Best) [RHEL-77986]
- tools/power turbostat: Add back PC8 support on Arrowlake (Steve Best) [RHEL-77986]
- tools/power turbostat: Remove PC7/PC9 support on MTL (Steve Best) [RHEL-77986]
- tools/power turbostat: Honor --show CPU, even when even when num_cpus=1 (Steve Best) [RHEL-77986]
- tools/power turbostat: Fix trailing '\n' parsing (Steve Best) [RHEL-77986]
- tools/power turbostat: Allow using cpu device in perf counters on hybrid platforms (Steve Best) [RHEL-77986]
- tools/power turbostat: Fix column printing for PMT xtal_time counters (Steve Best) [RHEL-77986]
- tools/power turbostat: fix GCC9 build regression (Steve Best) [RHEL-77986]
- thermal: intel: Fix compile issue when CONFIG_NET is not defined (Steve Best) [RHEL-79162]
- thermal: intel: int340x: Panther Lake power floor and workload hint support (Steve Best) [RHEL-79162]
- thermal: intel: int340x: Panther Lake DLVR support (Steve Best) [RHEL-79162]
- thermal: intel: Remove explicit user_space governor selection (Steve Best) [RHEL-79162]
- ACPI: DPTF: Support Panther Lake (Steve Best) [RHEL-79162]
- thermal: intel: int340x: processor: Enable MMIO RAPL for Panther Lake (Steve Best) [RHEL-79162]
- thermal: int3400: Remove unneeded data_vault attribute_group (Steve Best) [RHEL-79162]
- thermal: int3400: Fix reading of current_uuid for active policy (Steve Best) [RHEL-79162]
- thermal: Switch back to struct platform_driver::remove() (Steve Best) [RHEL-79162]
- x86/cpu: Fix FAM5_QUARK_X1000 to use X86_MATCH_VFM() (Steve Best) [RHEL-79162]
- tools/power/x86/intel-speed-select: v1.21 release (Steve Best) [RHEL-76843]
- tools/power/x86/intel-speed-select: Fix TRL restore after SST-TF disable (Steve Best) [RHEL-76843]
- platform/x86: ISST: Add Clearwater Forest to support list (Steve Best) [RHEL-76843]
- cpufreq: intel_pstate: Use CPUFREQ_POLICY_UNKNOWN (Steve Best) [RHEL-78189]
- cpufreq: intel_pstate: Drop Arrow Lake from "scaling factor" list (Steve Best) [RHEL-78189]
- cpufreq: intel_pstate: Use CPPC to get scaling factors (Steve Best) [RHEL-78189]

* Thu Feb 20 2025 Julio Faracco <jfaracco@redhat.com> [6.12.0-56.el10]
- cpupower: Adjust whitespace for amd-pstate specific prints (Steve Best) [RHEL-78946]
- cpupower: Don't fetch maximum latency when EPP is enabled (Steve Best) [RHEL-78946]
- cpupower: Add support for showing energy performance preference (Steve Best) [RHEL-78946]
- cpupower: Don't try to read frequency from hardware when kernel uses aperfmperf (Steve Best) [RHEL-78946]
- cpupower: Add support for amd-pstate preferred core rankings (Steve Best) [RHEL-78946]
- cpupower: Remove spurious return statement (Steve Best) [RHEL-78946]
- cpupower: fix TSC MHz calculation (Steve Best) [RHEL-78946]
- cpupower: revise is_valid flag handling for idle_monitor (Steve Best) [RHEL-78946]
- powercap: call put_device() on an error path in powercap_register_control_type() (Steve Best) [RHEL-79097]
- powercap: intel_rapl: Add support for Panther Lake platform (Steve Best) [RHEL-79097]
- Bump RHEL MINOR to 10.1 (Julio Faracco)


###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
